@@ -148,7 +148,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     angle = rdMolTransforms.GetAngleDeg(conf, 1, 3, 6)
-    self.assertTrue(int(angle) == 90)
+    self.assertAlmostEqual(angle, 90, delta=0.1)
     ff = ChemicalForceFields.UFFGetMoleculeForceField(m)
     self.assertTrue(ff)
     ff.UFFAddAngleConstraint(1, 3, 6, True, -10.0, 10.0, 100.0)
@@ -156,7 +156,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     angle = rdMolTransforms.GetAngleDeg(conf, 1, 3, 6)
-    self.assertTrue(int(angle) == 100)
+    self.assertAlmostEqual(angle, 100, delta=0.1)
     ff = ChemicalForceFields.UFFGetMoleculeForceField(m)
     self.assertTrue(ff)
     ff.UFFAddAngleConstraint(1, 3, 6, False, -10.0, 10.0, 100.0)
@@ -164,7 +164,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     angle = rdMolTransforms.GetAngleDeg(conf, 1, 3, 6)
-    self.assertEqual(int(angle), 10)
+    self.assertAlmostEqual(angle, 10, delta=0.1)
 
   def testUFFTorsionConstraints(self):
     m = Chem.MolFromMolBlock(self.molB, True, False)
@@ -176,7 +176,7 @@ M  END"""
     r = ff.Minimize()
     self.assertTrue(r == 0)
     dihedral = rdMolTransforms.GetDihedralDeg(conf, 1, 3, 6, 8)
-    self.assertTrue(int(dihedral) == 20)
+    self.assertAlmostEqual(dihedral, 20, delta=0.1)
     rdMolTransforms.SetDihedralDeg(conf, 1, 3, 6, 8, -30.0)
     ff = ChemicalForceFields.UFFGetMoleculeForceField(m)
     self.assertTrue(ff)
@@ -185,7 +185,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     dihedral = rdMolTransforms.GetDihedralDeg(conf, 1, 3, 6, 8)
-    self.assertEquals(int(dihedral), -40)
+    self.assertAlmostEqual(dihedral, -40, delta=0.1)
     rdMolTransforms.SetDihedralDeg(conf, 1, 3, 6, 8, -10.0)
     ff = ChemicalForceFields.UFFGetMoleculeForceField(m)
     self.assertTrue(ff)
@@ -194,7 +194,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     dihedral = rdMolTransforms.GetDihedralDeg(conf, 1, 3, 6, 8)
-    self.assertTrue(int(dihedral) == -10)
+    self.assertAlmostEqual(dihedral, -10, delta=0.1)
 
   def testUFFPositionConstraints(self):
     m = Chem.MolFromMolBlock(self.molB, True, False)
@@ -262,7 +262,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     angle = rdMolTransforms.GetAngleDeg(conf, 1, 3, 6)
-    self.assertTrue(int(angle) == 90)
+    self.assertAlmostEqual(angle, 90, delta=0.1)
     ff = ChemicalForceFields.MMFFGetMoleculeForceField(m, mp)
     self.assertTrue(ff)
     ff.MMFFAddAngleConstraint(1, 3, 6, True, -10.0, 10.0, 100.0)
@@ -270,7 +270,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     angle = rdMolTransforms.GetAngleDeg(conf, 1, 3, 6)
-    self.assertTrue(int(angle) == 100)
+    self.assertAlmostEqual(angle, 100, delta=0.1)
     ff = ChemicalForceFields.MMFFGetMoleculeForceField(m, mp)
     self.assertTrue(ff)
     ff.MMFFAddAngleConstraint(1, 3, 6, False, -10.0, 10.0, 100.0)
@@ -278,7 +278,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     angle = rdMolTransforms.GetAngleDeg(conf, 1, 3, 6)
-    self.assertEquals(int(angle), 10)  #(int(angle) == 10)
+    self.assertAlmostEqual(angle, 10, delta=0.1)
 
   def testMMFFTorsionConstraints(self):
     m = Chem.MolFromMolBlock(self.molB, True, False)
@@ -291,7 +291,7 @@ M  END"""
     r = ff.Minimize()
     self.assertTrue(r == 0)
     dihedral = rdMolTransforms.GetDihedralDeg(conf, 1, 3, 6, 8)
-    self.assertEquals(int(dihedral), 20)
+    self.assertAlmostEqual(dihedral, 20, delta=0.1)
     rdMolTransforms.SetDihedralDeg(conf, 1, 3, 6, 8, -30.0)
     ff = ChemicalForceFields.MMFFGetMoleculeForceField(m, mp)
     self.assertTrue(ff)
@@ -300,7 +300,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     dihedral = rdMolTransforms.GetDihedralDeg(conf, 1, 3, 6, 8)
-    self.assertTrue(int(dihedral) == -40)
+    self.assertAlmostEqual(dihedral, -40, delta=0.1)
     rdMolTransforms.SetDihedralDeg(conf, 1, 3, 6, 8, -10.0)
     ff = ChemicalForceFields.MMFFGetMoleculeForceField(m, mp)
     self.assertTrue(ff)
@@ -309,7 +309,7 @@ M  END"""
     self.assertTrue(r == 0)
     conf = m.GetConformer()
     dihedral = rdMolTransforms.GetDihedralDeg(conf, 1, 3, 6, 8)
-    self.assertTrue(int(dihedral) == -10)
+    self.assertAlmostEqual(dihedral, -10, delta=0.1)
 
   def testMMFFPositionConstraints(self):
     m = Chem.MolFromMolBlock(self.molB, True, False)
