@@ -21,6 +21,8 @@ namespace Abbreviations {
 
 namespace common_properties {
 const std::string numDummies = "_numDummies";
+const std::string origAtomMapping = "_origAtomMapping";
+const std::string origBondMapping = "_origBondMapping";
 }
 
 namespace Utils {
