@@ -164,6 +164,14 @@ TEST_CASE("applyMatches") {
       Abbreviations::applyMatches(*m, matches);
       CHECK(m->getNumAtoms() == 3);
       CHECK(MolToCXSmiles(*m) == "*C* |$CF3;;CO2H$|");
+      std::vector<unsigned int> atomMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
+      CHECK(atomMapping == std::vector<unsigned int>{1, 4, 5});
+      std::vector<unsigned int> bondMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{3, 4});
     }
   }
 }
@@ -184,6 +192,14 @@ Cy   *C1CCC(*)CC1  Cy)ABBREV");
       Abbreviations::applyMatches(*m, matches);
       CHECK(m->getNumAtoms() == 5);
       CHECK(MolToCXSmiles(*m) == "FC**Cl |$;;PEG3;Pent;$|");
+      std::vector<unsigned int> atomMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
+      CHECK(atomMapping == std::vector<unsigned int>{0, 1, 2, 11, 16});
+      std::vector<unsigned int> bondMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{0, 1, 10, 15});
     }
     {
       auto m = "COC1CCC(C)CC1"_smiles;
@@ -195,6 +211,14 @@ Cy   *C1CCC(*)CC1  Cy)ABBREV");
       Abbreviations::applyMatches(*m, matches);
       CHECK(m->getNumAtoms() == 4);
       CHECK(MolToCXSmiles(*m) == "C*OC |$;Cy;;$|");
+      std::vector<unsigned int> atomMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
+      CHECK(atomMapping == std::vector<unsigned int>{0, 1, 2, 6});
+      std::vector<unsigned int> bondMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{0, 1, 5});
     }
   }
 }
@@ -208,6 +232,14 @@ TEST_CASE("condense abbreviations") {
       double maxCoverage = 1.0;
       Abbreviations::condenseMolAbbreviations(*m, abbrevs, maxCoverage);
       CHECK(MolToCXSmiles(*m) == "*C* |$CF3;;CO2H$|");
+      std::vector<unsigned int> atomMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
+      CHECK(atomMapping == std::vector<unsigned int>{1, 4, 5});
+      std::vector<unsigned int> bondMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{3, 4});
     }
   }
 }
@@ -246,6 +278,14 @@ val *N[C@@H](C(C)C)C(=O)* val)ABBREV");
       Abbreviations::condenseMolAbbreviations(*m, linkers, maxCoverage);
       CHECK(m->getNumAtoms() == 5);
       CHECK(MolToCXSmiles(*m) == "FC**Cl |$;;PEG3;Hept;$|");
+      std::vector<unsigned int> atomMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
+      CHECK(atomMapping == std::vector<unsigned int>{0, 1, 2, 11, 18});
+      std::vector<unsigned int> bondMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{0, 1, 10, 17});
     }
     {
       auto m = "COC1CCC(C)CC1"_smiles;
@@ -254,6 +294,14 @@ val *N[C@@H](C(C)C)C(=O)* val)ABBREV");
       Abbreviations::condenseMolAbbreviations(*m, customLinkers, maxCoverage);
       CHECK(m->getNumAtoms() == 4);
       CHECK(MolToCXSmiles(*m) == "C*OC |$;Cy;;$|");
+      std::vector<unsigned int> atomMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
+      CHECK(atomMapping == std::vector<unsigned int>{0, 1, 2, 6});
+      std::vector<unsigned int> bondMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{0, 1, 5});
     }
   }
   SECTION("peptides") {
@@ -262,6 +310,16 @@ val *N[C@@H](C(C)C)C(=O)* val)ABBREV");
     double maxCoverage = 1.0;
     Abbreviations::condenseMolAbbreviations(*m, customLinkers, maxCoverage);
     CHECK(MolToCXSmiles(*m) == "NCC(=O)****O |$;;;;tyr;thr;lys;cys;$|");
+    std::vector<unsigned int> atomMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origAtomMapping,
+                              atomMapping));
+    CHECK(atomMapping ==
+          std::vector<unsigned int>{0, 1, 2, 3, 4, 16, 23, 32, 38});
+    std::vector<unsigned int> bondMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origBondMapping,
+                              bondMapping));
+    CHECK(bondMapping ==
+          std::vector<unsigned int>{0, 1, 2, 15, 38, 37, 31, 22});
   }
 }
 
@@ -277,9 +335,23 @@ TEST_CASE("abbreviations and linkers") {
       Abbreviations::condenseMolAbbreviations(*m, abbrevs, maxCoverage);
       CHECK(m->getNumAtoms() == 8);
       CHECK(MolToCXSmiles(*m) == "*C1CCC(C)CC1 |$OMe;;;;;;;$|");
+      std::vector<unsigned int> atomMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
+      CHECK(atomMapping == std::vector<unsigned int>{1, 2, 3, 4, 5, 6, 7, 8});
+      std::vector<unsigned int> bondMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{1, 2, 3, 4, 5, 6, 7, 8});
       Abbreviations::condenseMolAbbreviations(*m, linkers, maxCoverage);
       CHECK(m->getNumAtoms() == 3);
       CHECK(MolToCXSmiles(*m) == "**C |$OMe;Cy;$|");
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
+      CHECK(atomMapping == std::vector<unsigned int>{1, 2, 6});
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{1, 5});
     }
     {  // a more sensible order
       auto m = "COC1CCC(C)CC1"_smiles;
@@ -288,9 +360,23 @@ TEST_CASE("abbreviations and linkers") {
       Abbreviations::condenseMolAbbreviations(*m, linkers, maxCoverage);
       CHECK(m->getNumAtoms() == 4);
       CHECK(MolToCXSmiles(*m) == "C*OC |$;Cy;;$|");
+      std::vector<unsigned int> atomMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
+      CHECK(atomMapping == std::vector<unsigned int>{0, 1, 2, 6});
+      std::vector<unsigned int> bondMapping;
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{0, 1, 5});
       Abbreviations::condenseMolAbbreviations(*m, abbrevs, maxCoverage);
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origAtomMapping, atomMapping));
       CHECK(m->getNumAtoms() == 4);
       CHECK(MolToCXSmiles(*m) == "C*OC |$;Cy;;$|");
+      CHECK(atomMapping == std::vector<unsigned int>{0, 1, 2, 6});
+      CHECK(m->getPropIfPresent(
+          Abbreviations::common_properties::origBondMapping, bondMapping));
+      CHECK(bondMapping == std::vector<unsigned int>{0, 1, 5});
     }
   }
 }
@@ -402,6 +488,14 @@ M  END)CTAB"_ctab;
     CHECK(m->getNumAtoms() == 10);
     Abbreviations::condenseAbbreviationSubstanceGroups(*m);
     CHECK(m->getNumAtoms() == 5);
+    std::vector<unsigned int> atomMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origAtomMapping,
+                              atomMapping));
+    CHECK(atomMapping == std::vector<unsigned int>{0, 1, 4, 5, 6});
+    std::vector<unsigned int> bondMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origBondMapping,
+                              bondMapping));
+    CHECK(bondMapping == std::vector<unsigned int>{2, 3, 4, 5, 9});
     // remove the conformer before generating CXSMILES
     m->clearConformers();
     CHECK(MolToCXSmiles(*m) == "*C1CC1* |$CO2H;;;;CF3$|");
@@ -442,6 +536,15 @@ M  END
     Abbreviations::condenseAbbreviationSubstanceGroups(*m);
     CHECK(m->getNumAtoms() == 4);
     // remove the conformer before generating CXSMILES
+    Abbreviations::condenseAbbreviationSubstanceGroups(*m);
+    std::vector<unsigned int> atomMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origAtomMapping,
+                              atomMapping));
+    CHECK(atomMapping == std::vector<unsigned int>{0, 1, 2, 4});
+    std::vector<unsigned int> bondMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origBondMapping,
+                              bondMapping));
+    CHECK(bondMapping == std::vector<unsigned int>{0, 1, 2, 3});
     m->clearConformers();
     CHECK(MolToCXSmiles(*m) == "*C1CC1 |$CF3;;;$|");
   }
@@ -481,6 +584,14 @@ M  END)CTAB"_ctab;
     REQUIRE(m);
     CHECK(m->getNumAtoms() == 8);
     Abbreviations::condenseAbbreviationSubstanceGroups(*m);
+    std::vector<unsigned int> atomMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origAtomMapping,
+                              atomMapping));
+    CHECK(atomMapping == std::vector<unsigned int>{0, 1, 7});
+    std::vector<unsigned int> bondMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origBondMapping,
+                              bondMapping));
+    CHECK(bondMapping == std::vector<unsigned int>{0, 6});
     CHECK(m->getNumAtoms() == 3);
     // remove the conformer before generating CXSMILES
     m->clearConformers();
@@ -522,6 +633,14 @@ M  END
     REQUIRE(m);
     CHECK(m->getNumAtoms() == 8);
     Abbreviations::condenseAbbreviationSubstanceGroups(*m);
+    std::vector<unsigned int> atomMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origAtomMapping,
+                              atomMapping));
+    CHECK(atomMapping == std::vector<unsigned int>{0, 1, 7});
+    std::vector<unsigned int> bondMapping;
+    CHECK(m->getPropIfPresent(Abbreviations::common_properties::origBondMapping,
+                              bondMapping));
+    CHECK(bondMapping == std::vector<unsigned int>{0, 6});
     CHECK(m->getNumAtoms() == 3);
     // remove the conformer before generating CXSMILES
     m->clearConformers();
