@@ -35,8 +35,7 @@
 #include "RandomSample.h"
 #include "RandomSampleAllBBs.h"
 
-
-#ifdef RDK_USE_BOOST_SERIALIZATION  
+#ifdef RDK_USE_BOOST_SERIALIZATION
 #include <RDGeneral/BoostStartInclude.h>
 #include <boost/archive/text_oarchive.hpp>
 #include <boost/archive/text_iarchive.hpp>
@@ -63,19 +62,19 @@ namespace EnumerationStrategyPickler {
 
 void pickle(const boost::shared_ptr<EnumerationStrategyBase> &enumerator,
             std::ostream &ss) {
-#ifdef RDK_USE_BOOST_SERIALIZATION    
+#ifdef RDK_USE_BOOST_SERIALIZATION
   boost::archive::text_oarchive ar(ss);
   ar &enumerator;
 #else
   RDUNUSED_PARAM(enumerator);
   RDUNUSED_PARAM(ss);
   PRECONDITION(0, "BOOST SERIALIZATION NOT INSTALLED");
-#endif  
+#endif
 }
 
 void pickle(const boost::shared_ptr<EnumerationStrategyBase> &enumerator,
             std::string &s) {
-#ifdef RDK_USE_BOOST_SERIALIZATION    
+#ifdef RDK_USE_BOOST_SERIALIZATION
   std::stringstream ss;
   pickle(enumerator, ss);
   s = ss.str();
@@ -83,33 +82,31 @@ void pickle(const boost::shared_ptr<EnumerationStrategyBase> &enumerator,
   RDUNUSED_PARAM(enumerator);
   RDUNUSED_PARAM(s);
   PRECONDITION(0, "BOOST SERIALIZATION NOT INSTALLED");
-#endif  
+#endif
 }
 
 boost::shared_ptr<EnumerationStrategyBase> fromPickle(std::istream &pickle) {
-  boost::shared_ptr<EnumerationStrategyBase> enumerator;  
-#ifdef RDK_USE_BOOST_SERIALIZATION    
+  boost::shared_ptr<EnumerationStrategyBase> enumerator;
+#ifdef RDK_USE_BOOST_SERIALIZATION
   boost::archive::text_iarchive ar(pickle);
   ar &enumerator;
-  return enumerator;  
+  return enumerator;
 #else
   RDUNUSED_PARAM(pickle);
   PRECONDITION(0, "BOOST SERIALIZATION NOT INSTALLED");
 #endif
-
 }
 
 boost::shared_ptr<EnumerationStrategyBase> fromPickle(
     const std::string &pickle) {
-#ifdef RDK_USE_BOOST_SERIALIZATION    
+#ifdef RDK_USE_BOOST_SERIALIZATION
   std::stringstream ss(pickle);
   return fromPickle(ss);
 #else
   RDUNUSED_PARAM(pickle);
   PRECONDITION(0, "BOOST SERIALIZATION NOT INSTALLED");
   return boost::shared_ptr<EnumerationStrategyBase>();
-#endif  
-
-}
-}
+#endif
 }
+}  // namespace EnumerationStrategyPickler
+}  // namespace RDKit
