@@ -33,7 +33,6 @@
 
 #include <GraphMol/ChemReactions/Reaction.h>
 #include <GraphMol/Depictor/RDDepictor.h>
-#include <boost/foreach.hpp>
 
 namespace RDDepict {
 void compute2DCoordsForReaction(RDKit::ChemicalReaction &rxn, double spacing,
@@ -52,13 +51,11 @@ void compute2DCoordsForReaction(RDKit::ChemicalReaction &rxn, double spacing,
     compute2DCoords(**templIt, nullptr, canonOrient, true, nFlipsPerSample,
                     nSamples, sampleSeed, permuteDeg4Nodes);
     double minX = 100., maxX = -100.;
-    BOOST_FOREACH (RDGeom::Point3D &pt,
-                   (*templIt)->getConformer().getPositions()) {
+    for (auto &pt : (*templIt)->getConformer().getPositions()) {
       minX = std::min(pt.x, minX);
     }
     xOffset += minX;
-    BOOST_FOREACH (RDGeom::Point3D &pt,
-                   (*templIt)->getConformer().getPositions()) {
+    for (auto &pt : (*templIt)->getConformer().getPositions()) {
       pt.x += xOffset;
       maxX = std::max(pt.x, maxX);
     }
@@ -74,17 +71,15 @@ void compute2DCoordsForReaction(RDKit::ChemicalReaction &rxn, double spacing,
     compute2DCoords(**templIt, nullptr, canonOrient, true, nFlipsPerSample,
                     nSamples, sampleSeed, permuteDeg4Nodes);
     double minX = 100., maxX = -100.;
-    BOOST_FOREACH (RDGeom::Point3D &pt,
-                   (*templIt)->getConformer().getPositions()) {
+    for (auto &pt : (*templIt)->getConformer().getPositions()) {
       minX = std::min(pt.x, minX);
     }
     xOffset += minX;
-    BOOST_FOREACH (RDGeom::Point3D &pt,
-                   (*templIt)->getConformer().getPositions()) {
+    for (auto &pt : (*templIt)->getConformer().getPositions()) {
       pt.x += xOffset;
       maxX = std::max(pt.x, maxX);
     }
     xOffset = maxX + spacing;
   }
 }
-}  // end of namespace RDKit
+}  // namespace RDDepict
