@@ -43,7 +43,7 @@ class RDKIT_CHEMREACTIONS_EXPORT ReactionPickler {
   static const std::int32_t versionMajor;  //!< mark the pickle version
   static const std::int32_t versionMinor;  //!< mark the pickle version
   static const std::int32_t versionPatch;  //!< mark the pickle version
-  static const std::int32_t endianId;  //! mark the endian-ness of the pickle
+  static const std::int32_t endianId;  //!< mark the endian-ness of the pickle
 
   //! the pickle format is tagged using these tags:
   //! NOTE: if you add to this list, be sure to put new entries AT THE BOTTOM,
