@@ -14,7 +14,8 @@
 //       with the distribution.
 //     * Neither the name of Novartis Institutues for BioMedical Research Inc.
 //       nor the names of its contributors may be used to endorse or promote
-//       products derived from this software without specific prior written permission.
+//       products derived from this software without specific prior written
+//       permission.
 //
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 // "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -39,19 +40,18 @@
 
 namespace python = boost::python;
 
-
 namespace RDKit {
 
-template<class T>
+template <class T>
 std::vector<RDKit::MOL_SPTR_VECT> ConvertToVect(T bbs) {
   std::vector<RDKit::MOL_SPTR_VECT> vect;
   size_t num_bbs = python::extract<unsigned int>(bbs.attr("__len__")());
   vect.resize(num_bbs);
-  for(size_t i=0; i<num_bbs; ++i) {
+  for (size_t i = 0; i < num_bbs; ++i) {
     unsigned int len1 = python::extract<unsigned int>(bbs[i].attr("__len__")());
     RDKit::MOL_SPTR_VECT &reacts = vect[i];
     reacts.reserve(len1);
-    for(unsigned int j=0;j<len1;++j){
+    for (unsigned int j = 0; j < len1; ++j) {
       RDKit::ROMOL_SPTR mol = python::extract<RDKit::ROMOL_SPTR>(bbs[i][j]);
       if (mol) {
         reacts.push_back(mol);
@@ -63,7 +63,6 @@ std::vector<RDKit::MOL_SPTR_VECT> ConvertToVect(T bbs) {
   return vect;
 }
 
-
 bool EnumerateLibraryBase__nonzero__(RDKit::EnumerateLibraryBase *base) {
   return static_cast<bool>(*base);
 }
@@ -71,7 +70,7 @@ bool EnumerationStrategyBase__nonzero__(RDKit::EnumerationStrategyBase *base) {
   return static_cast<bool>(*base);
 }
 
-inline python::object pass_through(python::object const& o) { return o; }
+inline python::object pass_through(python::object const &o) { return o; }
 
 PyObject *EnumerateLibraryBase__next__(RDKit::EnumerateLibraryBase *base) {
   if (!static_cast<bool>(*base)) {
@@ -83,15 +82,15 @@ PyObject *EnumerateLibraryBase__next__(RDKit::EnumerateLibraryBase *base) {
     NOGIL gil;
     mols = base->next();
   }
-  PyObject *res=PyTuple_New(mols.size());
+  PyObject *res = PyTuple_New(mols.size());
 
-  for(unsigned int i=0;i<mols.size();++i){
-    PyObject *lTpl =PyTuple_New(mols[i].size());
-    for(unsigned int j=0;j<mols[i].size();++j){
-      PyTuple_SetItem(lTpl,j,
+  for (unsigned int i = 0; i < mols.size(); ++i) {
+    PyObject *lTpl = PyTuple_New(mols[i].size());
+    for (unsigned int j = 0; j < mols[i].size(); ++j) {
+      PyTuple_SetItem(lTpl, j,
                       python::converter::shared_ptr_to_python(mols[i][j]));
     }
-    PyTuple_SetItem(res,i,lTpl);
+    PyTuple_SetItem(res, i, lTpl);
   }
   return res;
 }
@@ -104,65 +103,48 @@ python::object EnumerateLibraryBase_Serialize(const EnumerateLibraryBase &en) {
 }
 
 class EnumerateLibraryWrap : public RDKit::EnumerateLibrary {
-public:
-  virtual ~EnumerateLibraryWrap() {}
+ public:
+  ~EnumerateLibraryWrap() override {}
   EnumerateLibraryWrap() : RDKit::EnumerateLibrary() {}
   EnumerateLibraryWrap(const RDKit::ChemicalReaction &rxn, python::list ob,
-                       const EnumerationParams & params = EnumerationParams()
-                       ) :
-      RDKit::EnumerateLibrary(rxn, ConvertToVect(ob), params) {
-  }
+                       const EnumerationParams &params = EnumerationParams())
+      : RDKit::EnumerateLibrary(rxn, ConvertToVect(ob), params) {}
 
   EnumerateLibraryWrap(const RDKit::ChemicalReaction &rxn, python::tuple ob,
-                       const EnumerationParams & params = EnumerationParams()
-                       ) :
-      RDKit::EnumerateLibrary(rxn, ConvertToVect(ob), params) {
-  }
+                       const EnumerationParams &params = EnumerationParams())
+      : RDKit::EnumerateLibrary(rxn, ConvertToVect(ob), params) {}
 
   EnumerateLibraryWrap(const RDKit::ChemicalReaction &rxn, python::list ob,
                        const EnumerationStrategyBase &enumerator,
-                       const EnumerationParams & params = EnumerationParams()
-                       ) :
-      RDKit::EnumerateLibrary(rxn, ConvertToVect(ob), enumerator, params) {
-  }
+                       const EnumerationParams &params = EnumerationParams())
+      : RDKit::EnumerateLibrary(rxn, ConvertToVect(ob), enumerator, params) {}
 
   EnumerateLibraryWrap(const RDKit::ChemicalReaction &rxn, python::tuple ob,
                        const EnumerationStrategyBase &enumerator,
-                       const EnumerationParams & params = EnumerationParams()) :
-      RDKit::EnumerateLibrary(rxn, ConvertToVect(ob), enumerator, params) {
-  }
-
+                       const EnumerationParams &params = EnumerationParams())
+      : RDKit::EnumerateLibrary(rxn, ConvertToVect(ob), enumerator, params) {}
 };
 
 namespace {
-  template< typename T >
-  inline
-  std::vector< T > to_std_vector( const python::object& iterable )
-  {
-    return std::vector< T >( python::stl_input_iterator< T >( iterable ),
-                             python::stl_input_iterator< T >( ) );
-  }
+template <typename T>
+inline std::vector<T> to_std_vector(const python::object &iterable) {
+  return std::vector<T>(python::stl_input_iterator<T>(iterable),
+                        python::stl_input_iterator<T>());
 }
+}  // namespace
 
-void ToBBS(EnumerationStrategyBase &rgroup, ChemicalReaction &rxn, python::list ob) {
+void ToBBS(EnumerationStrategyBase &rgroup, ChemicalReaction &rxn,
+           python::list ob) {
   rgroup.initialize(rxn, ConvertToVect(ob));
 }
 
-typedef std::vector<boost::uint64_t> VectSizeT;
-typedef std::vector<std::vector<std::string> > VectStringVect;
-typedef std::vector<MOL_SPTR_VECT > VectMolVect;
-
 struct enumeration_wrapper {
   static void wrap() {
     std::string docString;
-    python::class_<VectStringVect>("VectorOfStringVectors")
-      .def(python::vector_indexing_suite<VectStringVect, false>() );
 
-    python::class_<VectSizeT>("VectSizeT")
-      .def(python::vector_indexing_suite<VectSizeT, false>() );
-
-    python::class_<VectMolVect>("VectMolVect")
-      .def(python::vector_indexing_suite<VectMolVect, false>() );
+    RegisterVectorConverter<std::vector<std::string>>("VectorOfStringVectors");
+    RegisterVectorConverter<boost::uint64_t>("VectSizeT");
+    RegisterVectorConverter<MOL_SPTR_VECT>("VectMolVect");
 
     python::class_<RDKit::EnumerateLibraryBase, RDKit::EnumerateLibraryBase *,
                    RDKit::EnumerateLibraryBase &, boost::noncopyable>(
@@ -178,34 +160,40 @@ struct enumeration_wrapper {
              "Return the next smiles string from the enumeration.")
         .def("Serialize", &EnumerateLibraryBase_Serialize,
              "Serialize the library to a binary string.\n"
-             "Note that the position in the library is serialized as well.  Care should\n"
-             "be taken when serializing.  See GetState/SetState for position manipulation.")
+             "Note that the position in the library is serialized as well.  "
+             "Care should\n"
+             "be taken when serializing.  See GetState/SetState for position "
+             "manipulation.")
         .def("InitFromString", &RDKit::EnumerateLibraryBase::initFromString,
              python::arg("data"),
              "Inititialize the library from a binary string")
-        .def("GetPosition", &RDKit::EnumerateLibraryBase::getPosition,
-             "Returns the current enumeration position into the reagent vectors",
-             python::return_internal_reference<
-             1, python::with_custodian_and_ward_postcall<0, 1> >())
-        .def("GetState", &RDKit::EnumerateLibraryBase::getState,
-             "Returns the current enumeration state (position) of the library.\n"
-             "This position can be used to restart the library from a known position")
+        .def(
+            "GetPosition", &RDKit::EnumerateLibraryBase::getPosition,
+            "Returns the current enumeration position into the reagent vectors",
+            python::return_internal_reference<
+                1, python::with_custodian_and_ward_postcall<0, 1>>())
+        .def(
+            "GetState", &RDKit::EnumerateLibraryBase::getState,
+            "Returns the current enumeration state (position) of the library.\n"
+            "This position can be used to restart the library from a known "
+            "position")
         .def("SetState", &RDKit::EnumerateLibraryBase::setState,
              python::arg("state"),
              "Sets the enumeration state (position) of the library.")
         .def("ResetState", &RDKit::EnumerateLibraryBase::resetState,
-             "Returns the current enumeration state (position) of the library to the start.")
+             "Returns the current enumeration state (position) of the library "
+             "to the start.")
         .def("GetReaction", &RDKit::EnumerateLibraryBase::getReaction,
              "Returns the chemical reaction for this library",
              python::return_internal_reference<
-             1, python::with_custodian_and_ward_postcall<0, 1> >())
+                 1, python::with_custodian_and_ward_postcall<0, 1>>())
         .def("GetEnumerator", &RDKit::EnumerateLibraryBase::getEnumerator,
              "Returns the enumation strategy for the current library",
              python::return_internal_reference<
-             1, python::with_custodian_and_ward_postcall<0, 1> >());
+                 1, python::with_custodian_and_ward_postcall<0, 1>>());
 
-    docString = \
-"EnumerationParams\n\
+    docString =
+        "EnumerationParams\n\
 Controls some aspects of how the enumeration is performed.\n\
 Options:\n\
   reagentMaxMatchCount [ default Infinite ]\n\
@@ -217,18 +205,16 @@ Options:\n\
      does not pass sanitization, then none of the products will.\n\
 ";
 
-    python::class_<RDKit::EnumerationParams,
-                   RDKit::EnumerationParams*,
-                   RDKit::EnumerationParams&>("EnumerationParams",
-                                              docString.c_str(),
-                                              python::init<>())
+    python::class_<RDKit::EnumerationParams, RDKit::EnumerationParams *,
+                   RDKit::EnumerationParams &>(
+        "EnumerationParams", docString.c_str(), python::init<>())
         .def_readwrite("reagentMaxMatchCount",
-                    &RDKit::EnumerationParams::reagentMaxMatchCount)
+                       &RDKit::EnumerationParams::reagentMaxMatchCount)
         .def_readwrite("sanePartialProducts",
-                    &RDKit::EnumerationParams::sanePartialProducts);
+                       &RDKit::EnumerationParams::sanePartialProducts);
 
-    docString = \
-"EnumerateLibrary\n\
+    docString =
+        "EnumerateLibrary\n\
 This class allows easy enumeration of reactions.  Simply provide a reaction\n\
 and a set of reagents and you are off the races.\n\
 \n\
@@ -295,40 +281,30 @@ for result in itertools.islice(libary2, 1000):\n\
     # do something with the next 1000 samples\n\
 ";
     python::class_<EnumerateLibraryWrap, boost::noncopyable,
-                   python::bases<RDKit::EnumerateLibraryBase> >(
-                       "EnumerateLibrary", docString.c_str(),
-                       python::init<>())
-      .def(python::init<
-           const RDKit::ChemicalReaction &,
-           python::list,
-           python::optional<const RDKit::EnumerationParams&>
-           >(python::args("rxn", "reagents", "params")))
-      .def(python::init<
-           const RDKit::ChemicalReaction &,
-           python::tuple,
-           python::optional<const RDKit::EnumerationParams&>
-           >(python::args("rxn", "reagents", "params")))
+                   python::bases<RDKit::EnumerateLibraryBase>>(
+        "EnumerateLibrary", docString.c_str(), python::init<>())
+        .def(python::init<const RDKit::ChemicalReaction &, python::list,
+                          python::optional<const RDKit::EnumerationParams &>>(
+            python::args("rxn", "reagents", "params")))
+        .def(python::init<const RDKit::ChemicalReaction &, python::tuple,
+                          python::optional<const RDKit::EnumerationParams &>>(
+            python::args("rxn", "reagents", "params")))
 
-      .def(python::init<const RDKit::ChemicalReaction &,
-           python::list,
-           const RDKit::EnumerationStrategyBase &,
-           python::optional<const RDKit::EnumerationParams&>
-           >(python::args(
-               "rxn", "reagents", "enumerator", "params")))
-      .def(python::init<const RDKit::ChemicalReaction &,
-           python::tuple,
-           const RDKit::EnumerationStrategyBase &,
-           python::optional<const RDKit::EnumerationParams&>
-           >(python::args(
-               "rxn", "reagents", "enumerator", "params")))
+        .def(python::init<const RDKit::ChemicalReaction &, python::list,
+                          const RDKit::EnumerationStrategyBase &,
+                          python::optional<const RDKit::EnumerationParams &>>(
+            python::args("rxn", "reagents", "enumerator", "params")))
+        .def(python::init<const RDKit::ChemicalReaction &, python::tuple,
+                          const RDKit::EnumerationStrategyBase &,
+                          python::optional<const RDKit::EnumerationParams &>>(
+            python::args("rxn", "reagents", "enumerator", "params")))
 
-      .def("GetReagents", &RDKit::EnumerateLibrary::getReagents,
-           "Return the reagents used in this library.",
-           python::return_internal_reference<
-           1, python::with_custodian_and_ward_postcall<0, 1> >())
-      ;
+        .def("GetReagents", &RDKit::EnumerateLibrary::getReagents,
+             "Return the reagents used in this library.",
+             python::return_internal_reference<
+                 1, python::with_custodian_and_ward_postcall<0, 1>>());
 
-    //iterator_wrappers<EnumerateLibrary>().wrap("EnumerateLibraryIterator");
+    // iterator_wrappers<EnumerateLibrary>().wrap("EnumerateLibraryIterator");
 
     python::class_<RDKit::EnumerationStrategyBase,
                    RDKit::EnumerationStrategyBase *,
@@ -338,8 +314,7 @@ for result in itertools.islice(libary2, 1000):\n\
         .def("__bool__", &EnumerationStrategyBase__nonzero__)
         .def("Type", &EnumerationStrategyBase::type,
              "Returns the enumeration strategy type as a string.")
-        .def("Skip", &EnumerationStrategyBase::skip,
-             python::args("skipCount"),
+        .def("Skip", &EnumerationStrategyBase::skip, python::args("skipCount"),
              "Skip the next Nth results. note: this may be an expensive "
              "operation\n"
              "depending on the enumeration strategy used. It is recommended to "
@@ -348,63 +323,63 @@ for result in itertools.islice(libary2, 1000):\n\
         .def("__copy__", python::pure_virtual(&EnumerationStrategyBase::copy),
              python::return_value_policy<python::manage_new_object>())
         .def("GetNumPermutations", &EnumerationStrategyBase::getNumPermutations,
-             "Returns the total number of results for this enumeration strategy.\n"
+             "Returns the total number of results for this enumeration "
+             "strategy.\n"
              "Note that some strategies are effectively infinite.")
         .def("GetPosition", &EnumerationStrategyBase::getPosition,
              "Return the current indices into the arrays of reagents",
              python::return_internal_reference<
-                 1, python::with_custodian_and_ward_postcall<0, 1> >())
+                 1, python::with_custodian_and_ward_postcall<0, 1>>())
         .def("next", python::pure_virtual(&EnumerationStrategyBase::next),
              "Return the next indices into the arrays of reagents",
              python::return_internal_reference<
-                 1, python::with_custodian_and_ward_postcall<0, 1> >())
+                 1, python::with_custodian_and_ward_postcall<0, 1>>())
         .def("__next__", python::pure_virtual(&EnumerationStrategyBase::next),
              "Return the next indices into the arrays of reagents",
              python::return_internal_reference<
-                 1, python::with_custodian_and_ward_postcall<0, 1> >())
+                 1, python::with_custodian_and_ward_postcall<0, 1>>())
         .def("Initialize", ToBBS);
 
-    docString = "CartesianProductStrategy produces a standard walk through all possible\n"
+    docString =
+        "CartesianProductStrategy produces a standard walk through all "
+        "possible\n"
         "reagent combinations:\n"
         "\n"
         "(0,0,0), (1,0,0), (2,0,0) ...\n";
 
     python::class_<RDKit::CartesianProductStrategy,
-                   RDKit::CartesianProductStrategy*,
-                   RDKit::CartesianProductStrategy&,
-                   python::bases<EnumerationStrategyBase> >("CartesianProductStrategy",
-                                                            docString.c_str(),
-                                                            python::init<>())
+                   RDKit::CartesianProductStrategy *,
+                   RDKit::CartesianProductStrategy &,
+                   python::bases<EnumerationStrategyBase>>(
+        "CartesianProductStrategy", docString.c_str(), python::init<>())
         .def("__copy__", &RDKit::CartesianProductStrategy::copy,
-             python::return_value_policy<python::manage_new_object>())
-      ;
+             python::return_value_policy<python::manage_new_object>());
 
-    docString = "RandomSampleStrategy simply randomly samples from the reagent sets.\n"
+    docString =
+        "RandomSampleStrategy simply randomly samples from the reagent sets.\n"
         "Note that this strategy never halts and can produce duplicates.";
-    python::class_<RDKit::RandomSampleStrategy,
-                   RDKit::RandomSampleStrategy*,
-                   RDKit::RandomSampleStrategy&,
-                   python::bases<EnumerationStrategyBase> >("RandomSampleStrategy",
-                                                            docString.c_str(),
-                                                            python::init<>())
+    python::class_<RDKit::RandomSampleStrategy, RDKit::RandomSampleStrategy *,
+                   RDKit::RandomSampleStrategy &,
+                   python::bases<EnumerationStrategyBase>>(
+        "RandomSampleStrategy", docString.c_str(), python::init<>())
         .def("__copy__", &RDKit::RandomSampleStrategy::copy,
-             python::return_value_policy<python::manage_new_object>())
-      ;
+             python::return_value_policy<python::manage_new_object>());
 
-    docString = "RandomSampleAllBBsStrategy randomly samples from the reagent sets\n"
-        "with the constraint that all building blocks are samples as early as possible.\n"
+    docString =
+        "RandomSampleAllBBsStrategy randomly samples from the reagent sets\n"
+        "with the constraint that all building blocks are samples as early as "
+        "possible.\n"
         "Note that this strategy never halts and can produce duplicates.";
     python::class_<RDKit::RandomSampleAllBBsStrategy,
-                   RDKit::RandomSampleAllBBsStrategy*,
-                   RDKit::RandomSampleAllBBsStrategy&,
-                   python::bases<EnumerationStrategyBase> >("RandomSampleAllBBsStrategy",
-                                                            docString.c_str(),
-                                                            python::init<>())
+                   RDKit::RandomSampleAllBBsStrategy *,
+                   RDKit::RandomSampleAllBBsStrategy &,
+                   python::bases<EnumerationStrategyBase>>(
+        "RandomSampleAllBBsStrategy", docString.c_str(), python::init<>())
         .def("__copy__", &RDKit::RandomSampleAllBBsStrategy::copy,
-             python::return_value_policy<python::manage_new_object>())
-      ;
+             python::return_value_policy<python::manage_new_object>());
 
-    docString = "Randomly sample Pairs evenly from a collection of building blocks\n"
+    docString =
+        "Randomly sample Pairs evenly from a collection of building blocks\n"
         "This is a good strategy for choosing a relatively small selection\n"
         "of building blocks from a larger set.  As the amount of work needed\n"
         "to retrieve the next evenly sample building block grows with the\n"
@@ -413,26 +388,22 @@ for result in itertools.islice(libary2, 1000):\n\
         "See EnumerationStrategyBase for more details.\n";
 
     python::class_<RDKit::EvenSamplePairsStrategy,
-                   RDKit::EvenSamplePairsStrategy*,
-                   RDKit::EvenSamplePairsStrategy&,
-                   python::bases<EnumerationStrategyBase> >("EvenSamplePairsStrategy",
-                                                            docString.c_str(),
-                                                            python::init<>())
+                   RDKit::EvenSamplePairsStrategy *,
+                   RDKit::EvenSamplePairsStrategy &,
+                   python::bases<EnumerationStrategyBase>>(
+        "EvenSamplePairsStrategy", docString.c_str(), python::init<>())
         .def("__copy__", &RDKit::EvenSamplePairsStrategy::copy,
              python::return_value_policy<python::manage_new_object>())
         .def("Stats", &RDKit::EvenSamplePairsStrategy::stats,
-             "Return the statistics log of the pairs used in the current enumeration.")
-      ;
+             "Return the statistics log of the pairs used in the current "
+             "enumeration.");
 
     python::def("EnumerateLibraryCanSerialize", EnumerateLibraryCanSerialize,
                 "Returns True if the EnumerateLibrary is serializable "
                 "(requires boost serialization");
-
   }
 };
 
-}// end of namespace
+}  // namespace RDKit
 
-void wrap_enumeration() {
-  RDKit::enumeration_wrapper::wrap();
-}
+void wrap_enumeration() { RDKit::enumeration_wrapper::wrap(); }
