@@ -246,6 +246,21 @@ TEST_CASE("molzip", "[]") {
     }
   }
 
+  SECTION("use atom property as label") {
+    auto a = "[C@H]([*])(F)([*])"_smiles;
+    auto b = "[*]N.[*]I"_smiles;
+    a->getAtomWithIdx(1)->setProp<unsigned int>("foo", 1);
+    a->getAtomWithIdx(3)->setProp<unsigned int>("foo", 2);
+    b->getAtomWithIdx(0)->setProp<unsigned int>("foo", 1);
+    b->getAtomWithIdx(2)->setProp<unsigned int>("foo", 2);
+    MolzipParams p;
+    p.label = MolzipLabel::AtomProperty;
+    p.atomProperty = "foo";
+    auto mol = molzip(*a, *b, p);
+    // chirality is "lost" here because [C@H]([*])(F)([*]) is considered achiral
+    CHECK(MolToSmiles(*mol) == "NC(F)I");
+  }
+  
   SECTION("test bond stereo") {
     auto a = "F/C=C/[*:1]"_smiles;
     auto b = "[*:1]F"_smiles;
@@ -324,7 +339,7 @@ TEST_CASE("molzip", "[]") {
 
         if (std::count(smiles.begin(), smiles.end(), '/') != 2) {
           continue;  // we removed bond stereo in fragment to bonds!
-        }
+	}
         MolzipParams p;
         p.label = MolzipLabel::FragmentOnBonds;
         CHECK(MolToSmiles(*molzip(*resa, p)) == MolToSmiles(*m));
@@ -337,7 +352,7 @@ TEST_CASE("molzip", "[]") {
 
         if (std::count(smiles.begin(), smiles.end(), '/') != 2) {
           continue;  // we removed bond stereo in fragment to bonds!
-        }
+	}
         for (auto *atom : res->atoms()) {
           if (atom->getIsotope()) {
             atom->setAtomMapNum(atom->getIsotope());
@@ -383,6 +398,66 @@ TEST_CASE("molzip", "[]") {
     auto b = "[*:1]-N=C"_smiles;
     auto mol = molzip(*a, *b, p);
   }
+    
+  {
+      // check atom property zipping
+      auto a = "C=C*.O/C=N/*"_smiles;
+      a->getAtomWithIdx(2)->setProp<unsigned int>("fuse", 1);
+      a->getAtomWithIdx(6)->setProp<unsigned int>("fuse", 1);
+      MolzipParams p;
+      p.atomProperty = "fuse";
+      p.label = MolzipLabel::AtomProperty;
+      auto mol = molzip(*a, p);
+      CHECK(MolToSmiles(*mol) == "C=C/N=C/O");
+  }
+
+  SECTION("MolZip saves bonddir") {
+      { // a-* b<*
+         auto a = "CC[*:1]"_smiles;
+         auto b = "N[*:1]"_smiles;
+         b->getBondWithIdx(0)->setBondDir(Bond::BondDir::BEGINWEDGE);
+         auto mol = molzip(*a, *b);
+         CHECK(MolToSmiles(*mol) == "CCN");
+         CHECK(mol->getBondWithIdx(1)->getBondDir() == Bond::BondDir::BEGINWEDGE);
+         CHECK(mol->getBondWithIdx(1)->getBeginAtom()->getIdx() == 2);
+       }
+       { // a>* b-*
+         auto a = "[*:1]CC"_smiles;
+         auto b = "N[*:1]"_smiles;
+         a->getBondWithIdx(0)->setBondDir(Bond::BondDir::BEGINWEDGE);
+         auto mol = molzip(*a, *b);
+         CHECK(MolToSmiles(*mol) == "CCN");
+         CHECK(mol->getBondWithIdx(1)->getBondDir() == Bond::BondDir::BEGINWEDGE);
+         CHECK(mol->getBondWithIdx(1)->getBeginAtom()->getIdx() == 2);
+       }
+       { // a<* b-*
+         auto a = "CC[*:1]"_smiles;
+         auto b = "N[*:1]"_smiles;
+         a->getBondWithIdx(1)->setBondDir(Bond::BondDir::BEGINWEDGE);
+         auto mol = molzip(*a, *b);
+         CHECK(MolToSmiles(*mol) == "CCN");
+         CHECK(mol->getBondWithIdx(1)->getBondDir() == Bond::BondDir::BEGINWEDGE);
+         CHECK(mol->getBondWithIdx(1)->getBeginAtom()->getIdx() == 1);
+       }
+       { // a>* b-*
+         auto a = "[*:1]CC"_smiles;
+         auto b = "N[*:1]"_smiles;
+         a->getBondWithIdx(0)->setBondDir(Bond::BondDir::BEGINWEDGE);
+         auto mol = molzip(*a, *b);
+         CHECK(MolToSmiles(*mol) == "CCN");
+         CHECK(mol->getBondWithIdx(1)->getBondDir() == Bond::BondDir::BEGINWEDGE);
+         CHECK(mol->getBondWithIdx(1)->getBeginAtom()->getIdx() == 2);
+       }
+       { // a-* b<*
+         auto a = "CC[*:1]"_smiles;
+         auto b = "[*:1]N"_smiles;
+         b->getBondWithIdx(0)->setBondDir(Bond::BondDir::BEGINWEDGE);
+         auto mol = molzip(*a, *b);
+         CHECK(MolToSmiles(*mol) == "CCN");
+         CHECK(mol->getBondWithIdx(1)->getBondDir() == Bond::BondDir::BEGINWEDGE);
+         CHECK(mol->getBondWithIdx(1)->getBeginAtom()->getIdx() == 1);
+       }
+   }
 }
 
 TEST_CASE(
@@ -419,3 +494,22 @@ TEST_CASE(
     CHECK(mb.find("CFG=2") != std::string::npos);
   }
 }
+
+TEST_CASE(
+    "Github5334: ReplaceCore should set stereo on ring bonds when it breaks "
+    "rings") {
+  SECTION("segfault") {
+    auto a = "C([*:1])[*:2].[C@@H](Cl)([1*:1])[2*:2]"_smiles;
+    bool caught = false;
+    try {
+        auto mol = molzip(*a);
+        CHECK(false);
+    } catch (Invar::Invariant &e) {
+        CHECK(e.toUserString().find(
+                  "molzip: zipped Bond already exists, perhaps labels are duplicated") !=
+              std::string::npos);
+        caught = true;
+    }
+    CHECK(caught);
+  }
+}
