@@ -62,7 +62,23 @@ class RDKIT_GRAPHMOL_EXPORT Conformer : public RDProps {
   //! Copy Constructor: initialize from a second conformation.
   Conformer(const Conformer &other);
   Conformer &operator=(const Conformer &other);
-
+  Conformer(Conformer &&o) noexcept
+      : RDProps(std::move(o)),
+        df_is3D(std::move(o.df_is3D)),
+        d_id(std::move(o.d_id)),
+        dp_mol(std::move(o.dp_mol)),
+        d_positions(std::move(o.d_positions)){};
+  Conformer &operator=(Conformer &&o) noexcept {
+    if (this == &o) {
+      return *this;
+    }
+    RDProps::operator=(std::move(o));
+    df_is3D = std::move(o.df_is3D);
+    d_id = std::move(o.d_id);
+    dp_mol = std::move(o.dp_mol);
+    d_positions = std::move(o.d_positions);
+    return *this;
+  }
   //! Destructor
   ~Conformer() = default;
 
@@ -155,7 +171,9 @@ typedef boost::shared_ptr<Conformer> CONFORMER_SPTR;
 */
 inline bool hasNonZeroZCoords(const Conformer &conf) {
   for (auto p : conf.getPositions()) {
-    if (p.z != 0.0) return true;
+    if (p.z != 0.0) {
+      return true;
+    }
   }
   return false;
 }
