@@ -18,6 +18,7 @@
 #include <RDGeneral/types.h>
 #include <GraphMol/ROMol.h>
 #include <GraphMol/Conformer.h>
+#include <GraphMol/Chirality.h>
 #include <cmath>
 #include <GraphMol/MolOps.h>
 #include <GraphMol/Rings.h>
@@ -37,6 +38,209 @@ namespace RDDepict {
 bool preferCoordGen = false;
 
 namespace DepictorLocal {
+
+constexpr auto ISQRT2 = 0.707107;
+constexpr auto SQRT3_2 = 0.866025;
+
+std::vector<const RDKit::Atom *> getRankedAtomNeighbors(
+    const RDKit::ROMol &mol, const RDKit::Atom *atom,
+    const std::vector<int> &atomRanks) {
+  std::vector<const RDKit::Atom *> nbrs;
+  for (auto nbr : mol.atomNeighbors(atom)) {
+    nbrs.push_back(nbr);
+  }
+  std::sort(nbrs.begin(), nbrs.end(),
+            [&atomRanks](const auto e1, const auto e2) {
+              return atomRanks[e1->getIdx()] < atomRanks[e2->getIdx()];
+            });
+  return nbrs;
+}
+
+void embedSquarePlanar(const RDKit::ROMol &mol, const RDKit::Atom *atom,
+                       std::list<EmbeddedFrag> &efrags,
+                       const std::vector<int> &atomRanks) {
+  static const RDGeom::Point2D idealPoints[] = {
+      RDGeom::Point2D(ISQRT2 * BOND_LEN, ISQRT2 * BOND_LEN),
+      RDGeom::Point2D(ISQRT2 * BOND_LEN, -ISQRT2 * BOND_LEN),
+      RDGeom::Point2D(-ISQRT2 * BOND_LEN, -ISQRT2 * BOND_LEN),
+      RDGeom::Point2D(-ISQRT2 * BOND_LEN, ISQRT2 * BOND_LEN),
+  };
+  PRECONDITION(atom, "bad atom");
+  if (atom->getChiralTag() != RDKit::Atom::ChiralType::CHI_SQUAREPLANAR) {
+    return;
+  }
+  auto nbrs = getRankedAtomNeighbors(mol, atom, atomRanks);
+  RDGeom::INT_POINT2D_MAP coordMap;
+  coordMap[atom->getIdx()] = RDGeom::Point2D(0., 0.);
+  coordMap[nbrs[0]->getIdx()] = idealPoints[0];
+  bool q2Full = false;
+  for (const auto nbr : nbrs) {
+    if (nbr == nbrs.front()) {
+      continue;
+    }
+    auto angle =
+        RDKit::Chirality::getIdealAngleBetweenLigands(atom, nbrs.front(), nbr);
+    if (fabs(angle - 180) < 0.1) {
+      coordMap[nbr->getIdx()] = idealPoints[2];
+    } else {
+      if (!q2Full) {
+        coordMap[nbr->getIdx()] = idealPoints[1];
+        q2Full = true;
+      } else {
+        coordMap[nbr->getIdx()] = idealPoints[3];
+      }
+    }
+  }
+  efrags.emplace_back(&mol, coordMap);
+}
+
+void embedTBP(const RDKit::ROMol &mol, const RDKit::Atom *atom,
+              std::list<EmbeddedFrag> &efrags,
+              const std::vector<int> &atomRanks) {
+  static const RDGeom::Point2D idealPoints[] = {
+      RDGeom::Point2D(0, BOND_LEN),                        // axial
+      RDGeom::Point2D(0, -BOND_LEN),                       // axial
+      RDGeom::Point2D(-SQRT3_2 * BOND_LEN, BOND_LEN / 2),  // equatorial
+      RDGeom::Point2D(-SQRT3_2 * BOND_LEN,
+                      -BOND_LEN / 2),  // equatorial
+      RDGeom::Point2D(BOND_LEN, 0),    // equatorial
+  };
+  PRECONDITION(atom, "bad atom");
+  if (atom->getChiralTag() !=
+      RDKit::Atom::ChiralType::CHI_TRIGONALBIPYRAMIDAL) {
+    return;
+  }
+  auto nbrs = getRankedAtomNeighbors(mol, atom, atomRanks);
+  RDGeom::INT_POINT2D_MAP coordMap;
+  coordMap[atom->getIdx()] = RDGeom::Point2D(0., 0.);
+  const RDKit::Atom *axial1 =
+      RDKit::Chirality::getTrigonalBipyramidalAxialAtom(atom);
+  const RDKit::Atom *axial2 =
+      RDKit::Chirality::getTrigonalBipyramidalAxialAtom(atom, -1);
+  if (axial1) {
+    coordMap[axial1->getIdx()] = idealPoints[0];
+  }
+  if (axial2) {
+    coordMap[axial2->getIdx()] = idealPoints[1];
+  }
+  unsigned whichEq = 2;
+  for (const auto nbr : nbrs) {
+    if (nbr != axial1 && nbr != axial2) {
+      coordMap[nbr->getIdx()] = idealPoints[whichEq++];
+    }
+  }
+  efrags.emplace_back(&mol, coordMap);
+}
+
+void embedOctahedral(const RDKit::ROMol &mol, const RDKit::Atom *atom,
+                     std::list<EmbeddedFrag> &efrags,
+                     const std::vector<int> &atomRanks) {
+  static const RDGeom::Point2D idealPoints[] = {
+      RDGeom::Point2D(0, BOND_LEN),                         // axial
+      RDGeom::Point2D(0, -BOND_LEN),                        // axial
+      RDGeom::Point2D(SQRT3_2 * BOND_LEN, BOND_LEN / 2),    // equatorial
+      RDGeom::Point2D(SQRT3_2 * BOND_LEN, -BOND_LEN / 2),   // equatorial
+      RDGeom::Point2D(-SQRT3_2 * BOND_LEN, -BOND_LEN / 2),  // equatorial
+      RDGeom::Point2D(-SQRT3_2 * BOND_LEN, BOND_LEN / 2),   // equatorial
+  };
+  PRECONDITION(atom, "bad atom");
+  if (atom->getChiralTag() != RDKit::Atom::ChiralType::CHI_OCTAHEDRAL) {
+    return;
+  }
+  auto nbrs = getRankedAtomNeighbors(mol, atom, atomRanks);
+  RDGeom::INT_POINT2D_MAP coordMap;
+  coordMap[atom->getIdx()] = RDGeom::Point2D(0., 0.);
+  const RDKit::Atom *axial1 = nullptr;
+  const RDKit::Atom *axial2 = nullptr;
+  for (auto i = 0u; i < nbrs.size(); ++i) {
+    bool all90 = true;
+    for (auto j = i + 1; j < nbrs.size(); ++j) {
+      if (fabs(RDKit::Chirality::getIdealAngleBetweenLigands(atom, nbrs[i],
+                                                             nbrs[j]) -
+               180) < 0.1) {
+        axial1 = nbrs[i];
+        axial2 = nbrs[j];
+        all90 = false;
+        break;
+      } else if (fabs(RDKit::Chirality::getIdealAngleBetweenLigands(
+                          atom, nbrs[i], nbrs[j]) -
+                      90) > 0.1) {
+        all90 = false;
+      }
+    }
+    if (all90) {
+      axial1 = nbrs[i];
+    }
+    if (axial1) {
+      break;
+    }
+  }
+  if (axial1) {
+    coordMap[axial1->getIdx()] = idealPoints[0];
+  }
+  if (axial2) {
+    coordMap[axial2->getIdx()] = idealPoints[1];
+  }
+  const RDKit::Atom *refEqAtom1 = nullptr;
+  const RDKit::Atom *refEqAtom2 = nullptr;
+  for (const auto nbr : nbrs) {
+    if (nbr != axial1 && nbr != axial2) {
+      if (!refEqAtom1) {
+        refEqAtom1 = nbr;
+        coordMap[nbr->getIdx()] = idealPoints[2];
+        refEqAtom2 = RDKit::Chirality::getChiralAcrossAtom(atom, nbr);
+        if (refEqAtom2) {
+          coordMap[refEqAtom2->getIdx()] = idealPoints[4];
+        }
+      } else {
+        if (nbr == refEqAtom2 || nbr == refEqAtom1) {
+          continue;
+        }
+        coordMap[nbr->getIdx()] = idealPoints[3];
+        const auto acrossAtom2 =
+            RDKit::Chirality::getChiralAcrossAtom(atom, nbr);
+        if (acrossAtom2) {
+          coordMap[acrossAtom2->getIdx()] = idealPoints[5];
+        }
+        break;
+      }
+    }
+  }
+  efrags.emplace_back(&mol, coordMap);
+}
+
+void embedNontetrahedralStereo(const RDKit::ROMol &mol,
+                               std::list<EmbeddedFrag> &efrags,
+                               const std::vector<int> &atomRanks) {
+  boost::dynamic_bitset<> consider(mol.getNumAtoms());
+  for (const auto atm : mol.atoms()) {
+    if (RDKit::Chirality::hasNonTetrahedralStereo(atm)) {
+      consider[atm->getIdx()] = 1;
+    }
+  }
+  if (consider.empty()) {
+    return;
+  }
+  for (const auto atm : mol.atoms()) {
+    if (!consider[atm->getIdx()]) {
+      continue;
+    }
+    switch (atm->getChiralTag()) {
+      case RDKit::Atom::ChiralType::CHI_SQUAREPLANAR:
+        embedSquarePlanar(mol, atm, efrags, atomRanks);
+        break;
+      case RDKit::Atom::ChiralType::CHI_TRIGONALBIPYRAMIDAL:
+        embedTBP(mol, atm, efrags, atomRanks);
+        break;
+      case RDKit::Atom::ChiralType::CHI_OCTAHEDRAL:
+        embedOctahedral(mol, atm, efrags, atomRanks);
+        break;
+      default:
+        break;
+    }
+  }
+}
+
 // arings: indices of atoms in rings
 void embedFusedSystems(const RDKit::ROMol &mol,
                        const RDKit::VECT_INT_VECT &arings,
@@ -179,12 +383,17 @@ void _shiftCoords(std::list<EmbeddedFrag> &efrags) {
 double copySign(double to, double from, double tol) {
   return (from < -tol ? -fabs(to) : fabs(to));
 }
+
+struct ThetaBin {
+  double d_thetaAvg = 0.0;
+  std::vector<double> thetaValues;
+};
 }  // namespace DepictorLocal
 
 void computeInitialCoords(RDKit::ROMol &mol,
                           const RDGeom::INT_POINT2D_MAP *coordMap,
                           std::list<EmbeddedFrag> &efrags) {
-  RDKit::INT_VECT atomRanks;
+  std::vector<int> atomRanks;
   atomRanks.resize(mol.getNumAtoms());
   for (auto i = 0u; i < mol.getNumAtoms(); ++i) {
     atomRanks[i] = getAtomDepictRank(mol.getAtomWithIdx(i));
@@ -213,6 +422,10 @@ void computeInitialCoords(RDKit::ROMol &mol,
     // first deal with the fused rings
     DepictorLocal::embedFusedSystems(mol, arings, efrags);
   }
+
+  // do non-tetrahedral stereo
+  DepictorLocal::embedNontetrahedralStereo(mol, efrags, atomRanks);
+
   // deal with any cis/trans systems
   DepictorLocal::embedCisTransSystems(mol, efrags);
   // now get the atoms that are not yet embedded in either a cis/trans system
@@ -307,6 +520,9 @@ unsigned int compute2DCoords(RDKit::ROMol &mol,
                              unsigned int nFlipsPerSample,
                              unsigned int nSamples, int sampleSeed,
                              bool permuteDeg4Nodes, bool forceRDKit) {
+  if (mol.needsUpdatePropertyCache()) {
+    mol.updatePropertyCache(false);
+  }
 #ifdef RDK_BUILD_COORDGEN_SUPPORT
   // default to use CoordGen if we have it installed
   if (!forceRDKit && preferCoordGen) {
@@ -629,18 +845,19 @@ void generateDepictionMatching3DStructure(RDKit::ROMol &mol,
                                         25, true, forceRDKit);
 }
 
-void straightenDepiction(RDKit::ROMol &mol, int confId) {
+void straightenDepiction(RDKit::ROMol &mol, int confId, bool minimizeRotation) {
+  if (!mol.getNumBonds()) {
+    return;
+  }
   constexpr double RAD2DEG = 180. / M_PI;
   constexpr double DEG2RAD = M_PI / 180.;
+  constexpr double ALMOST_ZERO = 1.e-5;
   constexpr double INCR_DEG = 30.;
   constexpr double HALF_INCR_DEG = 0.5 * INCR_DEG;
-  constexpr double TOL_DEG = 5.0;
-  constexpr double ALMOST_ZERO = 1.e-5;
+  constexpr double QUARTER_INCR_DEG = 0.25 * INCR_DEG;
   auto &conf = mol.getConformer(confId);
   auto &pos = conf.getPositions();
-  std::unordered_map<int, std::pair<unsigned int, double>> thetaBins;
-  std::vector<double> thetaValues;
-  thetaValues.reserve(mol.getNumBonds());
+  std::unordered_map<int, DepictorLocal::ThetaBin> thetaBins;
   for (const auto b : mol.bonds()) {
     auto bi = b->getBeginAtomIdx();
     auto ei = b->getEndAtomIdx();
@@ -654,60 +871,64 @@ void straightenDepiction(RDKit::ROMol &mol, int confId) {
     }
     int thetaKey = static_cast<int>(
         d_theta + DepictorLocal::copySign(0.5, d_theta, ALMOST_ZERO));
-    auto it = thetaBins.find(thetaKey);
-    if (it == thetaBins.end()) {
-      it = thetaBins.emplace(thetaKey, std::make_pair(0U, 0.0)).first;
-    }
-    ++it->second.first;
-    it->second.second += d_theta;
-    thetaValues.push_back(theta);
+    auto &thetaBin = thetaBins[thetaKey];
+    thetaBin.d_thetaAvg += d_theta;
+    thetaBin.thetaValues.push_back(theta);
   }
-  unsigned int maxCount = 0;
-  double d_thetaMin = 0.;
-  for (const auto &it : thetaBins) {
-    const auto count = it.second.first;
-    const auto d_thetaAvg = it.second.second / static_cast<double>(count);
-    if (count > maxCount ||
-        (count == maxCount && fabs(d_thetaAvg) < fabs(d_thetaMin))) {
-      maxCount = count;
-      d_thetaMin = d_thetaAvg;
+  CHECK_INVARIANT(!thetaBins.empty(), "");
+  double d_thetaSmallest = std::numeric_limits<double>::max();
+  for (auto &it : thetaBins) {
+    auto &thetaBin = it.second;
+    thetaBin.d_thetaAvg /= static_cast<double>(thetaBin.thetaValues.size());
+    if (fabs(thetaBin.d_thetaAvg) < fabs(d_thetaSmallest)) {
+      d_thetaSmallest = thetaBin.d_thetaAvg;
     }
   }
-#ifdef __clang__
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wunused-lambda-capture"
-#endif
-  unsigned int n30 =
-      std::count_if(thetaValues.begin(), thetaValues.end(),
-                    [d_thetaMin, INCR_DEG, TOL_DEG](double theta) {
-                      theta += d_thetaMin;
-                      return (fabs(fmod(theta, INCR_DEG)) < TOL_DEG);
-                    });
-  unsigned int n60 = std::count_if(
-      thetaValues.begin(), thetaValues.end(),
-      [d_thetaMin, INCR_DEG, TOL_DEG, ALMOST_ZERO](double theta) {
-        theta += d_thetaMin;
-        return (fabs(fmod(theta, INCR_DEG)) < TOL_DEG &&
-                !(abs(static_cast<int>(
-                      theta / INCR_DEG +
-                      DepictorLocal::copySign(0.5, theta, ALMOST_ZERO))) %
-                  2));
-      });
-#ifdef __clang__
-#pragma clang diagnostic pop
-#endif
-  bool shouldRotate = (n60 > n30 / 2);
-  if (shouldRotate) {
-    d_thetaMin -= DepictorLocal::copySign(INCR_DEG, d_thetaMin, ALMOST_ZERO);
+  const auto &minRotationBin =
+      std::max_element(
+          thetaBins.begin(), thetaBins.end(),
+          [](const auto &a, const auto &b) {
+            const auto &aBin = a.second;
+            const auto &bBin = b.second;
+            return (aBin.thetaValues.size() < bBin.thetaValues.size() ||
+                    (aBin.thetaValues.size() == bBin.thetaValues.size() &&
+                     fabs(aBin.d_thetaAvg) > fabs(bBin.d_thetaAvg)));
+          })
+          ->second;
+  double d_thetaMin = minRotationBin.d_thetaAvg;
+  // unless we want to preserve as much as possible the initial orientation,
+  // we try to orient the molecule such that the majority of bonds have
+  // an angle of 30 or 90 degrees with the X axis
+  if (!minimizeRotation) {
+    unsigned int count60vs30[2] = {0, 0};
+    for (auto theta : minRotationBin.thetaValues) {
+      theta += d_thetaMin;
+      auto idx = static_cast<unsigned int>((fabs(theta) + 0.5) / INCR_DEG) % 2;
+      CHECK_INVARIANT(idx < 2, "");
+      ++count60vs30[idx];
+    }
+    if (count60vs30[0] > count60vs30[1]) {
+      d_thetaMin -= DepictorLocal::copySign(INCR_DEG, d_thetaMin, ALMOST_ZERO);
+    }
+  } else if (fabs(d_thetaSmallest) < ALMOST_ZERO ||
+             (fabs(d_thetaSmallest) < fabs(d_thetaMin) &&
+              fabs(d_thetaMin) > QUARTER_INCR_DEG)) {
+    d_thetaMin = d_thetaSmallest;
+  }
+  if (fabs(d_thetaMin) > ALMOST_ZERO) {
+    d_thetaMin *= DEG2RAD;
+    RDGeom::Transform3D trans;
+    trans.SetRotation(d_thetaMin, RDGeom::Z_Axis);
+    MolTransforms::transformConformer(conf, trans);
   }
-  d_thetaMin *= DEG2RAD;
-  RDGeom::Transform3D trans;
-  trans.SetRotation(d_thetaMin, RDGeom::Z_Axis);
-  MolTransforms::transformConformer(conf, trans);
 }
 
 double normalizeDepiction(RDKit::ROMol &mol, int confId, int canonicalize,
                           double scaleFactor) {
+  constexpr double SCALE_FACTOR_THRESHOLD = 1.e-5;
+  if (!mol.getNumBonds()) {
+    return -1.;
+  }
   auto &conf = mol.getConformer(confId);
   if (scaleFactor < 0.0) {
     constexpr double RDKIT_BOND_LEN = 1.5;
@@ -730,7 +951,7 @@ double normalizeDepiction(RDKit::ROMol &mol, int confId, int canonicalize,
         mostCommonBondLengthInt = it->first;
       }
     }
-    if (!binnedBondLengths.empty()) {
+    if (mostCommonBondLengthInt > 0) {
       double mostCommonBondLength =
           static_cast<double>(mostCommonBondLengthInt) * 0.1;
       scaleFactor = RDKIT_BOND_LEN / mostCommonBondLength;
@@ -746,7 +967,8 @@ double normalizeDepiction(RDKit::ROMol &mol, int confId, int canonicalize,
       *canonTrans *= rotate90;
     }
   }
-  if (scaleFactor > 0. && fabs(scaleFactor - 1.0) > 1.e-5) {
+  bool isScaleFactorSane = (scaleFactor > SCALE_FACTOR_THRESHOLD);
+  if (isScaleFactorSane && fabs(scaleFactor - 1.0) > SCALE_FACTOR_THRESHOLD) {
     RDGeom::Transform3D trans;
     trans.setVal(0, 0, scaleFactor);
     trans.setVal(1, 1, scaleFactor);
@@ -757,6 +979,9 @@ double normalizeDepiction(RDKit::ROMol &mol, int confId, int canonicalize,
   } else if (canonTrans) {
     MolTransforms::transformConformer(conf, *canonTrans);
   }
+  if (!isScaleFactorSane) {
+    scaleFactor = -1.;
+  }
   return scaleFactor;
 }
 }  // namespace RDDepict
