@@ -16,8 +16,9 @@
 #include <iostream>
 #ifdef _MSC_VER
 #define _CRT_SECURE_NO_WARNINGS
-#include <Windows.h>  // for Winmm.lib timeGetTime()
-#ifdef _DEBUG         // check memory leaks
+#define NOMINMAX
+#include <Winsock2.h>  // for timeval
+#ifdef _DEBUG          // check memory leaks
 #include <crtdbg.h>
 #define _CRTDBG_MAP_ALLOC
 #ifndef new
