@@ -10,14 +10,19 @@
 //
 #include <list>
 #include <RDGeneral/RDLog.h>
+#include <GraphMol/Chirality.h>
 #include "MolFileStereochem.h"
 #include <Geometry/point.h>
 #include <boost/dynamic_bitset.hpp>
 #include <algorithm>
-#include "MolFileStereochem.h"
 #include <RDGeneral/Ranking.h>
 
 namespace RDKit {
+
+void GetMolFileBondStereoInfo(const Bond *bond, const INT_MAP_INT &wedgeBonds,
+                              const Conformer *conf, int &dirCode,
+                              bool &reverse);
+
 typedef std::list<double> DOUBLE_LIST;
 
 void WedgeBond(Bond *bond, unsigned int fromAtomIdx, const Conformer *conf) {
@@ -78,14 +83,13 @@ std::tuple<unsigned int, unsigned int, unsigned int> getDoubleBondPresence(
   return std::make_tuple(hasDouble, hasKnownDouble, hasAnyDouble);
 }
 
-INT_MAP_INT pickBondsToWedge(const ROMol &mol) {
+std::pair<bool, INT_VECT> countChiralNbrs(const ROMol &mol, int noNbrs) {
   // we need ring information; make sure findSSSR has been called before
   // if not call now
   if (!mol.getRingInfo()->isInitialized()) {
     MolOps::findSSSR(mol);
   }
 
-  static int noNbrs = 100;
   INT_VECT nChiralNbrs(mol.getNumAtoms(), noNbrs);
 
   // start by looking for bonds that are already wedged
@@ -118,11 +122,7 @@ INT_MAP_INT pickBondsToWedge(const ROMol &mol) {
     }
     nChiralNbrs[at->getIdx()] = 0;
     chiNbrs = true;
-    ROMol::ADJ_ITER nbrIdx, endNbrs;
-    boost::tie(nbrIdx, endNbrs) = mol.getAtomNeighbors(at);
-    while (nbrIdx != endNbrs) {
-      const Atom *nat = mol[*nbrIdx];
-      ++nbrIdx;
+    for (const auto nat : mol.atomNeighbors(at)) {
       if (nat->getAtomicNum() == 1) {
         // special case: it's an H... we weight these especially high:
         nChiralNbrs[at->getIdx()] -= 10;
@@ -136,13 +136,100 @@ INT_MAP_INT pickBondsToWedge(const ROMol &mol) {
       nChiralNbrs[at->getIdx()] -= 1;
     }
   }
+  return std::pair<bool, INT_VECT>(chiNbrs, nChiralNbrs);
+}
+
+// picks a bond for atom that we will wedge when we write the mol file
+// returns idx of that bond.
+int pickBondToWedge(const Atom *atom, const ROMol &mol,
+                    const INT_VECT &nChiralNbrs, const INT_MAP_INT &resSoFar,
+                    int noNbrs) {
+  // here is what we are going to do
+  // - at each chiral center look for a bond that is begins at the atom and
+  //   is not yet picked to be wedged for a different chiral center, preferring
+  //   bonds to Hs
+  // - if we do not find a bond that begins at the chiral center - we will take
+  //   the first bond that is not yet picked by any other chiral centers
+  // we use the orders calculated above to determine which order to do the
+  // wedging
+  RDKit::ROMol::OBOND_ITER_PAIR atomBonds = mol.getAtomBonds(atom);
+  std::vector<std::pair<int, int>> nbrScores;
+  while (atomBonds.first != atomBonds.second) {
+    const Bond *bond = mol[*atomBonds.first];
+    ++atomBonds.first;
+
+    // can only wedge single bonds:
+    if (bond->getBondType() != Bond::SINGLE) {
+      continue;
+    }
+
+    int bid = bond->getIdx();
+    if (resSoFar.find(bid) == resSoFar.end()) {
+      // very strong preference for Hs:
+      if (bond->getOtherAtom(atom)->getAtomicNum() == 1) {
+        nbrScores.emplace_back(-1000000,
+                               bid);  // lower than anything else can be
+        continue;
+      }
+      // prefer lower atomic numbers with lower degrees and no specified
+      // chirality:
+      const Atom *oatom = bond->getOtherAtom(atom);
+      int nbrScore = oatom->getAtomicNum() + 100 * oatom->getDegree() +
+                     1000 * ((oatom->getChiralTag() != Atom::CHI_UNSPECIFIED));
+      // prefer neighbors that are nonchiral or have as few chiral neighbors
+      // as possible:
+      int oIdx = oatom->getIdx();
+      if (nChiralNbrs[oIdx] < noNbrs) {
+        // the counts are negative, so we have to subtract them off
+        nbrScore -= 100000 * nChiralNbrs[oIdx];
+      }
+      // prefer bonds to non-ring atoms:
+      nbrScore += 10000 * mol.getRingInfo()->numAtomRings(oIdx);
+      // prefer non-ring bonds;
+      nbrScore += 20000 * mol.getRingInfo()->numBondRings(bid);
+      // prefer bonds to atoms which don't have a double bond from them
+      unsigned int hasDoubleBond;       // is a double bond there?
+      unsigned int hasKnownDoubleBond;  // is specified stereo there?
+      unsigned int hasAnyDoubleBond;    // is STEREOANY there?
+      std::tie(hasDoubleBond, hasKnownDoubleBond, hasAnyDoubleBond) =
+          getDoubleBondPresence(mol, *oatom);
+      nbrScore += 11000 * hasDoubleBond;
+      nbrScore += 12000 * hasKnownDoubleBond;
+      nbrScore += 23000 * hasAnyDoubleBond;
+
+      // std::cerr << "    nrbScore: " << idx << " - " << oIdx << " : "
+      //           << nbrScore << " nChiralNbrs: " << nChiralNbrs[oIdx]
+      //           << std::endl;
+      nbrScores.emplace_back(nbrScore, bid);
+    }
+  }
+  // There's still one situation where this whole thing can fail: an unlucky
+  // situation where all neighbors of all neighbors of an atom are chiral and
+  // that atom ends up being the last one picked for stereochem assignment.
+  //
+  // We'll catch that as an error here and hope that it's as unlikely to occur
+  // as it seems like it is. (I'm going into this knowing that it's bound to
+  // happen; I'll kick myself and do the hard solution at that point.)
+  CHECK_INVARIANT(nbrScores.size(), "no eligible neighbors for chiral center");
+  std::sort(nbrScores.begin(), nbrScores.end(), Rankers::pairLess);
+  return nbrScores[0].second;
+}
+
+INT_MAP_INT pickBondsToWedge(const ROMol &mol) {
+  // returns map of bondIdx -> bond begin atom for those bonds that
+  // need wedging.
   std::vector<unsigned int> indices(mol.getNumAtoms());
   for (unsigned int i = 0; i < mol.getNumAtoms(); ++i) {
     indices[i] = i;
   }
+  static int noNbrs = 100;
+  std::pair<bool, INT_VECT> retVal = countChiralNbrs(mol, noNbrs);
+  bool chiNbrs = retVal.first;
+  INT_VECT nChiralNbrs = retVal.second;
   if (chiNbrs) {
-    std::sort(indices.begin(), indices.end(),
-              Rankers::argless<INT_VECT>(nChiralNbrs));
+    std::sort(indices.begin(), indices.end(), [&](auto i1, auto i2) {
+      return nChiralNbrs[i1] < nChiralNbrs[i2];
+    });
   }
 #if 0
   std::cerr << "  nbrs: ";
@@ -154,15 +241,6 @@ INT_MAP_INT pickBondsToWedge(const ROMol &mol) {
             std::ostream_iterator<int>(std::cerr, " "));
   std::cerr << std::endl;
 #endif
-  // picks a bond for each atom that we will wedge when we write the mol file
-  // here is what we are going to do
-  // - at each chiral center look for a bond that is begins at the atom and
-  //   is not yet picked to be wedged for a different chiral center, preferring
-  //   bonds to Hs
-  // - if we do not find a bond that begins at the chiral center - we will take
-  //   the first bond that is not yet picked by any other chiral centers
-  // we use the orders calculated above to determine which order to do the
-  // wedging
   INT_MAP_INT res;
   for (auto idx : indices) {
     if (nChiralNbrs[idx] > noNbrs) {
@@ -176,70 +254,8 @@ INT_MAP_INT pickBondsToWedge(const ROMol &mol) {
     if (type != Atom::CHI_TETRAHEDRAL_CW && type != Atom::CHI_TETRAHEDRAL_CCW) {
       break;
     }
-    RDKit::ROMol::OBOND_ITER_PAIR atomBonds = mol.getAtomBonds(atom);
-    std::vector<std::pair<int, int>> nbrScores;
-    while (atomBonds.first != atomBonds.second) {
-      const Bond *bond = mol[*atomBonds.first];
-      ++atomBonds.first;
-
-      // can only wedge single bonds:
-      if (bond->getBondType() != Bond::SINGLE) {
-        continue;
-      }
-
-      int bid = bond->getIdx();
-      if (res.find(bid) == res.end()) {
-        // very strong preference for Hs:
-        if (bond->getOtherAtom(atom)->getAtomicNum() == 1) {
-          nbrScores.emplace_back(-1000000,
-                                 bid);  // lower than anything else can be
-          continue;
-        }
-        // prefer lower atomic numbers with lower degrees and no specified
-        // chirality:
-        const Atom *oatom = bond->getOtherAtom(atom);
-        int nbrScore =
-            oatom->getAtomicNum() + 100 * oatom->getDegree() +
-            1000 * ((oatom->getChiralTag() != Atom::CHI_UNSPECIFIED));
-        // prefer neighbors that are nonchiral or have as few chiral neighbors
-        // as possible:
-        int oIdx = oatom->getIdx();
-        if (nChiralNbrs[oIdx] < noNbrs) {
-          // the counts are negative, so we have to subtract them off
-          nbrScore -= 100000 * nChiralNbrs[oIdx];
-        }
-        // prefer bonds to non-ring atoms:
-        nbrScore += 10000 * mol.getRingInfo()->numAtomRings(oIdx);
-        // prefer non-ring bonds;
-        nbrScore += 10000 * mol.getRingInfo()->numBondRings(bid);
-        // prefer bonds to atoms which don't have a double bond from them
-        unsigned int hasDoubleBond;       // is a double bond there?
-        unsigned int hasKnownDoubleBond;  // is specified stereo there?
-        unsigned int hasAnyDoubleBond;    // is STEREOANY there?
-        std::tie(hasDoubleBond, hasKnownDoubleBond, hasAnyDoubleBond) =
-            getDoubleBondPresence(mol, *oatom);
-        nbrScore += 11000 * hasDoubleBond;
-        nbrScore += 12000 * hasKnownDoubleBond;
-        nbrScore += 13000 * hasAnyDoubleBond;
-
-        // std::cerr << "    nrbScore: " << idx << " - " << oIdx << " : "
-        //           << nbrScore << " nChiralNbrs: " << nChiralNbrs[oIdx]
-        //           << std::endl;
-        nbrScores.emplace_back(nbrScore, bid);
-      }
-    }
-    // There's still one situation where this whole thing can fail: an unlucky
-    // situation where all neighbors of all neighbors of an atom are chiral and
-    // that atom ends up being the last one picked for stereochem assignment.
-    //
-    // We'll catch that as an error here and hope that it's as unlikely to occur
-    // as it seems like it is. (I'm going into this knowing that it's bound to
-    // happen; I'll kick myself and do the hard solution at that point.)
-    CHECK_INVARIANT(nbrScores.size(),
-                    "no eligible neighbors for chiral center");
-    std::sort(nbrScores.begin(), nbrScores.end(),
-              Rankers::pairLess<int, int>());
-    res[nbrScores[0].second] = idx;
+    int bnd = pickBondToWedge(atom, mol, nChiralNbrs, res, noNbrs);
+    res[bnd] = idx;
   }
   return res;
 }
@@ -542,15 +558,7 @@ void DetectAtomStereoChemistry(RWMol &mol, const Conformer *conf) {
 }
 
 void ClearSingleBondDirFlags(ROMol &mol) {
-  for (RWMol::BondIterator bondIt = mol.beginBonds(); bondIt != mol.endBonds();
-       ++bondIt) {
-    if ((*bondIt)->getBondType() == Bond::SINGLE) {
-      if ((*bondIt)->getBondDir() == Bond::UNKNOWN) {
-        (*bondIt)->setProp(common_properties::_UnknownStereo, 1);
-      }
-      (*bondIt)->setBondDir(Bond::NONE);
-    }
-  }
+  MolOps::clearSingleBondDirFlags(mol);
 }
 
 void DetectBondStereoChemistry(ROMol &mol, const Conformer *conf) {
@@ -559,4 +567,77 @@ void DetectBondStereoChemistry(ROMol &mol, const Conformer *conf) {
                "conformer does not belong to molecule");
   MolOps::detectBondStereochemistry(mol, conf->getId());
 }
+
+void reapplyMolBlockWedging(ROMol &mol) {
+  MolOps::clearSingleBondDirFlags(mol);
+  for (auto b : mol.bonds()) {
+    int explicit_unknown_stereo = -1;
+    if (b->getPropIfPresent<int>(common_properties::_UnknownStereo,
+                                 explicit_unknown_stereo) &&
+        explicit_unknown_stereo) {
+      b->setBondDir(Bond::UNKNOWN);
+    }
+    int bond_dir = -1;
+    if (b->getPropIfPresent<int>(common_properties::_MolFileBondStereo,
+                                 bond_dir)) {
+      if (bond_dir == 1) {
+        b->setBondDir(Bond::BEGINWEDGE);
+      } else if (bond_dir == 6) {
+        b->setBondDir(Bond::BEGINDASH);
+      }
+    }
+    int cfg = -1;
+    if (b->getPropIfPresent<int>(common_properties::_MolFileBondCfg, cfg)) {
+      switch (cfg) {
+        case 1:
+          b->setBondDir(Bond::BEGINWEDGE);
+          break;
+        case 2:
+          if (b->getBondType() == Bond::SINGLE) {
+            b->setBondDir(Bond::UNKNOWN);
+          } else if (b->getBondType() == Bond::DOUBLE) {
+            b->setBondDir(Bond::EITHERDOUBLE);
+            b->setStereo(Bond::STEREOANY);
+          }
+          break;
+        case 3:
+          b->setBondDir(Bond::BEGINDASH);
+          break;
+      }
+    }
+  }
+}
+
+void markUnspecifiedStereoAsUnknown(ROMol &mol, int confId) {
+  INT_MAP_INT wedgeBonds = pickBondsToWedge(mol);
+  const auto conf = mol.getConformer(confId);
+  for (auto b : mol.bonds()) {
+    if (b->getBondType() == Bond::DOUBLE) {
+      int dirCode;
+      bool reverse;
+      GetMolFileBondStereoInfo(b, wedgeBonds, &conf, dirCode, reverse);
+      if (dirCode == 3) {
+        b->setStereo(Bond::STEREOANY);
+      }
+    }
+  }
+  static int noNbrs = 100;
+  auto si = Chirality::findPotentialStereo(mol);
+  if (si.size()) {
+    std::pair<bool, INT_VECT> retVal = countChiralNbrs(mol, noNbrs);
+    INT_VECT nChiralNbrs = retVal.second;
+    for (auto i : si) {
+      if (i.type == Chirality::StereoType::Atom_Tetrahedral &&
+          i.specified == Chirality::StereoSpecified::Unspecified) {
+        i.specified = Chirality::StereoSpecified::Unknown;
+        auto atom = mol.getAtomWithIdx(i.centeredOn);
+        INT_MAP_INT resSoFar;
+        int bndIdx = pickBondToWedge(atom, mol, nChiralNbrs, resSoFar, noNbrs);
+        auto bond = mol.getBondWithIdx(bndIdx);
+        bond->setBondDir(Bond::UNKNOWN);
+      }
+    }
+  }
+}
+
 }  // namespace RDKit
