@@ -51,10 +51,22 @@ RDKIT_FILEPARSERS_EXPORT void addWavyBondsForStereoAny(
 //! picks the bonds which should be wedged
 /// \returns a map from bond idx -> controlling atom idx
 RDKIT_FILEPARSERS_EXPORT INT_MAP_INT pickBondsToWedge(const ROMol &mol);
+//! deprecated, please use MolOps::clearSingleBondDirFlags instead
 RDKIT_FILEPARSERS_EXPORT void ClearSingleBondDirFlags(ROMol &mol);
 RDKIT_FILEPARSERS_EXPORT Bond::BondDir DetermineBondWedgeState(
     const Bond *bond, unsigned int fromAtomIdx, const Conformer *conf);
 RDKIT_FILEPARSERS_EXPORT Bond::BondDir DetermineBondWedgeState(
     const Bond *bond, const INT_MAP_INT &wedgeBonds, const Conformer *conf);
+//! Forces use of atom wedging from MolBlock if present.
+/*
+ \param mol: molecule to have its wedges altered
+ */
+RDKIT_FILEPARSERS_EXPORT void reapplyMolBlockWedging(ROMol &mol);
+
+//! Set double bonds with unspecified stereo to STEREOANY and add wavy bonds to
+///  potential stereocenters with unspecified chirality
+RDKIT_FILEPARSERS_EXPORT void markUnspecifiedStereoAsUnknown(ROMol &mol,
+                                                             int confId = -1);
+
 }  // namespace RDKit
 #endif
