@@ -510,8 +510,7 @@ unsigned int getAtomParityFlag(const Atom *atom, const Conformer *conf) {
     vs.emplace_back(idx, v);
     ++nbrIdx;
   }
-  std::sort(vs.begin(), vs.end(),
-            Rankers::pairLess<unsigned int, RDGeom::Point3D>());
+  std::sort(vs.begin(), vs.end(), Rankers::pairLess);
   double vol;
   if (vs.size() == 4) {
     vol = vs[0].second.crossProduct(vs[1].second).dotProduct(vs[3].second);
