@@ -39,6 +39,12 @@
 #include "FilterMatcherBase.h"
 #include <GraphMol/MolPickler.h>
 
+#ifdef RDK_USE_BOOST_SERIALIZATION
+#include <RDGeneral/BoostStartInclude.h>
+#include <boost/serialization/shared_ptr.hpp>
+#include <RDGeneral/BoostEndInclude.h>
+#endif
+
 namespace RDKit {
 
 namespace {
@@ -350,12 +356,10 @@ class RDKIT_FILTERCATALOG_EXPORT SmartsMatcher : public FilterMatcherBase {
   template <class Archive>
   void load(Archive &ar, const unsigned int version) {
     ar &boost::serialization::base_object<FilterMatcherBase>(*this);
-    {
-      RDUNUSED_PARAM(version);
-      std::string res;
-      ar &res;
-      d_pattern = boost::shared_ptr<ROMol>(new ROMol(res));
-    }
+    RDUNUSED_PARAM(version);
+    std::string res;
+    ar &res;
+    d_pattern = boost::shared_ptr<ROMol>(new ROMol(res));
     ar &d_min_count;
     ar &d_max_count;
   }
