@@ -155,25 +155,30 @@ class PythonFilterMatch : public FilterMatcherBase {
   }
 
   ~PythonFilterMatch() override {
+    PyGILStateHolder h;
     if (incref) {
       python::decref(functor);
     }
   }
   bool isValid() const override {
+    PyGILStateHolder h;
     return python::call_method<bool>(functor, "IsValid");
   }
 
   std::string getName() const override {
+    PyGILStateHolder h;
     return python::call_method<std::string>(functor, "GetName");
   }
 
   bool getMatches(const ROMol &mol,
                   std::vector<FilterMatch> &matchVect) const override {
+    PyGILStateHolder h;    
     return python::call_method<bool>(functor, "GetMatches", boost::ref(mol),
                                      boost::ref(matchVect));
   }
 
   bool hasMatch(const ROMol &mol) const override {
+    PyGILStateHolder h;    
     return python::call_method<bool>(functor, "HasMatch", boost::ref(mol));
   }
 
@@ -299,6 +304,13 @@ python::dict GetFlattenedFunctionalGroupHierarchyHelper(bool normalize) {
   }
   return dict;
 }
+
+std::vector<std::vector<boost::shared_ptr<const FilterCatalogEntry>>>
+RunFilterCatalogWrapper(const FilterCatalog &fc, const std::vector<std::string> &smiles, int numThreads) {
+  NOGIL nogil;
+  return RunFilterCatalog(fc, smiles, numThreads);
+}
+
 struct filtercat_wrapper {
   static void wrap() {
     python::class_<std::pair<int, int>>("IntPair")
@@ -517,7 +529,7 @@ struct filtercat_wrapper {
                 "Returns True if the FilterCatalog is serializable "
                 "(requires boost serialization");
 
-    python::def("RunFilterCatalog", RunFilterCatalog,
+    python::def("RunFilterCatalog", RunFilterCatalogWrapper,
                 (python::arg("filterCatalog"), python::arg("smiles"),
                  python::arg("numThreads") = 1),
                 "Run the filter catalog on the input list of smiles "
