@@ -37,10 +37,11 @@ class RDKIT_FINGERPRINTS_EXPORT MorganAtomInvGenerator
    */
   MorganAtomInvGenerator(const bool includeRingMembership = true);
 
-  std::vector<std::uint32_t> *getAtomInvariants(const ROMol &mol) const;
+  std::vector<std::uint32_t> *getAtomInvariants(
+      const ROMol &mol) const override;
 
-  std::string infoString() const;
-  MorganAtomInvGenerator *clone() const;
+  std::string infoString() const override;
+  MorganAtomInvGenerator *clone() const override;
 };
 
 /**
@@ -63,10 +64,11 @@ class RDKIT_FINGERPRINTS_EXPORT MorganFeatureAtomInvGenerator
    */
   MorganFeatureAtomInvGenerator(std::vector<const ROMol *> *patterns = nullptr);
 
-  std::vector<std::uint32_t> *getAtomInvariants(const ROMol &mol) const;
+  std::vector<std::uint32_t> *getAtomInvariants(
+      const ROMol &mol) const override;
 
-  std::string infoString() const;
-  MorganFeatureAtomInvGenerator *clone() const;
+  std::string infoString() const override;
+  MorganFeatureAtomInvGenerator *clone() const override;
 };
 
 /**
@@ -90,11 +92,12 @@ class RDKIT_FINGERPRINTS_EXPORT MorganBondInvGenerator
   MorganBondInvGenerator(const bool useBondTypes = true,
                          const bool useChirality = false);
 
-  std::vector<std::uint32_t> *getBondInvariants(const ROMol &mol) const;
+  std::vector<std::uint32_t> *getBondInvariants(
+      const ROMol &mol) const override;
 
-  std::string infoString() const;
-  MorganBondInvGenerator *clone() const;
-  ~MorganBondInvGenerator(){};
+  std::string infoString() const override;
+  MorganBondInvGenerator *clone() const override;
+  ~MorganBondInvGenerator() override = default;
 };
 
 /**
@@ -109,9 +112,9 @@ class RDKIT_FINGERPRINTS_EXPORT MorganArguments
   const bool df_onlyNonzeroInvariants;
   const unsigned int d_radius;
 
-  OutputType getResultSize() const;
+  OutputType getResultSize() const override;
 
-  std::string infoString() const;
+  std::string infoString() const override;
 
   /**
    \brief Construct a new MorganArguments object
@@ -152,7 +155,8 @@ class RDKIT_FINGERPRINTS_EXPORT MorganAtomEnv
                       const std::vector<std::uint32_t> *atomInvariants,
                       const std::vector<std::uint32_t> *bondInvariants,
                       const AdditionalOutput *additionalOutput,
-                      const bool hashResults = false) const;
+                      const bool hashResults = false,
+                      const std::uint64_t fpSize = 0) const override;
 
   /**
    \brief Construct a new MorganAtomEnv object
@@ -180,18 +184,18 @@ class RDKIT_FINGERPRINTS_EXPORT MorganEnvGenerator
       const AdditionalOutput *additionalOutput,
       const std::vector<std::uint32_t> *atomInvariants,
       const std::vector<std::uint32_t> *bondInvariants,
-      const bool hashResults = false) const;
+      const bool hashResults = false) const override;
 
-  std::string infoString() const;
+  std::string infoString() const override;
 };
 
 /**
  \brief Get a fingerprint generator for Morgan fingerprint
 
- \param OutputType determines the size of the bitIds and the result, can be 32
+ \tparam OutputType determines the size of the bitIds and the result, can be 32
  or 64 bit unsigned integer
 
- \param radiu the number of iterations to grow the fingerprint
+ \param radius the number of iterations to grow the fingerprint
 
  \param countSimulation if set, use count simulation while generating the
  fingerprint
@@ -223,6 +227,12 @@ class RDKIT_FINGERPRINTS_EXPORT MorganEnvGenerator
  fingerprint generator
 
  \return FingerprintGenerator<OutputType>* that generates Morgan fingerprints
+
+This generator supports the following \c AdditionalOutput types:
+  - \c atomToBits : which bits each atom is the central atom for
+  - \c atomCounts : how many bits each atom sets
+  - \c bitInfoMap : map from bitId to (atomId, radius) pairs
+
  */
 template <typename OutputType>
 RDKIT_FINGERPRINTS_EXPORT FingerprintGenerator<OutputType> *getMorganGenerator(
