@@ -75,8 +75,7 @@ static inline unsigned long long computeMorganCodeHash(const ROMol& mol) {
 
 static inline void convertMatchingToBondVect(
     std::vector<BondVector_t>& matching_bonds,
-    const std::vector<MatchVectType>& matching_atoms, const ROMol& mol) {
-  RDUNUSED_PARAM(mol);
+    const std::vector<MatchVectType>& matching_atoms) {
   for (const auto& matching_atom : matching_atoms) {
     matching_bonds.emplace_back();
     BondVector_t& mb = matching_bonds.back();  // current match
@@ -504,7 +503,7 @@ bool fragmentMol(const ROMol& mol,
 #endif
 
   std::vector<BondVector_t> matching_bonds;  // List of matched query's bonds
-  convertMatchingToBondVect(matching_bonds, matching_atoms, mol);
+  convertMatchingToBondVect(matching_bonds, matching_atoms);
   if (matching_bonds.size() > maxCutBonds) {
     return false;
   }
@@ -524,7 +523,7 @@ bool fragmentMol(const ROMol& mol,
                  unsigned int minCuts, unsigned int maxCuts) {
   std::vector<BondVector_t> matching_bonds;  // List of matched query's bonds
 
-  BOOST_FOREACH (unsigned int i, bondsToCut) {
+  for (auto i : bondsToCut) {
     const Bond* bond = mol.getBondWithIdx(i);
     BondVector_t bonds;
     unsigned int a1 = bond->getBeginAtomIdx();
