@@ -37,7 +37,7 @@
 #include <sys/time.h>
 #endif
 #ifdef _WIN32
-#include <Windows.h>
+#include <windows.h>
 #else
 #include <sys/resource.h>
 #endif
