@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2001-2006 Rational Discovery LLC
+//  Copyright (C) 2001-2022 Greg Landrum and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -39,11 +39,10 @@ class RDKIT_MOLALIGN_EXPORT MolAlignException : public std::exception {
 
 //! Compute the transformation required to align a molecule
 /*!
-  The 3D transformation required to align the specied conformation in the probe
-  molecule
-  to a specified conformation in the reference molecule is computed so that the
-  root mean
-  squared distance between a specified set of atoms is minimized
+  The 3D transformation required to align the specified conformation in the
+  probe molecule to a specified conformation in the reference molecule is
+  computed so that the root mean squared distance between a specified set of
+  atoms is minimized
 
   \param prbMol    molecule that is to be aligned
   \param refMol    molecule used as the reference for the alignment
@@ -58,7 +57,7 @@ class RDKIT_MOLALIGN_EXPORT MolAlignException : public std::exception {
                    substructure matching
   \param weights   Optionally specify weights for each of the atom pairs
   \param reflect   if true reflect the conformation of the probe molecule
-  \param maxIters  maximum number of iteration used in mimizing the RMSD
+  \param maxIters  maximum number of iterations used in minimizing the RMSD
 
   <b>Returns</b>
   RMSD value
@@ -71,13 +70,11 @@ RDKIT_MOLALIGN_EXPORT double getAlignmentTransform(
 
 //! Optimally (minimum RMSD) align a molecule to another molecule
 /*!
-  The 3D transformation required to align the specied conformation in the probe
-  molecule
-  to a specified conformation in the reference molecule is computed so that the
-  root mean
-  squared distance between a specified set of atoms is minimized. This
-  transforms is them
-  applied to the specified conformation in the probe molecule
+  The 3D transformation required to align the specified conformation in the
+  probe molecule to a specified conformation in the reference molecule is
+  computed so that the root mean squared distance between a specified set of
+  atoms is minimized. This transform is then applied to the specified
+  conformation in the probe molecule
 
   \param prbMol    molecule that is to be aligned
   \param refMol    molecule used as the reference for the alignment
@@ -91,7 +88,7 @@ RDKIT_MOLALIGN_EXPORT double getAlignmentTransform(
                    substructure matching
   \param weights   Optionally specify weights for each of the atom pairs
   \param reflect   if true reflect the conformation of the probe molecule
-  \param maxIters  maximum number of iteration used in mimizing the RMSD
+  \param maxIters  maximum number of iterations used in minimizing the RMSD
 
   <b>Returns</b>
   RMSD value
@@ -102,6 +99,47 @@ RDKIT_MOLALIGN_EXPORT double alignMol(
     const RDNumeric::DoubleVector *weights = nullptr, bool reflect = false,
     unsigned int maxIters = 50);
 
+//! Compute the optimal RMS, transformation and atom map for aligning
+//! two molecules, taking symmetry into account. Molecule coordinates
+//! are left unaltered.
+/*!
+  This function will attempt to align all permutations of matching atom
+  orders in both molecules, for some molecules it will lead to 'combinatorial
+  explosion' especially if hydrogens are present.
+  Use 'RDKit::MolAlign::getAlignmentTransform' to align molecules
+  without changing the atom order.
+
+  \param prbMol     the molecule to be aligned to the reference
+  \param refMol     the reference molecule
+  \param bestTrans  storage for the best computed transform
+  \param bestMatch  storage for the MatchVectType corresponding to
+                    the best match found.
+  \param prbCid     (optional) probe conformation to use
+  \param refCid     (optional) reference conformation to use
+  \param map        (optional) a vector of vectors of pairs of atom IDs
+                    (probe AtomId, ref AtomId) used to compute the alignments.
+                    If not provided, these will be generated using a
+                    substructure search.
+  \param maxMatches (optional) if map is empty, this will be the max number of
+                    matches found in a SubstructMatch().
+  \param symmetrizeConjugatedTerminalGroups (optional) if set, conjugated
+                    terminal functional groups (like nitro or carboxylate)
+                    will be considered symmetrically
+  \param weights    (optional) weights for each pair of atoms.
+  \param reflect    if true reflect the conformation of the probe molecule
+  \param maxIters   maximum number of iterations used in minimizing the RMSD
+
+  <b>Returns</b>
+  Best RMSD value found
+*/
+RDKIT_MOLALIGN_EXPORT double getBestAlignmentTransform(
+    const ROMol &prbMol, const ROMol &refMol, RDGeom::Transform3D &bestTrans,
+    MatchVectType &bestMatch, int prbCid = -1, int refCid = -1,
+    const std::vector<MatchVectType> &map = std::vector<MatchVectType>(),
+    int maxMatches = 1e6, bool symmetrizeConjugatedTerminalGroups = true,
+    const RDNumeric::DoubleVector *weights = nullptr, bool reflect = false,
+    unsigned int maxIters = 50);
+
 //! Returns the optimal RMS for aligning two molecules, taking
 /// symmetry into account. As a side-effect, the probe molecule is
 /// left in the aligned state.
@@ -112,50 +150,95 @@ RDKIT_MOLALIGN_EXPORT double alignMol(
   Use 'RDKit::MolAlign::alignMol' to align molecules without changing the
   atom order.
 
-  \param probeMol   the molecule to be aligned to the reference
+  \param prbMol     the molecule to be aligned to the reference
   \param refMol     the reference molecule
-  \param probeId    (optional) probe conformation to use
-  \param refId      (optional) reference conformation to use
+  \param trans      storage for the computed transform
+  \param prbCid     (optional) probe conformation to use
+  \param refCid     (optional) reference conformation to use
   \param map        (optional) a vector of vectors of pairs of atom IDs
                     (probe AtomId, ref AtomId) used to compute the alignments.
                     If not provided, these will be generated using a
                     substructure search.
   \param maxMatches (optional) if map is empty, this will be the max number of
                     matches found in a SubstructMatch().
+  \param symmetrizeConjugatedTerminalGroups (optional) if set, conjugated
+                    terminal functional groups (like nitro or carboxylate)
+                    will be considered symmetrically
+  \param weights    (optional) weights for each pair of atoms.
 
   <b>Returns</b>
   Best RMSD value found
 */
 RDKIT_MOLALIGN_EXPORT double getBestRMS(
-    ROMol &probeMol, ROMol &refMol, int probeId = -1, int refId = -1,
+    ROMol &prbMol, const ROMol &refMol, int prbCid = -1, int refCid = -1,
     const std::vector<MatchVectType> &map = std::vector<MatchVectType>(),
-    int maxMatches = 1e6);
+    int maxMatches = 1e6, bool symmetrizeConjugatedTerminalGroups = true,
+    const RDNumeric::DoubleVector *weights = nullptr);
 
 //! Returns the RMS between two molecules, taking symmetry into account.
+//! In contrast to getBestRMS, the RMS is computed "in place", i.e.
+//! probe molecules are not aligned to the reference ahead of the
+//! RMS calculation. This is useful, for example, to compute
+//! the RMSD between docking poses and the co-crystallized ligand.
 /*!
-  This function will attempt to align all permutations of matching atom
+  This function will attempt to match all permutations of matching atom
   orders in both molecules, for some molecules it will lead to 'combinatorial
   explosion' especially if hydrogens are present.
 
-  \param probeMol   the molecule to be aligned to the reference
+  \param prbMol     the molecule to be aligned to the reference
   \param refMol     the reference molecule
-  \param probeId    (optional) probe conformation to use
-  \param refId      (optional) reference conformation to use
+  \param prbCid     (optional) probe conformation to use
+  \param refCid     (optional) reference conformation to use
   \param map        (optional) a vector of vectors of pairs of atom IDs
                     (probe AtomId, ref AtomId) used to compute the alignments.
                     If not provided, these will be generated using a
                     substructure search.
   \param maxMatches (optional) if map is empty, this will be the max number of
                     matches found in a SubstructMatch().
-  \param weights    (optional) weights for each pair of atom.
+  \param symmetrizeConjugatedTerminalGroups (optional) if set, conjugated
+                    terminal functional groups (like nitro or carboxylate) will
+                    be considered symmetrically
+  \param weights    (optional) weights for each pair of atoms.
 
   <b>Returns</b>
   Best RMSD value found
 */
 RDKIT_MOLALIGN_EXPORT double CalcRMS(
-    ROMol &probeMol, const ROMol &refMol, int prbCid = -1, int refCid = -1,
+    ROMol &prbMol, const ROMol &refMol, int prbCid = -1, int refCid = -1,
     const std::vector<MatchVectType> &map = std::vector<MatchVectType>(),
-    int maxMatches = 1e6, const RDNumeric::DoubleVector *weights = nullptr);
+    int maxMatches = 1e6, bool symmetrizeConjugatedTerminalGroups = true,
+    const RDNumeric::DoubleVector *weights = nullptr);
+
+//! Returns the RMS between two molecules, taking symmetry into account.
+//! In contrast to getBestRMS, the RMS is computed "in place", i.e.
+//! probe molecules are not aligned to the reference ahead of the
+//! RMS calculation. This is useful, for example, to compute
+//! the RMSD between docking poses and the co-crystallized ligand.
+/*!
+  This function will attempt to match all permutations of matching atom
+  orders in both molecules, for some molecules it will lead to 'combinatorial
+  explosion' especially if hydrogens are present.
+
+  \param prbMol     the molecule to be aligned to the reference
+  \param refMol     the reference molecule
+  \param prbCid     (optional) probe conformation to use
+  \param refCid     (optional) reference conformation to use
+  \param map        (optional) a vector of vectors of pairs of atom IDs
+                    (probe AtomId, ref AtomId) used to compute the alignments.
+                    If not provided, these will be generated using a
+                    substructure search.
+  \param maxMatches (optional) if map is empty, this will be the max number of
+                    matches found in a SubstructMatch().
+  \param weights    (optional) weights for each pair of atoms.
+
+  <b>Returns</b>
+  Best RMSD value found
+*/
+RDKIT_MOLALIGN_EXPORT double CalcRMS(ROMol &prbMol, const ROMol &refMol,
+                                     int prbCid, int refCid,
+                                     const std::vector<MatchVectType> &map,
+                                     int maxMatches,
+                                     const RDNumeric::DoubleVector *weights);
 
 //! Align the conformations of a molecule using a common set of atoms. If
 /// the molecules contains queries, then the queries must also match exactly.
@@ -165,8 +248,7 @@ RDKIT_MOLALIGN_EXPORT double CalcRMS(
   \param atomIds   vector of atoms to be used to generate the alignment.
                    All atoms will be used is not specified
   \param confIds   vector of conformations to align - defaults to all
-  \param weights   vector of weights to applied to particular atom pairs
-                   defaults to all weights = 1
+  \param weights   (optional) weights for each pair of atoms.
   \param reflect   toggles reflecting (about the origin) the alignment
   \param maxIters  the maximum number of iterations to attempt
   \param RMSlist   if nonzero, this will be used to return the RMS values
