@@ -17,7 +17,7 @@ class RDKIT_MOLCATALOG_EXPORT MolCatalogParams
  public:
   MolCatalogParams() { d_typeStr = "MolCatalog Parameters"; }
 
-  ~MolCatalogParams();
+  ~MolCatalogParams() override;
 
   //! copy constructor
   MolCatalogParams(const MolCatalogParams &other) {
@@ -27,13 +27,13 @@ class RDKIT_MOLCATALOG_EXPORT MolCatalogParams
   MolCatalogParams(const std::string &pickle);
 
   //! serializes to the stream
-  void toStream(std::ostream &) const;
+  void toStream(std::ostream &) const override;
   //! returns a serialized (pickled) form
-  std::string Serialize() const;
+  std::string Serialize() const override;
   //! initialize from a stream containing a pickle
-  void initFromStream(std::istream &ss);
+  void initFromStream(std::istream &ss) override;
   //! initialize from a string containing a pickle
-  void initFromString(const std::string &text);
+  void initFromString(const std::string &text) override;
 };
 }  // namespace RDKit
 
