@@ -1,7 +1,7 @@
 from rdkit import DataStructs
 from rdkit import RDConfig
 from rdkit import Chem
-from rdkit.Chem import ChemicalFeatures, rdDistGeom
+from rdkit.Chem import ChemicalFeatures, rdDistGeom, AllChem
 from rdkit import Geometry
 import unittest, os
 
@@ -195,6 +195,28 @@ EndFeature
     cfac = None
     self.assertEqual(feats[0].GetFamily(), 'Donor')
 
+  def testGithub2530(self):
+    cfac = ChemicalFeatures.BuildFeatureFactory(
+      os.path.join(RDConfig.RDDataDir, "BaseFeatures.fdef"))
+    m = Chem.MolFromSmiles('C1CCC1OC')
+    rdDistGeom.EmbedMolecule(m)
+    feats = cfac.GetFeaturesForMol(m)
+    feat_pos = feats[0].GetPos(-1)
+    feat_pos_default = feats[0].GetPos()
+    self.assertEqual(feat_pos[0], feat_pos_default[0])
+    self.assertEqual(feat_pos[1], feat_pos_default[1])
+    self.assertEqual(feat_pos[2], feat_pos_default[2])
+
+    # Conformers generation:
+    m2 = Chem.AddHs(m)
+    AllChem.EmbedMultipleConfs(m2, numConfs=10, params=AllChem.ETKDG())
+
+    feats_0 = cfac.GetFeaturesForMol(m2, confId=-1)
+    feats_5 = cfac.GetFeaturesForMol(m2, confId=5)
+    self.assertNotEqual(feats_5[0], feats_0[0])
+    self.assertNotEqual(feats_5[1], feats_0[1])
+    self.assertNotEqual(feats_5[2], feats_0[2])
+
 
 if __name__ == '__main__':
   unittest.main()
