@@ -1,11 +1,13 @@
 //
+//  Copyright (C) 2021-2022 David Cosgrove and other RDKit contributors
+//
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
 //  The contents are covered by the terms of the BSD license
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
-// Original author: David Cosgrove (CozChemIx) on 29/04/2020.
+// Original author: David Cosgrove (CozChemIx).
 //
 // A concrete class derived from DrawText that uses SVG
 // to draw text onto a picture.
@@ -15,20 +17,28 @@
 
 #include <iosfwd>
 
-#include <GraphMol/MolDraw2D/DrawText.h>
+#include <GraphMol/MolDraw2D/DrawTextNotFT.h>
 
 namespace RDKit {
 
+class MolDraw2DSVG;
+
+namespace MolDraw2D_detail {
+
 // ****************************************************************************
 
-class DrawTextSVG : public DrawText {
+class DrawTextSVG : public DrawTextNotFT {
+
  public:
   DrawTextSVG(double max_fnt_sz, double min_fnt_sz, std::ostream &oss,
               std::string &d_act_class);
+  DrawTextSVG(const DrawTextSVG &) = delete;
+  DrawTextSVG(DrawTextSVG &&) = delete;
+  DrawTextSVG &operator=(const DrawTextSVG &) = delete;
+  DrawTextSVG &operator=(DrawTextSVG &&) = delete;
 
   void drawChar(char c, const Point2D &cds) override;
 
- private:
   std::ostream &oss_;
   std::string &d_active_class_;
 
@@ -41,6 +51,7 @@ class DrawTextSVG : public DrawText {
                       std::vector<char> &draw_chars) const override;
 };
 
+}  // namespace MolDraw2D_detail
 }  // namespace RDKit
 
 #endif  // RDKIT_DRAWTEXTSVG_H
