@@ -213,7 +213,7 @@ void MolDraw2D::drawMolecules(
       MolDraw2D_detail::getBondHighlightsForAtoms(
           *mols[i], (*highlight_atoms)[i], *lhighlight_bonds);
     };
-
+    auto prevSize = drawMols_.size();
     drawMols_.emplace_back(new MolDraw2D_detail::DrawMol(
         *mols[i], legend, panelWidth(), panelHeight(), drawOptions(),
         *text_drawer_, ha, lhighlight_bonds.get(), ham, hbm, nullptr, hr,
@@ -231,11 +231,11 @@ void MolDraw2D::drawMolecules(
     drawMols_.back()->setOffsets(col * panelWidth(), row * panelHeight());
     drawMols_.back()->createDrawObjects();
     if (drawMols_.back()->getScale() < drawMols_[minScaleMol]->getScale()) {
-      minScaleMol = i;
+      minScaleMol = prevSize;
     }
     if (drawMols_.back()->getFontScale() <
         drawMols_[minFontScaleMol]->getFontScale()) {
-      minFontScaleMol = i;
+      minFontScaleMol = prevSize;
     }
   }
 
@@ -578,9 +578,9 @@ const std::vector<std::pair<std::string, MolDraw2D_detail::OrientType>>
 // ****************************************************************************
 double MolDraw2D::getDrawLineWidth() const {
   double width = lineWidth();
-  // This works fairly well for SVG and Cairo. 0.02 is picked by eye
   if (drawOptions().scaleBondWidth) {
-    width *= scale() * 0.02;
+    // lineWidthScaleFactor is defined in MolDraw2DHelpers.h
+    width *= scale() * lineWidthScaleFactor;
     if (width < 0.0) {
       width = 0.0;
     }
@@ -897,8 +897,8 @@ void MolDraw2D::makeReactionDrawMol(
     const std::map<int, DrawColour> &highlightAtomMap,
     const std::map<int, DrawColour> &highlightBondMap,
     std::vector<std::shared_ptr<MolDraw2D_detail::DrawMol>> &mols) {
+  mol.updatePropertyCache(false);
   if (drawOptions().prepareMolsBeforeDrawing) {
-    mol.updatePropertyCache(false);
     try {
       RDLog::LogStateSetter blocker;
       MolOps::Kekulize(mol, false);  // kekulize, but keep the aromatic flags!
