@@ -14,6 +14,7 @@
 #include <fstream>
 #include <GraphMol/MolDraw2D/MolDraw2DCairo.h>
 #include <GraphMol/MolDraw2D/DrawTextCairo.h>
+#include <GraphMol/MolDraw2D/MolDraw2DDetails.h>
 #ifdef RDK_BUILD_FREETYPE_SUPPORT
 #include <GraphMol/MolDraw2D/DrawTextFTCairo.h>
 #endif
@@ -133,32 +134,25 @@ void MolDraw2DCairo::drawWavyLine(const Point2D &cds1, const Point2D &cds2,
   PRECONDITION(dp_cr, "no draw context");
   PRECONDITION(nSegments > 1, "too few segments");
 
-  if (nSegments % 2) {
-    ++nSegments;  // we're going to assume an even number of segments
-  }
-
-  Point2D delta = (cds2 - cds1);
-  Point2D perp(delta.y, -delta.x);
-  perp.normalize();
-  perp *= vertOffset;
-  delta /= nSegments;
-
-  Point2D c1 = rawCoords ? cds1 : getDrawCoords(cds1);
+  auto segments =
+      MolDraw2D_detail::getWavyLineSegments(cds1, cds2, nSegments, vertOffset);
 
   double width = getDrawLineWidth();
   cairo_set_line_width(dp_cr, width);
   cairo_set_dash(dp_cr, nullptr, 0, 0);
   setColour(col1);
+
+  auto c1 = std::get<0>(segments[0]);
+  c1 = rawCoords ? c1 : getDrawCoords(c1);
+
   cairo_move_to(dp_cr, c1.x, c1.y);
   for (unsigned int i = 0; i < nSegments; ++i) {
-    Point2D startpt = cds1 + delta * i;
-    Point2D segpt =
-        rawCoords ? startpt + delta : getDrawCoords(startpt + delta);
-    Point2D cpt1 = startpt + delta / 3. + perp * (i % 2 ? -1 : 1);
+    auto cpt1 = std::get<1>(segments[i]);
     cpt1 = rawCoords ? cpt1 : getDrawCoords(cpt1);
-    Point2D cpt2 = startpt + delta * 2. / 3. + perp * (i % 2 ? -1 : 1);
+    auto cpt2 = std::get<2>(segments[i]);
     cpt2 = rawCoords ? cpt2 : getDrawCoords(cpt2);
-    // if (i == nSegments / 2 && col2 != col1) setColour(col2);
+    auto segpt = std::get<3>(segments[i]);
+    segpt = rawCoords ? segpt : getDrawCoords(segpt);
     cairo_curve_to(dp_cr, cpt1.x, cpt1.y, cpt2.x, cpt2.y, segpt.x, segpt.y);
   }
   cairo_stroke(dp_cr);
@@ -200,6 +194,7 @@ void MolDraw2DCairo::drawPolygon(const std::vector<Point2D> &cds,
 
 // ****************************************************************************
 void MolDraw2DCairo::clearDrawing() {
+  MolDraw2D::clearDrawing();
   PRECONDITION(dp_cr, "no draw context");
   setColour(drawOptions().backgroundColour);
   cairo_rectangle(dp_cr, offset().x, offset().y, width(), height());
