@@ -47,41 +47,26 @@ namespace {
 // left at the end of the run.
 static const bool DELETE_WITH_GOOD_HASH = true;
 #ifdef RDK_BUILD_FREETYPE_SUPPORT
-static const std::map<std::string, std::hash_result_t> SVG_HASHES =
-    {
-        {"rxn_test1_1.svg", 1477987745U},
-        {"rxn_test1_2.svg", 2538023343U},
-        {"rxn_test1_3.svg", 680474854U},
-        {"rxn_test1_4.svg", 2509069997U},
-        {"rxn_test1_5.svg", 3506839570U},
-        {"rxn_test1_6.svg", 1403115944U},
-        {"rxn_test1_7.svg", 2837557771U},
-        {"rxn_test2_1.svg", 2788219013U},
-        {"rxn_test2_2_1.svg", 423226601U},
-        {"rxn_test2_2_2.svg", 3888536321U},
-        {"rxn_test2_2_3.svg", 1655870507U},
-        {"rxn_test2_2_4.svg", 1301077885U},
-        {"rxn_test3_1.svg", 918050585U},
-        {"rxn_test4_1.svg", 3760324344U},
-        {"rxn_test4_2.svg", 2562939407U},
+static const std::map<std::string, std::hash_result_t> SVG_HASHES = {
+    {"rxn_test1_1.svg", 46725873U},     {"rxn_test1_2.svg", 2822273042U},
+    {"rxn_test1_3.svg", 3749362740U},   {"rxn_test1_4.svg", 2720989271U},
+    {"rxn_test1_5.svg", 3245376196U},   {"rxn_test1_6.svg", 3282888040U},
+    {"rxn_test1_7.svg", 1748644916U},   {"rxn_test2_1.svg", 409647324U},
+    {"rxn_test2_2_1.svg", 1275078201U}, {"rxn_test2_2_2.svg", 2689198952U},
+    {"rxn_test2_2_3.svg", 3750657998U}, {"rxn_test2_2_4.svg", 844519751U},
+    {"rxn_test3_1.svg", 3321754513U},   {"rxn_test4_1.svg", 1987969092U},
+    {"rxn_test4_2.svg", 946039978U},
 };
 #else
 static const std::map<std::string, std::hash_result_t> SVG_HASHES = {
-    {"rxn_test1_1.svg", 750251696U},
-    {"rxn_test1_2.svg", 1034097793U},
-    {"rxn_test1_3.svg", 2608858489U},
-    {"rxn_test1_4.svg", 2268215787U},
-    {"rxn_test1_5.svg", 580358319U},
-    {"rxn_test1_6.svg", 3328371709U},
-    {"rxn_test1_7.svg", 3974929571U},
-    {"rxn_test2_1.svg", 1967050197U},
-    {"rxn_test2_2_1.svg", 3154044612U},
-    {"rxn_test2_2_2.svg", 2988162762U},
-    {"rxn_test2_2_3.svg", 2997497304U},
-    {"rxn_test2_2_4.svg", 298660385U},
-    {"rxn_test3_1.svg", 1136097145U},
-    {"rxn_test4_1.svg", 1747105692U},
-    {"rxn_test4_2.svg", 1624200008U},
+    {"rxn_test1_1.svg", 3077363070U},   {"rxn_test1_2.svg", 343913088U},
+    {"rxn_test1_3.svg", 1743857837U},   {"rxn_test1_4.svg", 421748462U},
+    {"rxn_test1_5.svg", 2287478842U},   {"rxn_test1_6.svg", 771132615U},
+    {"rxn_test1_7.svg", 573680560U},    {"rxn_test2_1.svg", 2821179072U},
+    {"rxn_test2_2_1.svg", 1304295583U}, {"rxn_test2_2_2.svg", 1361778996U},
+    {"rxn_test2_2_3.svg", 2608405344U}, {"rxn_test2_2_4.svg", 574045696U},
+    {"rxn_test3_1.svg", 3205563676U},   {"rxn_test4_1.svg", 2762964801U},
+    {"rxn_test4_2.svg", 1182024377U},
 };
 #endif
 
@@ -96,21 +81,14 @@ static const std::map<std::string, std::hash_result_t> SVG_HASHES = {
 // better because the floats are all output to only 1 decimal place so there
 // is a much smaller chance of different systems producing different files.
 static const std::map<std::string, std::hash_result_t> PNG_HASHES = {
-    {"rxn_test1_1.png", 2867700423U},
-    {"rxn_test1_2.png", 2074724089U},
-    {"rxn_test1_3.png", 421271067U},
-    {"rxn_test1_4.png", 3523297494U},
-    {"rxn_test1_5.png", 3888923008U},
-    {"rxn_test1_6.png", 3767742095U},
-    {"rxn_test1_7.png", 254968254U},
-    {"rxn_test2_1.png", 432415333U},
-    {"rxn_test2_2_1.png", 519534633U},
-    {"rxn_test2_2_2.png", 1058522300U},
-    {"rxn_test2_2_3.png", 392287367U},
-    {"rxn_test2_2_4.png", 1762710408U},
-    {"rxn_test3_1.png", 3503835876U},
-    {"rxn_test4_1.png", 1845902236U},
-    {"rxn_test4_2.png", 2849520465U},
+    {"rxn_test1_1.png", 3579100589U},  {"rxn_test1_2.png", 3996724834U},
+    {"rxn_test1_3.png", 4153817948U},  {"rxn_test1_4.png", 4175225545U},
+    {"rxn_test1_5.png", 3400977230U},  {"rxn_test1_6.png", 2636974466U},
+    {"rxn_test1_7.png", 4164917700U},  {"rxn_test2_1.png", 2654417911U},
+    {"rxn_test2_2_1.png", 997060634U}, {"rxn_test2_2_2.png", 2090979640U},
+    {"rxn_test2_2_3.png", 857100114U}, {"rxn_test2_2_4.png", 610638635U},
+    {"rxn_test3_1.png", 501226401U},   {"rxn_test4_1.png", 805353504U},
+    {"rxn_test4_2.png", 2842629749U},
 };
 
 std::hash_result_t hash_file(const std::string &filename) {
