@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2018 Susan H. Leung
+//  Copyright (C) 2018-2021 Susan H. Leung and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -18,15 +18,32 @@ typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
 
 namespace RDKit {
 namespace {
-std::pair<ROMol*, ROMol*>* getPair(const std::string& tmpStr) {
-  std::pair<ROMol*, ROMol*>* mol_pair = nullptr;
-  if (tmpStr.length() == 0) {
-    // empty line
-    return mol_pair;
+
+std::pair<ROMol*, ROMol*>* getPair(const std::string& name,
+                                   const std::string& acid_smarts,
+                                   const std::string& base_smarts) {
+  ROMol* acid(SmartsToMol(acid_smarts));
+  if (!acid) {
+    throw ValueErrorException("Failed parsing acid SMARTS: " + acid_smarts);
   }
-  if (tmpStr.substr(0, 2) == "//") {
-    // comment line
-    return mol_pair;
+  ROMol* base(SmartsToMol(base_smarts));
+  if (!base) {
+    delete acid;
+    throw ValueErrorException("Failed parsing base SMARTS: " + base_smarts);
+  }
+
+  acid->setProp(common_properties::_Name, name);
+  base->setProp(common_properties::_Name, name);
+
+  return new std::pair<ROMol*, ROMol*>(acid, base);
+}
+std::pair<ROMol*, ROMol*>* getPair(std::string tmpStr) {
+  // Remove whitespace
+  boost::trim(tmpStr);
+
+  if (tmpStr.length() == 0 || tmpStr.substr(0, 2) == "//") {
+    // empty or comment line
+    return nullptr;
   }
 
   boost::char_separator<char> tabSep("\t");
@@ -38,7 +55,7 @@ std::pair<ROMol*, ROMol*>* getPair(const std::string& tmpStr) {
   boost::erase_all(name, " ");
   ++token;
 
-  // grab the acid :
+  // grab the acid:
   std::string acid_smarts = *token;
   boost::erase_all(acid_smarts, " ");
   ++token;
@@ -48,17 +65,7 @@ std::pair<ROMol*, ROMol*>* getPair(const std::string& tmpStr) {
   boost::erase_all(base_smarts, " ");
   ++token;
 
-  ROMol* acid(SmartsToMol(acid_smarts));
-  ROMol* base(SmartsToMol(base_smarts));
-  
-	CHECK_INVARIANT(acid, acid_smarts);
-  CHECK_INVARIANT(base, base_smarts);
-  
-	acid->setProp(common_properties::_Name, name);
-  base->setProp(common_properties::_Name, name);
-  
-	mol_pair = new std::pair<ROMol*, ROMol*>(acid, base);
-  return mol_pair;
+  return getPair(name, acid_smarts, base_smarts);
 }
 }  // namespace
 
@@ -87,19 +94,32 @@ std::vector<std::pair<ROMOL_SPTR, ROMOL_SPTR>> readPairs(std::istream& inStream,
   char inLine[MAX_LINE_LEN];
   std::string tmpstr;
   int nRead = 0;
-  while (!inStream.eof() && !inStream.fail() && (nToRead < 0 || nRead < nToRead)) {
+  while (!inStream.eof() && !inStream.fail() &&
+         (nToRead < 0 || nRead < nToRead)) {
     inStream.getline(inLine, MAX_LINE_LEN, '\n');
     tmpstr = inLine;
     // parse the molpair on this line (if there is one)
     std::shared_ptr<std::pair<ROMol*, ROMol*>> mol_pair(getPair(tmpstr));
     if (mol_pair != nullptr) {
-      pairs.emplace_back(
-          ROMOL_SPTR(mol_pair->first), ROMOL_SPTR(mol_pair->second));
+      pairs.emplace_back(ROMOL_SPTR(mol_pair->first),
+                         ROMOL_SPTR(mol_pair->second));
       nRead++;
     }
   }
   return pairs;
 }
 
+std::vector<std::pair<ROMOL_SPTR, ROMOL_SPTR>> readPairs(
+    const std::vector<std::tuple<std::string, std::string, std::string>>&
+        data) {
+  std::vector<std::pair<ROMOL_SPTR, ROMOL_SPTR>> pairs;
+  for (const auto& tpl : data) {
+    std::shared_ptr<std::pair<ROMol*, ROMol*>> mol_pair(
+        getPair(std::get<0>(tpl), std::get<1>(tpl), std::get<2>(tpl)));
+    pairs.emplace_back(ROMOL_SPTR(mol_pair->first),
+                       ROMOL_SPTR(mol_pair->second));
+  }
+  return pairs;
+}
 }  // namespace MolStandardize
 }  // namespace RDKit
