@@ -425,9 +425,9 @@ chlorine	[Cl]
 
     enumerator = rdMolStandardize.TautomerEnumerator()
     res68 = enumerator.Enumerate(m68)
-    self.assertEqual(len(res68), 252)
+    self.assertEqual(len(res68), 72)
     self.assertEqual(len(res68.tautomers), len(res68))
-    self.assertEqual(res68.status, rdMolStandardize.TautomerEnumeratorStatus.MaxTransformsReached)
+    self.assertEqual(res68.status, rdMolStandardize.TautomerEnumeratorStatus.Completed)
 
     enumerator = rdMolStandardize.GetV1TautomerEnumerator()
     res68 = enumerator.Enumerate(m68)
@@ -592,10 +592,17 @@ chlorine	[Cl]
     smi68 = "[H][C](CO)(NC(=O)C1=C(O)C(O)=CC=C1)C(O)=O"
     m68 = Chem.MolFromSmiles(smi68)
 
+    def createV1Enumerator():
+      enumerator = rdMolStandardize.GetV1TautomerEnumerator()
+      enumerator.SetMaxTransforms(10000)
+      enumerator.SetMaxTautomers(10000)
+      return enumerator
+
     params = rdMolStandardize.CleanupParameters()
     params.maxTransforms = 10000
     params.maxTautomers = 10000
-    enumerator = rdMolStandardize.TautomerEnumerator(params)
+
+    enumerator = createV1Enumerator()
     enumerator.SetCallback(MyTautomerEnumeratorCallback(self, 50.0))
     res68 = enumerator.Enumerate(m68)
     # either the enumeration was canceled due to timeout
@@ -611,14 +618,14 @@ chlorine	[Cl]
     self.assertTrue(hasReachedTimeout or hasCompleted)
     self.assertTrue(hasReachedTimeout ^ hasCompleted)
 
-    enumerator = rdMolStandardize.TautomerEnumerator(params)
+    enumerator = createV1Enumerator()
     enumerator.SetCallback(MyTautomerEnumeratorCallback(self, 10000.0))
     res68 = enumerator.Enumerate(m68)
     # either the enumeration completed
     # or it ran very slowly and was canceled due to timeout
-    hasReachedTimeout = (len(res68.tautomers) < 295
+    hasReachedTimeout = (len(res68.tautomers) < 375
                          and res68.status == rdMolStandardize.TautomerEnumeratorStatus.Canceled)
-    hasCompleted = (len(res68.tautomers) == 295
+    hasCompleted = (len(res68.tautomers) == 375
                     and res68.status == rdMolStandardize.TautomerEnumeratorStatus.Completed)
     if hasReachedTimeout:
       print("Enumeration was canceled due to timeout (10 s)", file=sys.stderr)
@@ -634,14 +641,13 @@ chlorine	[Cl]
       enumerator.SetCallback(MyBrokenCallback2())
 
     # GitHub #4736
-    enumerator = rdMolStandardize.TautomerEnumerator(params)
+    enumerator = createV1Enumerator()
     enumerator.SetCallback(MyTautomerEnumeratorCallback(self, 50.0))
     enumerator_copy = rdMolStandardize.TautomerEnumerator(enumerator)
     res68 = enumerator.Enumerate(m68)
     res68_copy = enumerator_copy.Enumerate(m68)
     self.assertTrue(res68.status == res68_copy.status)
 
-
   def test17PickCanonicalCIPChangeOnChiralCenter(self):
 
     def get_canonical_taut(res):
