@@ -22,7 +22,7 @@
 #include <DataStructs/BitVects.h>
 #include <DataStructs/BitOps.h>
 
-#ifdef RDK_THREADSAFE_SSS
+#ifdef RDK_BUILD_THREADSAFE_SSS
 #include <mutex>
 #include <utility>
 #endif
@@ -141,12 +141,11 @@ static inline void parseAtomType(int val, int &atomic_num, bool &aromatic) {
     atomic_num = val;
   }
 }
-static inline bool getAtomTypeIsAromatic(int val) {
-  if (val > 1000) return true;
-  return false;
-}
+static inline bool getAtomTypeIsAromatic(int val) { return val > 1000; }
 static inline int getAtomTypeAtomicNum(int val) {
-  if (val > 1000) return val - 1000;
+  if (val > 1000) {
+    return val - 1000;
+  }
   return val;
 }
 
@@ -790,7 +789,7 @@ class RDKIT_GRAPHMOL_EXPORT RecursiveStructureQuery
   }
   unsigned int getSerialNumber() const { return d_serialNumber; }
 
-#ifdef RDK_THREADSAFE_SSS
+#ifdef RDK_BUILD_THREADSAFE_SSS
   std::mutex d_mutex;
 #endif
  private:
