@@ -91,6 +91,8 @@ struct RDKIT_RGROUPDECOMPOSITION_EXPORT RGroupDecompositionParameters {
   bool removeHydrogensPostMatch = true;
   //! allow labelled Rgroups of degree 2 or more
   bool allowNonTerminalRGroups = false;
+  // unlabelled core atoms can have multiple rgroups
+  bool allowMultipleRGroupsOnUnlabelled = false;
 
   double timeout = -1.0;  ///< timeout in seconds. <=0 indicates no timeout
 
@@ -100,6 +102,9 @@ struct RDKIT_RGROUPDECOMPOSITION_EXPORT RGroupDecompositionParameters {
   // Prepare the core for substructure searching and rgroup assignment
   bool prepareCore(RWMol &, const RWMol *alignCore);
 
+  // Add r groups to unlabelled atoms if allowMultipleRGroupsOnUnlabelled is set
+  void addDummyAtomsToUnlabelledCoreAtoms(RWMol &core);
+
   // Parameters specific to GA
 
   // GA population size or -1 to use best guess
@@ -114,7 +119,7 @@ struct RDKIT_RGROUPDECOMPOSITION_EXPORT RGroupDecompositionParameters {
   // Number of runs
   int gaNumberRuns = 1;
   // Sequential or parallel runs?
-#ifdef RDK_THREADSAFE_SSS
+#ifdef RDK_BUILD_THREADSAFE_SSS
   bool gaParallelRuns = true;
 #else
   bool gaParallelRuns = false;
@@ -142,6 +147,7 @@ class UsedLabelMap {
       d_map[rl.second] = std::make_pair(false, (rl.first > 0));
     }
   }
+  bool has(int label) const { return d_map.find(label) != d_map.end(); }
   bool getIsUsed(int label) const { return d_map.at(label).first; }
   void setIsUsed(int label) { d_map[label].first = true; }
   bool isUserDefined(int label) const { return d_map.at(label).second; }
@@ -206,7 +212,9 @@ RDKIT_RGROUPDECOMPOSITION_EXPORT unsigned int RGroupDecompose(
 
 inline bool checkForTimeout(const std::chrono::steady_clock::time_point &t0,
                             double timeout, bool throwOnTimeout = true) {
-  if (timeout <= 0) return false;
+  if (timeout <= 0) {
+    return false;
+  }
   auto t1 = std::chrono::steady_clock::now();
   std::chrono::duration<double> elapsed = t1 - t0;
   if (elapsed.count() >= timeout) {
