@@ -1,5 +1,6 @@
 //
-//  Copyright (C) 2017 Novartis Institutes for BioMedical Research
+//  Copyright (C) 2017-2022 Novartis Institutes for BioMedical Research and
+//  other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -22,6 +23,9 @@
 // #define VERBOSE 1
 
 namespace RDKit {
+
+extern const std::string _rgroupInputDummy;
+
 struct RGroupDecompData {
   // matches[mol_idx] == vector of potential matches
   std::map<int, RCore> cores;
@@ -53,19 +57,29 @@ struct RGroupDecompData {
   RGroupDecompData(const RWMol &inputCore,
                    RGroupDecompositionParameters inputParams)
       : params(std::move(inputParams)) {
-    cores[0] = RCore(inputCore);
+    addCore(inputCore);
     prepareCores();
   }
 
   RGroupDecompData(const std::vector<ROMOL_SPTR> &inputCores,
                    RGroupDecompositionParameters inputParams)
       : params(std::move(inputParams)) {
-    for (size_t i = 0; i < inputCores.size(); ++i) {
-      cores[i] = RCore(*inputCores[i]);
+    for (const auto &core : inputCores) {
+      addCore(*core);
     }
     prepareCores();
   }
 
+  void addCore(const ROMol &inputCore) {
+    if (params.allowMultipleRGroupsOnUnlabelled) {
+      RWMol core(inputCore);
+      params.addDummyAtomsToUnlabelledCoreAtoms(core);
+      cores[cores.size()] = RCore(core);
+    } else {
+      cores[cores.size()] = RCore(inputCore);
+    }
+  }
+
   void prepareCores() {
     for (auto &core : cores) {
       RWMol *alignCore = core.first ? cores[0].core.get() : nullptr;
@@ -77,7 +91,7 @@ struct RGroupDecompData {
   }
 
   void setRlabel(Atom *atom, int rlabel) {
-    PRECONDITION(rlabel != 0, "RLabels must be >0");
+    PRECONDITION(rlabel > 0, "RLabels must be >0");
     if (params.rgroupLabelling & AtomMap) {
       atom->setAtomMapNum(rlabel);
     }
@@ -89,10 +103,28 @@ struct RGroupDecompData {
     }
 
     if (params.rgroupLabelling & Isotope) {
-      atom->setIsotope(rlabel + 1);
+      atom->setIsotope(rlabel);
     }
   }
 
+  int getRlabel(Atom *atom) const {
+    if (params.rgroupLabelling & AtomMap) {
+      return atom->getAtomMapNum();
+    }
+    if (params.rgroupLabelling & Isotope) {
+      return atom->getIsotope();
+    }
+
+    if (params.rgroupLabelling & MDLRGroup) {
+      unsigned int label = 0;
+      if (atom->getPropIfPresent(common_properties::_MolFileRLabel, label)) {
+        return label;
+      }
+    }
+
+    CHECK_INVARIANT(0, "no valid r label found");
+  }
+
   double scoreFromPrunedData(const std::vector<size_t> &permutation,
                              bool reset = true) {
     PRECONDITION(
@@ -130,7 +162,8 @@ struct RGroupDecompData {
   }
 
   void prune() {  // prune all but the current "best" permutation of matches
-    PRECONDITION(permutation.size() <= matches.size(), "permutation.size() should be <= matches.size()");
+    PRECONDITION(permutation.size() <= matches.size(),
+                 "permutation.size() should be <= matches.size()");
     size_t offset = matches.size() - permutation.size();
     for (size_t mol_idx = 0; mol_idx < permutation.size(); ++mol_idx) {
       std::vector<RGroupMatch> keepVector;
@@ -380,7 +413,9 @@ struct RGroupDecompData {
           CHECK_INVARIANT(label != mappings.end(), "Unprocessed mapping");
 
           if (atom->getAtomicNum() == 0) {
-            setRlabel(atom, label->second);
+            if (!atom->hasProp(_rgroupInputDummy)) {
+              setRlabel(atom, label->second);
+            }
           } else if (atom->hasProp(RLABEL_CORE_INDEX)) {
             atom->setAtomicNum(0);
             setRlabel(atom, label->second);
@@ -403,7 +438,7 @@ struct RGroupDecompData {
     addAtoms(mol, atomsToAdd);
 
     if (params.removeHydrogensPostMatch) {
-      RDLog::BlockLogs blocker;
+      RDLog::LogStateSetter blocker;
       bool implicitOnly = false;
       bool updateExplicitCount = false;
       bool sanitize = false;
