@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2003-2021 Greg Landrum and other RDKit contributors
+//  Copyright (C) 2003-2022 Greg Landrum and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -22,6 +22,13 @@
 #include "Conformer.h"
 #include "SubstanceGroup.h"
 
+#ifdef RDK_USE_BOOST_SERIALIZATION
+#include <RDGeneral/BoostStartInclude.h>
+#include <boost/archive/text_oarchive.hpp>
+#include <boost/archive/text_iarchive.hpp>
+#include <RDGeneral/BoostEndInclude.h>
+#endif
+
 namespace RDKit {
 class QueryAtom;
 class QueryBond;
@@ -472,6 +479,24 @@ void ROMol::debugMol(std::ostream &str) const {
   while (bondItP.first != bondItP.second) {
     str << "\t" << *d_graph[*(bondItP.first++)] << std::endl;
   }
+
+  const auto &sgs = getSubstanceGroups(*this);
+  if (!sgs.empty()) {
+    str << "Substance Groups:" << std::endl;
+    for (const auto &sg : sgs) {
+      str << "\t" << sg << std::endl;
+    }
+  }
+
+  const auto &stgs = getStereoGroups();
+  if (!stgs.empty()) {
+    unsigned idx = 0;
+    str << "Stereo Groups:" << std::endl;
+    for (const auto &stg : stgs) {
+      str << "\t" << idx << ' ' << stg << std::endl;
+      ++idx;
+    }
+  }
 }
 
 // --------------------------------------------
@@ -667,4 +692,29 @@ unsigned int ROMol::addConformer(Conformer *conf, bool assignId) {
   return conf->getId();
 }
 
+#ifdef RDK_USE_BOOST_SERIALIZATION
+template <class Archive>
+void ROMol::save(Archive &ar, const unsigned int) const {
+  std::string pkl;
+  MolPickler::pickleMol(*this, pkl, PicklerOps::AllProps);
+  ar << pkl;
+}
+
+template <class Archive>
+void ROMol::load(Archive &ar, const unsigned int) {
+  std::string pkl;
+  ar >> pkl;
+
+  initMol();
+  numBonds = 0;
+  MolPickler::molFromPickle(pkl, *this, PicklerOps::AllProps);
+  numBonds = rdcast<unsigned int>(boost::num_edges(d_graph));
+}
+
+template RDKIT_GRAPHMOL_EXPORT void ROMol::save<boost::archive::text_oarchive>(
+    boost::archive::text_oarchive &, const unsigned int) const;
+template RDKIT_GRAPHMOL_EXPORT void ROMol::load<boost::archive::text_iarchive>(
+    boost::archive::text_iarchive &, const unsigned int);
+#endif
+
 }  // namespace RDKit
