@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2003-2018 Greg Landrum and Rational Discovery LLC
+//  Copyright (C) 2003-2022 Greg Landrum and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -19,6 +19,8 @@
 #define RD_ROMOL_H
 
 /// Std stuff
+#include <cstddef>
+#include <iterator>
 #include <utility>
 #include <map>
 
@@ -27,6 +29,10 @@
 #include <boost/graph/adjacency_list.hpp>
 #include <boost/smart_ptr.hpp>
 #include <boost/dynamic_bitset.hpp>
+
+#ifdef RDK_USE_BOOST_SERIALIZATION
+#include <boost/serialization/split_member.hpp>
+#endif
 #include <RDGeneral/BoostEndInclude.h>
 
 // our stuff
@@ -37,6 +43,7 @@
 #include "Conformer.h"
 #include "SubstanceGroup.h"
 #include "StereoGroup.h"
+#include "RingInfo.h"
 
 namespace RDKit {
 class SubstanceGroup;
@@ -110,6 +117,12 @@ struct CXXAtomIterator {
   Iterator vstart, vend;
 
   struct CXXAtomIter {
+    using iterator_category = std::forward_iterator_tag;
+    using difference_type = std::ptrdiff_t;
+    using value_type = Vertex;
+    using pointer = Vertex *;
+    using reference = Vertex &;
+
     Graph *graph;
     Iterator pos;
     Atom *current;
@@ -117,7 +130,7 @@ struct CXXAtomIterator {
     CXXAtomIter(Graph *graph, Iterator pos)
         : graph(graph), pos(pos), current(nullptr) {}
 
-    Vertex &operator*() {
+    reference operator*() {
       current = (*graph)[*pos];
       return current;
     }
@@ -146,6 +159,12 @@ struct CXXBondIterator {
   Iterator vstart, vend;
 
   struct CXXBondIter {
+    using iterator_category = std::forward_iterator_tag;
+    using difference_type = std::ptrdiff_t;
+    using value_type = Edge;
+    using pointer = Edge *;
+    using reference = Edge &;
+
     Graph *graph;
     Iterator pos;
     Bond *current;
@@ -153,7 +172,7 @@ struct CXXBondIterator {
     CXXBondIter(Graph *graph, Iterator pos)
         : graph(graph), pos(pos), current(nullptr) {}
 
-    Edge &operator*() {
+    reference operator*() {
       current = (*graph)[*pos];
       return current;
     }
@@ -183,7 +202,7 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
   //! \cond TYPEDEFS
 
   //! \name typedefs
-  //@{
+  //! @{
   typedef MolGraph::vertex_descriptor vertex_descriptor;
   typedef MolGraph::edge_descriptor edge_descriptor;
 
@@ -240,7 +259,7 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
   typedef CONF_SPTR_LIST_I ConformerIterator;
   typedef CONF_SPTR_LIST_CI ConstConformerIterator;
 
-  //@}
+  //! @}
   //! \endcond
 
   //! C++11 Range iterator
@@ -322,11 +341,73 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
   //! construct a molecule from a pickle string
   ROMol(const std::string &binStr, unsigned int propertyFlags);
 
+  ROMol(ROMol &&o) noexcept
+      : RDProps(std::move(o)),
+        d_graph(std::move(o.d_graph)),
+        d_atomBookmarks(std::move(o.d_atomBookmarks)),
+        d_bondBookmarks(std::move(o.d_bondBookmarks)),
+        d_confs(std::move(o.d_confs)),
+        d_sgroups(std::move(o.d_sgroups)),
+        d_stereo_groups(std::move(o.d_stereo_groups)),
+        numBonds(o.numBonds) {
+    for (auto atom : atoms()) {
+      atom->setOwningMol(this);
+    }
+    for (auto bond : bonds()) {
+      bond->setOwningMol(this);
+    }
+    for (auto conf : d_confs) {
+      conf->setOwningMol(this);
+    }
+    o.d_graph.clear();
+    o.numBonds = 0;
+    dp_ringInfo = std::exchange(o.dp_ringInfo, nullptr);
+    dp_delAtoms = std::exchange(o.dp_delAtoms, nullptr);
+    dp_delBonds = std::exchange(o.dp_delBonds, nullptr);
+  }
+  ROMol &operator=(ROMol &&o) noexcept {
+    if (this == &o) {
+      return *this;
+    }
+    RDProps::operator=(std::move(o));
+    d_graph = std::move(o.d_graph);
+    d_atomBookmarks = std::move(o.d_atomBookmarks);
+    d_bondBookmarks = std::move(o.d_bondBookmarks);
+    if (dp_ringInfo) {
+      delete dp_ringInfo;
+    }
+    dp_ringInfo = std::exchange(o.dp_ringInfo, nullptr);
+
+    d_confs = std::move(o.d_confs);
+    d_sgroups = std::move(o.d_sgroups);
+    d_stereo_groups = std::move(o.d_stereo_groups);
+    dp_delAtoms = std::exchange(o.dp_delAtoms, nullptr);
+    dp_delBonds = std::exchange(o.dp_delBonds, nullptr);
+    numBonds = o.numBonds;
+    o.numBonds = 0;
+
+    for (auto atom : atoms()) {
+      atom->setOwningMol(this);
+    }
+    for (auto bond : bonds()) {
+      bond->setOwningMol(this);
+    }
+    for (auto conf : d_confs) {
+      conf->setOwningMol(this);
+    }
+
+    o.d_graph.clear();
+    return *this;
+  }
+
+  ROMol &operator=(const ROMol &) =
+      delete;  // disable assignment, RWMol's support assignment
+
   virtual ~ROMol() { destroy(); }
 
-  //@}
+  //! @}
   //! \name Atoms
-  //@{
+  //! @{
 
   //! returns our number of atoms
   inline unsigned int getNumAtoms() const {
@@ -351,10 +432,10 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
   }
   //! returns the degree (number of neighbors) of an Atom in the graph
   unsigned int getAtomDegree(const Atom *at) const;
-  //@}
+  //! @}
 
   //! \name Bonds
-  //@{
+  //! @{
 
   //! returns our number of Bonds
   unsigned int getNumBonds(bool onlyHeavy = 1) const;
@@ -389,10 +470,10 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
                                rdcast<unsigned int>(idx2));
   }
 
-  //@}
+  //! @}
 
   //! \name Bookmarks
-  //@{
+  //! @{
 
   //! associates an Atom pointer with a bookmark
   void setAtomBookmark(Atom *at, int mark) {
@@ -445,10 +526,10 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
   //! returns a pointer to all of our bond \c bookmarks
   BOND_BOOKMARK_MAP *getBondBookmarks() { return &d_bondBookmarks; }
 
-  //@}
+  //! @}
 
   //! \name Conformers
-  //@{
+  //! @{
 
   //! return the conformer with a specified ID
   //! if the ID is negative the first conformation will be returned
@@ -481,7 +562,7 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
   }
 
   //! \name Topology
-  //@{
+  //! @{
 
   //! returns a pointer to our RingInfo structure
   //! <b>Note:</b> the client should not delete this.
@@ -589,10 +670,10 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
       \endcode
    */
   MolGraph const &getTopology() const { return d_graph; }
-  //@}
+  //! @}
 
   //! \name Iterators
-  //@{
+  //! @{
 
   //! get an AtomIterator pointing at our first Atom
   AtomIterator beginAtoms();
@@ -658,10 +739,10 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
 
   inline ConstConformerIterator endConformers() const { return d_confs.end(); }
 
-  //@}
+  //! @}
 
   //! \name Properties
-  //@{
+  //! @{
 
   //! clears all of our \c computed \c properties
   void clearComputedProps(bool includeRings = true) const;
@@ -674,13 +755,13 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
 
   bool needsUpdatePropertyCache() const;
 
-  //@}
+  //! @}
 
   //! \name Misc
-  //@{
+  //! @{
   //! sends some debugging info to a stream
   void debugMol(std::ostream &str) const;
-  //@}
+  //! @}
 
   Atom *operator[](const vertex_descriptor &v) { return d_graph[v]; }
   const Atom *operator[](const vertex_descriptor &v) const {
@@ -699,6 +780,26 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
     return d_stereo_groups;
   }
 
+  //! Sets groups of atoms with relative stereochemistry
+  /*!
+    \param stereo_groups the new set of stereo groups. All will be replaced.
+
+    Stereo groups are also called enhanced stereochemistry in the SDF/Mol3000
+    file format. stereo_groups should be std::move()ed into this function.
+  */
+  void setStereoGroups(std::vector<StereoGroup> stereo_groups);
+
+#ifdef RDK_USE_BOOST_SERIALIZATION
+  //! \name boost::serialization support
+  //! @{
+  template <class Archive>
+  void save(Archive &ar, const unsigned int version) const;
+  template <class Archive>
+  void load(Archive &ar, const unsigned int version);
+  BOOST_SERIALIZATION_SPLIT_MEMBER()
+  //! @}
+#endif
+
  private:
   MolGraph d_graph;
   ATOM_BOOKMARK_MAP d_atomBookmarks;
@@ -716,9 +817,6 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
       &getSubstanceGroups(const ROMol &);
   void clearSubstanceGroups() { d_sgroups.clear(); }
 
-  ROMol &operator=(
-      const ROMol &);  // disable assignment, RWMol's support assignment
-
  protected:
   unsigned int numBonds{0};
 #ifndef WIN32
@@ -750,14 +848,6 @@ class RDKIT_GRAPHMOL_EXPORT ROMol : public RDProps {
   */
   unsigned int addBond(Bond *bond, bool takeOwnership = false);
 
-  //! Sets groups of atoms with relative stereochemistry
-  /*!
-    \param stereo_groups the new set of stereo groups. All will be replaced.
-
-    Stereo groups are also called enhanced stereochemistry in the SDF/Mol3000
-    file format. stereo_groups should be std::move()ed into this function.
-  */
-  void setStereoGroups(std::vector<StereoGroup> stereo_groups);
   //! adds a Bond to our collection
   /*!
     \param bond          pointer to the Bond to add
