@@ -16,23 +16,23 @@ class TestCase(unittest.TestCase):
     m = Chem.MolFromSmiles('OCCc1ccccc1')
     mrg = rdRG.GenerateMolExtendedReducedGraph(m)
     mrg.UpdatePropertyCache(False)
-    self.failUnlessEqual('*cCCO', Chem.MolToSmiles(mrg))
+    self.assertEqual('*cCCO', Chem.MolToSmiles(mrg))
 
     m = Chem.MolFromSmiles('OCCC1CCCCC1')
     mrg = rdRG.GenerateMolExtendedReducedGraph(m)
     mrg.UpdatePropertyCache(False)
-    self.failUnlessEqual('*CCCO', Chem.MolToSmiles(mrg))
+    self.assertEqual('*CCCO', Chem.MolToSmiles(mrg))
 
   def test2(self):
     m = Chem.MolFromSmiles('OCCc1ccccc1')
     mrg = rdRG.GenerateMolExtendedReducedGraph(m)
     mrg.UpdatePropertyCache(False)
-    self.failUnlessEqual('*cCCO', Chem.MolToSmiles(mrg))
+    self.assertEqual('*cCCO', Chem.MolToSmiles(mrg))
 
     fp1 = rdRG.GenerateErGFingerprintForReducedGraph(mrg)
     fp2 = rdRG.GetErGFingerprint(m)
     md = max(abs(fp1 - fp2))
-    self.failUnless(md < 1e-4)
+    self.assertLess(md, 1e-4)
 
   def test3(self):
     m = Chem.MolFromSmiles('OCCc1ccccc1')
@@ -41,7 +41,7 @@ class TestCase(unittest.TestCase):
     fp2 = rdRG.GetErGFingerprint(m)
 
     md = max(abs(fp1 - fp2))
-    self.failUnlessAlmostEqual(0.0, md, 4)
+    self.assertAlmostEqual(0.0, md, 4)
 
   def test4(self):
     m = Chem.MolFromSmiles('OCCc1ccccc1')
@@ -49,7 +49,13 @@ class TestCase(unittest.TestCase):
     fp2 = rdRG.GetErGFingerprint(m, fuzzIncrement=0.1)
 
     md = max(abs(fp1 - fp2))
-    self.failUnlessAlmostEqual(0.2, md, 4)
+    self.assertAlmostEqual(0.2, md, 4)
+
+  def testCanRetrieveProp(self):
+    m = Chem.MolFromSmiles('OCCc1ccccc1')
+    mrg = rdRG.GenerateMolExtendedReducedGraph(m)
+    erg_types = [tuple(atom.GetPropsAsDict().get('_ErGAtomTypes')) for atom in mrg.GetAtoms()]
+    self.assertEqual(erg_types, [(0, 1), (), (), (), (5,)])
 
 
 if __name__ == '__main__':
