@@ -30,7 +30,9 @@ struct RDKIT_SMILESPARSE_EXPORT SmilesParserParams {
   bool parseName = true; /**< parse (and set) the molecule name as well */
   bool removeHs = true;  /**< remove Hs after constructing the molecule */
   bool useLegacyStereo =
-      true; /**< use the legacy stereochemistry perception code */
+      true; /**< \deprecated use the legacy stereochemistry perception code
+               DEPRECATED, please use Chirality::setUseLegacyStereoPerception()
+               instead. */
   bool skipCleanup =
       false; /**<  skip the final cleanup stage (for internal use) */
 };
