@@ -1,7 +1,7 @@
 #
 # Created by Gareth Jones on 5/30/2020.
 #
-# Copyright 2020 Schrodinger, Inc
+# Copyright 2020-2022 Schrodinger, Inc and other RDKit contributors
 #  @@ All Rights Reserved @@
 #  This file is part of the RDKit.
 #  The contents are covered by the terms of the BSD license
@@ -16,6 +16,7 @@ from rdkit import Chem, DataStructs
 from rdkit.Chem import rdTautomerQuery
 from unittest import TestCase, main
 import os
+import pickle
 
 
 class TautomerQueryTestCase(TestCase):
@@ -89,6 +90,20 @@ class TautomerQueryTestCase(TestCase):
     self.assertTrue(target.HasSubstructMatch(mol))
     self.assertTrue(tautomer_query.IsSubstructOf(target))
 
+  def test_serialization(self):
+    mol = Chem.MolFromSmiles("O=C1CCCCC1")
+    base_tautomer_query = rdTautomerQuery.TautomerQuery(mol)
+    for tautomer_query in (pickle.loads(pickle.dumps(base_tautomer_query)),
+                           rdTautomerQuery.TautomerQuery(base_tautomer_query.ToBinary())):
+      self.assertEqual(2, len(tautomer_query.GetTautomers()))
+      modified_bonds = tautomer_query.GetModifiedBonds()
+      self.assertEqual(3, len(modified_bonds))
+      modified_atoms = tautomer_query.GetModifiedAtoms()
+      self.assertEqual(3, len(modified_atoms))
+
+      target = Chem.MolFromSmiles("OC1=CCCC(CC)C1")
+      self.assertTrue(target.HasSubstructMatch(tautomer_query.GetTemplateMolecule()))
+
 
 if __name__ == "__main__":
   main()
