@@ -33,6 +33,18 @@ python::object bondRings(const RingInfo *self) {
   }
   return python::tuple(res);
 }
+python::object atomMembers(const RingInfo *self, unsigned int idx) {
+  return python::tuple(self->atomMembers(idx));
+}
+python::object bondMembers(const RingInfo *self, unsigned int idx) {
+  return python::tuple(self->bondMembers(idx));
+}
+python::object atomRingSizes(const RingInfo *self, unsigned int idx) {
+  return python::tuple(self->atomRingSizes(idx));
+}
+python::object bondRingSizes(const RingInfo *self, unsigned int idx) {
+  return python::tuple(self->bondRingSizes(idx));
+}
 
 #ifdef RDK_USE_URF
 python::object atomRingFamilies(const RingInfo *self) {
@@ -51,9 +63,10 @@ python::object bondRingFamilies(const RingInfo *self) {
 }
 #endif
 
-void addRing(RingInfo *self,python::object atomRing, python::object bondRing){
+void addRing(RingInfo *self, python::object atomRing, python::object bondRing) {
   unsigned int nAts = python::extract<unsigned int>(atomRing.attr("__len__")());
-  unsigned int nBnds = python::extract<unsigned int>(bondRing.attr("__len__")());
+  unsigned int nBnds =
+      python::extract<unsigned int>(bondRing.attr("__len__")());
   if (nAts != nBnds) {
     throw_value_error("list sizes must match");
   }
@@ -66,9 +79,9 @@ void addRing(RingInfo *self,python::object atomRing, python::object bondRing){
     aring[i] = python::extract<int>(atomRing[i])();
     bring[i] = python::extract<int>(bondRing[i])();
   }
-  self->addRing(aring,bring);
-}
+  self->addRing(aring, bring);
 }
+}  // namespace
 
 namespace RDKit {
 std::string classDoc = "contains information about a molecule's rings\n";
@@ -78,23 +91,34 @@ struct ringinfo_wrapper {
     python::class_<RingInfo>("RingInfo", classDoc.c_str(), python::no_init)
         .def("IsAtomInRingOfSize", &RingInfo::isAtomInRingOfSize)
         .def("MinAtomRingSize", &RingInfo::minAtomRingSize)
+        .def("AreAtomsInSameRing", &RingInfo::areAtomsInSameRing)
+        .def("AreAtomsInSameRingOfSize", &RingInfo::areAtomsInSameRingOfSize)
         .def("IsBondInRingOfSize", &RingInfo::isBondInRingOfSize)
         .def("MinBondRingSize", &RingInfo::minBondRingSize)
+        .def("AreBondsInSameRing", &RingInfo::areBondsInSameRing)
+        .def("AreBondsInSameRingOfSize", &RingInfo::areBondsInSameRingOfSize)
         .def("NumAtomRings", &RingInfo::numAtomRings)
         .def("NumBondRings", &RingInfo::numBondRings)
         .def("NumRings", &RingInfo::numRings)
         .def("AtomRings", atomRings)
         .def("BondRings", bondRings)
+        .def("AtomMembers", atomMembers)
+        .def("BondMembers", bondMembers)
+        .def("AtomRingSizes", atomRingSizes)
+        .def("BondRingSizes", bondRingSizes)
 #ifdef RDK_USE_URF
         .def("NumRingFamilies", &RingInfo::numRingFamilies)
         .def("NumRelevantCycles", &RingInfo::numRelevantCycles)
         .def("AtomRingFamilies", atomRingFamilies)
         .def("BondRingFamilies", bondRingFamilies)
-        .def("AreRingFamiliesInitialized", &RingInfo::areRingFamiliesInitialized)
+        .def("AreRingFamiliesInitialized",
+             &RingInfo::areRingFamiliesInitialized)
 #endif
-        .def("AddRing", addRing, (python::arg("self"),python::arg("atomIds"),python::arg("bondIds")),
-         "Adds a ring to the set. Be very careful with this operation.");
+        .def("AddRing", addRing,
+             (python::arg("self"), python::arg("atomIds"),
+              python::arg("bondIds")),
+             "Adds a ring to the set. Be very careful with this operation.");
   };
 };
-}  // end of namespace
+}  // namespace RDKit
 void wrap_ringinfo() { RDKit::ringinfo_wrapper::wrap(); }
