@@ -7,9 +7,12 @@
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
+#include <RDGeneral/export.h>
 #ifndef _RDCHEM_INCL_
 #define _RDCHEM_INCL_
 
+#define PY_ARRAY_UNIQUE_SYMBOL rdchem_array_API
+
 namespace RDKit {
 class ConformerException;
 }
