@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2003-2021 Greg Landrum and other RDKit contributors
+//  Copyright (C) 2003-2022 Greg Landrum and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -153,6 +153,29 @@ ROMol *MolFromMolBlock(python::object imolBlock, bool sanitize, bool removeHs,
   return static_cast<ROMol *>(newM);
 }
 
+ROMol *MolFromXYZFile(const char *xyzFilename) {
+  RWMol *newM = nullptr;
+  try {
+    newM = XYZFileToMol(xyzFilename);
+  } catch (RDKit::FileParseException &e) {
+    BOOST_LOG(rdWarningLog) << e.what() << std::endl;
+  } catch (...) {
+  }
+  return static_cast<ROMol *>(newM);
+}
+
+ROMol *MolFromXYZBlock(python::object ixyzBlock) {
+  std::istringstream inStream(pyObjectToString(ixyzBlock));
+  RWMol *newM = nullptr;
+  try {
+    newM = XYZDataStreamToMol(inStream);
+  } catch (RDKit::FileParseException &e) {
+    BOOST_LOG(rdWarningLog) << e.what() << std::endl;
+  } catch (...) {
+  }
+  return static_cast<ROMol *>(newM);
+}
+
 ROMol *MolFromSVG(python::object imolBlock, bool sanitize, bool removeHs) {
   RWMol *res = nullptr;
   res = RDKitSVGToMol(pyObjectToString(imolBlock), sanitize, removeHs);
@@ -573,6 +596,37 @@ python::tuple MolsFromPNGString(python::object png, const std::string &tag,
   return python::tuple(res);
 }
 
+python::object MolsFromCDXMLFile(const char *filename, bool sanitize, bool removeHs) {
+  std::vector<std::unique_ptr<RWMol>> mols;
+  try {
+    mols = CDXMLFileToMols(filename, sanitize, removeHs);
+  } catch (RDKit::BadFileException &e) {
+    PyErr_SetString(PyExc_IOError, e.what());
+    throw python::error_already_set();
+  } catch (RDKit::FileParseException &e) {
+    BOOST_LOG(rdWarningLog) << e.what() << std::endl;
+  } catch (...) {
+  }
+  python::list res;
+  for (auto &mol : mols) {
+    // take ownership of the data from the unique_ptr
+    ROMOL_SPTR sptr(static_cast<ROMol*>(mol.release()));
+    res.append(sptr);
+  }
+  return python::tuple(res);
+}
+
+python::tuple MolsFromCDXML(python::object cdxml, bool sanitize, bool removeHs) {
+  auto mols = CDXMLToMols(pyObjectToString(cdxml), sanitize, removeHs);
+  python::list res;
+  for (auto &mol : mols) {
+    // take ownership of the data from the unique_ptr
+    ROMOL_SPTR sptr(static_cast<ROMol*>(mol.release()));
+    res.append(sptr);
+  }
+  return python::tuple(res);
+}
+
 namespace {
 python::dict translateMetadata(
     const std::vector<std::pair<std::string, std::string>> &metadata) {
@@ -741,6 +795,34 @@ BOOST_PYTHON_MODULE(rdmolfiles) {
       docString.c_str(),
       python::return_value_policy<python::manage_new_object>());
 
+  docString =
+      "Construct a molecule from an XYZ file.\n\n\
+  ARGUMENTS:\n\
+\n\
+    - xyzname: name of the file to read\n\
+\n\
+  RETURNS:\n\
+\n\
+    a Mol object, None on failure.\n\
+\n";
+  python::def("MolFromXYZFile", RDKit::MolFromXYZFile,
+              (python::arg("xyzFileName")), docString.c_str(),
+              python::return_value_policy<python::manage_new_object>());
+
+  docString =
+      "Construct a molecule from an XYZ string.\n\n\
+  ARGUMENTS:\n\
+\n\
+    - xyzBlock: the XYZ data to read\n\
+\n\
+  RETURNS:\n\
+\n\
+    a Mol object, None on failure.\n\
+\n";
+  python::def("MolFromXYZBlock", RDKit::MolFromXYZBlock,
+              (python::arg("xyzFileName")), docString.c_str(),
+              python::return_value_policy<python::manage_new_object>());
+
   docString =
       "Construct a molecule from an RDKit-generate SVG string.\n\n\
   ARGUMENTS:\n\
@@ -1004,8 +1086,6 @@ BOOST_PYTHON_MODULE(rdmolfiles) {
                python::arg{"confId"} = -1, python::arg{"kekulize"} = true),
               docString.c_str());
 
-  //
-
   docString =
       "Returns a XYZ block for a molecule\n\
   ARGUMENTS:\n\
@@ -1055,10 +1135,10 @@ BOOST_PYTHON_MODULE(rdmolfiles) {
       .def_readwrite("removeHs", &RDKit::SmilesParserParams::removeHs,
                      "controls whether or not Hs are removed before the "
                      "molecule is returned")
-      .def_readwrite("useLegacyStereo",
-                     &RDKit::SmilesParserParams::useLegacyStereo,
-                     "controls whether or not the legacy stereochemistry "
-                     "perception code is used");
+      .def_readwrite(
+          "useLegacyStereo", &RDKit::SmilesParserParams::useLegacyStereo,
+          "controls whether or not the legacy stereochemistry "
+          "perception code is used. DEPRECATED: Please use Chem.SetUseLegacyStereoPerception() instead.");
   python::class_<RDKit::SmartsParserParams, boost::noncopyable>(
       "SmartsParserParams", "Parameters controlling SMARTS Parsing")
       .def_readwrite("debugParse", &RDKit::SmartsParserParams::debugParse,
@@ -1894,6 +1974,10 @@ BOOST_PYTHON_MODULE(rdmolfiles) {
 
      RETURNS:
        a Mol object, None on failure.)DOC";
+  
+  std::string cdxml_notes =
+    R"DOC()DOC";
+
   python::def(
       "MolFromPNGFile", MolFromPNGFile,
       (python::arg("filename"), python::arg("params") = python::object()),
@@ -1909,6 +1993,51 @@ BOOST_PYTHON_MODULE(rdmolfiles) {
                python::arg("params") = python::object()),
               "returns a tuple of molecules constructed from the PNG file");
 
+  docString =
+      R"DOC(Construct a molecule from a cdxml file.
+
+     Note that the CDXML format is large and complex, the RDKit doesn't support
+     full functionality, just the base ones required for molecule and
+     reaction parsing.
+
+     ARGUMENTS:
+
+       - filename: the cdxml filename
+
+       - sanitize: if True, sanitize the molecules [default True]
+       - removeHs: if True, convert explicit Hs into implicit Hs. [default True]
+
+     RETURNS:
+       an iterator of parsed Mol objects.)DOC";
+  
+  python::def("MolsFromCDXMLFile", MolsFromCDXMLFile,
+	      (python::arg("filename"), python::arg("sanitize")=true, python::arg("removeHs")=true),
+	      docString.c_str()
+);
+  
+  docString =
+      R"DOC(Construct a molecule from a cdxml string.
+
+     Note that the CDXML format is large and complex, the RDKit doesn't support
+     full functionality, just the base ones required for molecule and
+     reaction parsing.
+
+     ARGUMENTS:
+
+       - filename: the cdxml string
+
+       - sanitize: if True, sanitize the molecules [default True]
+       - removeHs: if True, convert explicit Hs into implicit Hs. [default True]
+
+
+     RETURNS:
+       an iterator of parsed Mol objects.)DOC";
+  
+  python::def("MolsFromCDXML", MolsFromCDXML,
+	      (python::arg("cdxml"), python::arg("sanitize")=true, python::arg("removeHs")=true),
+	      docString.c_str()
+	      );
+  
   docString =
       R"DOC(Adds molecular metadata to PNG data read from a file.
 
@@ -2020,7 +2149,7 @@ BOOST_PYTHON_MODULE(rdmolfiles) {
   wrap_tdtwriter();
   wrap_pdbwriter();
 
-#ifdef RDK_THREADSAFE_SSS
+#ifdef RDK_BUILD_THREADSAFE_SSS
   /********************************************************
    * MultithreadedMolWriter stuff
    *******************************************************/
