@@ -508,13 +508,13 @@ void testIssue2892580() {
 
   int massVal;
   massVal = queryAtomMass(a);
-  TEST_ASSERT(massVal == static_cast<int>(std::round(
-                             12.011 * massIntegerConversionFactor)));
+  TEST_ASSERT(massVal == static_cast<int>(
+                             std::round(12.011 * massIntegerConversionFactor)));
 
   a->setIsotope(13);
   massVal = queryAtomMass(a);
-  TEST_ASSERT(massVal == static_cast<int>(std::round(
-                             13.003 * massIntegerConversionFactor)));
+  TEST_ASSERT(massVal == static_cast<int>(
+                             std::round(13.003 * massIntegerConversionFactor)));
 
   delete a;
   BOOST_LOG(rdErrorLog) << "Done!" << std::endl;
