@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2004-2021 Greg Landrum and other RDKit contributors
+//  Copyright (C) 2004-2022 Greg Landrum and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -21,6 +21,14 @@
 #include <GraphMol/SmilesParse/SmartsWrite.h>
 #include <GraphMol/Substruct/SubstructMatch.h>
 
+#ifdef RDK_USE_BOOST_SERIALIZATION
+#include <RDGeneral/BoostStartInclude.h>
+#include <boost/archive/text_oarchive.hpp>
+#include <boost/archive/text_iarchive.hpp>
+#include <boost/archive/archive_exception.hpp>
+#include <RDGeneral/BoostEndInclude.h>
+#endif
+
 #include <RDGeneral/RDLog.h>
 
 #include <cstdlib>
@@ -1755,6 +1763,64 @@ void testAdditionalQueryPickling() {
   BOOST_LOG(rdErrorLog) << "\tdone" << std::endl;
 }
 
+void testBoostSerialization() {
+#ifdef RDK_USE_BOOST_SERIALIZATION
+  BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
+  BOOST_LOG(rdErrorLog) << "Testing boost::serialization integration"
+                        << std::endl;
+  auto m1 = "CCC"_smiles;
+  TEST_ASSERT(m1);
+  m1->setProp("foo", 1);
+  m1->getAtomWithIdx(0)->setProp("afoo", 2);
+  m1->getBondWithIdx(0)->setProp("bfoo", 3);
+  {
+    std::stringstream ss;
+    {
+      boost::archive::text_oarchive ar(ss);
+      ar << *m1;
+    }
+    ss.seekg(0);
+    ROMol m2;
+    {
+      boost::archive::text_iarchive ar(ss);
+      ar >> m2;
+    }
+    TEST_ASSERT(m2.getNumAtoms(m1->getNumAtoms()));
+    int pval = 0;
+    TEST_ASSERT(m2.getPropIfPresent("foo", pval));
+    TEST_ASSERT(pval == 1);
+    TEST_ASSERT(m2.getAtomWithIdx(0)->getPropIfPresent("afoo", pval));
+    TEST_ASSERT(pval == 2);
+    TEST_ASSERT(m2.getBondWithIdx(0)->getPropIfPresent("bfoo", pval));
+    TEST_ASSERT(pval == 3);
+  }
+
+  {  // test RWMol
+    RWMol m3(*m1);
+    std::stringstream ss;
+    {
+      boost::archive::text_oarchive ar(ss);
+      ar << m3;
+    }
+    ss.seekg(0);
+    RWMol m2;
+    {
+      boost::archive::text_iarchive ar(ss);
+      ar >> m2;
+    }
+    TEST_ASSERT(m2.getNumAtoms(m1->getNumAtoms()));
+    int pval = 0;
+    TEST_ASSERT(m2.getPropIfPresent("foo", pval));
+    TEST_ASSERT(pval == 1);
+    TEST_ASSERT(m2.getAtomWithIdx(0)->getPropIfPresent("afoo", pval));
+    TEST_ASSERT(pval == 2);
+    TEST_ASSERT(m2.getBondWithIdx(0)->getPropIfPresent("bfoo", pval));
+    TEST_ASSERT(pval == 3);
+  }
+  BOOST_LOG(rdErrorLog) << "\tdone" << std::endl;
+
+#endif
+}
 int main(int argc, char *argv[]) {
   RDLog::InitLogs();
   bool doLong = false;
@@ -1799,4 +1865,5 @@ int main(int argc, char *argv[]) {
   testConformerOptions();
   testPropertyOptions();
   testAdditionalQueryPickling();
+  testBoostSerialization();
 }
