@@ -28,10 +28,13 @@
 #include <GraphMol/Descriptors/MolDescriptors.h>
 #include <GraphMol/Fingerprints/MorganFingerprints.h>
 #include <GraphMol/Fingerprints/Fingerprints.h>
+#include <GraphMol/Fingerprints/AtomPairs.h>
 #include <GraphMol/Depictor/RDDepictor.h>
 #include <GraphMol/CIPLabeler/CIPLabeler.h>
 #include <GraphMol/Abbreviations/Abbreviations.h>
 #include <GraphMol/DistGeomHelpers/Embedder.h>
+#include <GraphMol/ChemReactions/Reaction.h>
+#include <GraphMol/ChemReactions/ReactionPickler.h>
 #include <DataStructs/BitOps.h>
 
 #include "common.h"
@@ -95,6 +98,15 @@ RWMol mol_from_pkl(const char *pkl, size_t pkl_sz) {
   return res;
 }
 
+ChemicalReaction rxn_from_pkl(const char *pkl, size_t pkl_sz) {
+  if (!pkl || !pkl_sz) {
+    return ChemicalReaction();
+  }
+  std::string rxn_pkl(pkl, pkl_sz);
+  ChemicalReaction res(rxn_pkl);
+  return res;
+}
+
 #ifdef PT_OPT_GET
 #undef PT_OPT_GET
 #endif
@@ -215,6 +227,17 @@ extern "C" char *get_svg(const char *pkl, size_t pkl_sz,
   return str_to_c(MinimalLib::mol_to_svg(mol, width, height, details_json));
 }
 
+extern "C" char *get_rxn_svg(const char *pkl, size_t pkl_sz,
+                             const char *details_json) {
+  if (!pkl || !pkl_sz) {
+    return nullptr;
+  }
+  auto rxn = rxn_from_pkl(pkl, pkl_sz);
+  unsigned int width = MinimalLib::d_defaultWidth;
+  unsigned int height = MinimalLib::d_defaultHeight;
+  return str_to_c(MinimalLib::rxn_to_svg(rxn, width, height, details_json));
+}
+
 extern "C" char *get_inchi(const char *pkl, size_t pkl_sz,
                            const char *details_json) {
   if (!pkl || !pkl_sz) {
@@ -280,6 +303,7 @@ extern "C" char *get_mol(const char *input, size_t *pkl_sz,
   MolPickler::pickleMol(*mol, pkl, propFlags);
   return str_to_c(pkl, pkl_sz);
 }
+
 extern "C" char *get_qmol(const char *input, size_t *pkl_sz,
                           const char *details_json) {
   std::unique_ptr<RWMol> mol{MinimalLib::qmol_from_input(input, details_json)};
@@ -291,8 +315,24 @@ extern "C" char *get_qmol(const char *input, size_t *pkl_sz,
   MolPickler::pickleMol(*mol, pkl);
   return str_to_c(pkl, pkl_sz);
 }
+
+extern "C" char *get_rxn(const char *input, size_t *pkl_sz,
+                         const char *details_json) {
+  std::unique_ptr<ChemicalReaction> rxn{
+      MinimalLib::rxn_from_input(input, details_json)};
+  if (!rxn) {
+    *pkl_sz = 0;
+    return NULL;
+  }
+  unsigned int propFlags = PicklerOps::PropertyPickleOptions::AllProps ^
+                           PicklerOps::PropertyPickleOptions::ComputedProps;
+  std::string pkl;
+  ReactionPickler::pickleReaction(*rxn, pkl, propFlags);
+  return str_to_c(pkl, pkl_sz);
+}
+
 extern "C" char *version() { return str_to_c(rdkitVersion); }
-#ifdef RDK_THREADSAFE_SSS
+#ifdef RDK_BUILD_THREADSAFE_SSS
 std::atomic_int logging_needs_init{1};
 #else
 short logging_needs_init = 1;
@@ -306,7 +346,7 @@ extern "C" void enable_logging() {
 }
 
 extern "C" void disable_logging() {
-#ifdef RDK_THREADSAFE_SSS
+#ifdef RDK_BUILD_THREADSAFE_SSS
   static std::atomic_int needs_init{1};
 #else
   static short needs_init = 1;
@@ -394,100 +434,13 @@ extern "C" char *get_descriptors(const char *mol_pkl, size_t mol_pkl_sz) {
   return str_to_c(MinimalLib::get_descriptors(mol));
 }
 
-namespace {
-std::unique_ptr<ExplicitBitVect> morgan_fp_helper(const char *mol_pkl,
-                                                  size_t mol_pkl_sz,
-                                                  const char *details_json) {
-  if (!mol_pkl || !mol_pkl_sz) {
-    return nullptr;
-  }
-  auto mol = mol_from_pkl(mol_pkl, mol_pkl_sz);
-
-  size_t radius = 2;
-  size_t nBits = 2048;
-  bool useChirality = false;
-  bool useBondTypes = true;
-  bool includeRedundantEnvironments = false;
-  bool onlyNonzeroInvariants = false;
-  if (details_json && strlen(details_json)) {
-    // FIX: this should eventually be moved somewhere else
-    std::istringstream ss;
-    ss.str(details_json);
-    boost::property_tree::ptree pt;
-    boost::property_tree::read_json(ss, pt);
-    PT_OPT_GET(radius);
-    PT_OPT_GET(nBits);
-    PT_OPT_GET(useChirality);
-    PT_OPT_GET(useBondTypes);
-    PT_OPT_GET(includeRedundantEnvironments);
-    PT_OPT_GET(onlyNonzeroInvariants);
-  }
-  auto fp = MorganFingerprints::getFingerprintAsBitVect(
-      mol, radius, nBits, nullptr, nullptr, useChirality, useBondTypes,
-      onlyNonzeroInvariants, nullptr, includeRedundantEnvironments);
-  return std::unique_ptr<ExplicitBitVect>{fp};
-}
-
-std::unique_ptr<ExplicitBitVect> rdkit_fp_helper(const char *mol_pkl,
-                                                 size_t mol_pkl_sz,
-                                                 const char *details_json) {
-  if (!mol_pkl || !mol_pkl_sz) {
-    return nullptr;
-  }
-  auto mol = mol_from_pkl(mol_pkl, mol_pkl_sz);
-  unsigned int minPath = 1;
-  unsigned int maxPath = 7;
-  unsigned int nBits = 2048;
-  unsigned int nBitsPerHash = 2;
-  bool useHs = true;
-  bool branchedPaths = true;
-  bool useBondOrder = true;
-  if (details_json && strlen(details_json)) {
-    // FIX: this should eventually be moved somewhere else
-    std::istringstream ss;
-    ss.str(details_json);
-    boost::property_tree::ptree pt;
-    boost::property_tree::read_json(ss, pt);
-    PT_OPT_GET(minPath);
-    PT_OPT_GET(maxPath);
-    PT_OPT_GET(nBits);
-    PT_OPT_GET(nBitsPerHash);
-    PT_OPT_GET(useHs);
-    PT_OPT_GET(branchedPaths);
-    PT_OPT_GET(useBondOrder);
-  }
-  auto fp = RDKFingerprintMol(mol, minPath, maxPath, nBits, nBitsPerHash, useHs,
-                              0, 128, branchedPaths, useBondOrder);
-  return std::unique_ptr<ExplicitBitVect>{fp};
-}
-
-std::unique_ptr<ExplicitBitVect> pattern_fp_helper(const char *mol_pkl,
-                                                   size_t mol_pkl_sz,
-                                                   const char *details_json) {
-  if (!mol_pkl || !mol_pkl_sz) {
-    return nullptr;
-  }
-  auto mol = mol_from_pkl(mol_pkl, mol_pkl_sz);
-  unsigned int nBits = 2048;
-  bool tautomericFingerprint = false;
-  if (details_json && strlen(details_json)) {
-    // FIX: this should eventually be moved somewhere else
-    std::istringstream ss;
-    ss.str(details_json);
-    boost::property_tree::ptree pt;
-    boost::property_tree::read_json(ss, pt);
-    PT_OPT_GET(nBits);
-    PT_OPT_GET(tautomericFingerprint);
-  }
-  auto fp = PatternFingerprintMol(mol, nBits, nullptr, nullptr,
-                                  tautomericFingerprint);
-  return std::unique_ptr<ExplicitBitVect>{fp};
-}
-}  // namespace
-
 extern "C" char *get_morgan_fp(const char *mol_pkl, size_t mol_pkl_sz,
                                const char *details_json) {
-  auto fp = morgan_fp_helper(mol_pkl, mol_pkl_sz, details_json);
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::morgan_fp_as_bitvect(mol_from_pkl(mol_pkl, mol_pkl_sz),
+                                             details_json);
   auto res = BitVectToText(*fp);
   return str_to_c(res);
 }
@@ -495,14 +448,22 @@ extern "C" char *get_morgan_fp(const char *mol_pkl, size_t mol_pkl_sz,
 extern "C" char *get_morgan_fp_as_bytes(const char *mol_pkl, size_t mol_pkl_sz,
                                         size_t *nbytes,
                                         const char *details_json) {
-  auto fp = morgan_fp_helper(mol_pkl, mol_pkl_sz, details_json);
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::morgan_fp_as_bitvect(mol_from_pkl(mol_pkl, mol_pkl_sz),
+                                             details_json);
   auto res = BitVectToBinaryText(*fp);
   return str_to_c(res, nbytes);
 }
 
 extern "C" char *get_rdkit_fp(const char *mol_pkl, size_t mol_pkl_sz,
                               const char *details_json) {
-  auto fp = rdkit_fp_helper(mol_pkl, mol_pkl_sz, details_json);
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::rdkit_fp_as_bitvect(mol_from_pkl(mol_pkl, mol_pkl_sz),
+                                            details_json);
   auto res = BitVectToText(*fp);
   return str_to_c(res);
 }
@@ -510,14 +471,22 @@ extern "C" char *get_rdkit_fp(const char *mol_pkl, size_t mol_pkl_sz,
 extern "C" char *get_rdkit_fp_as_bytes(const char *mol_pkl, size_t mol_pkl_sz,
                                        size_t *nbytes,
                                        const char *details_json) {
-  auto fp = rdkit_fp_helper(mol_pkl, mol_pkl_sz, details_json);
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::rdkit_fp_as_bitvect(mol_from_pkl(mol_pkl, mol_pkl_sz),
+                                            details_json);
   auto res = BitVectToBinaryText(*fp);
   return str_to_c(res, nbytes);
 }
 
 extern "C" char *get_pattern_fp(const char *mol_pkl, size_t mol_pkl_sz,
                                 const char *details_json) {
-  auto fp = pattern_fp_helper(mol_pkl, mol_pkl_sz, details_json);
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::pattern_fp_as_bitvect(mol_from_pkl(mol_pkl, mol_pkl_sz),
+                                              details_json);
   auto res = BitVectToText(*fp);
   return str_to_c(res);
 }
@@ -525,17 +494,103 @@ extern "C" char *get_pattern_fp(const char *mol_pkl, size_t mol_pkl_sz,
 extern "C" char *get_pattern_fp_as_bytes(const char *mol_pkl, size_t mol_pkl_sz,
                                          size_t *nbytes,
                                          const char *details_json) {
-  auto fp = pattern_fp_helper(mol_pkl, mol_pkl_sz, details_json);
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::pattern_fp_as_bitvect(mol_from_pkl(mol_pkl, mol_pkl_sz),
+                                              details_json);
   auto res = BitVectToBinaryText(*fp);
   return str_to_c(res, nbytes);
 }
 
+extern "C" char *get_topological_torsion_fp(const char *mol_pkl,
+                                            size_t mol_pkl_sz,
+                                            const char *details_json) {
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::topological_torsion_fp_as_bitvect(
+      mol_from_pkl(mol_pkl, mol_pkl_sz), details_json);
+  auto res = BitVectToText(*fp);
+  return str_to_c(res);
+}
+
+extern "C" char *get_topological_torsion_fp_as_bytes(const char *mol_pkl,
+                                                     size_t mol_pkl_sz,
+                                                     size_t *nbytes,
+                                                     const char *details_json) {
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::topological_torsion_fp_as_bitvect(
+      mol_from_pkl(mol_pkl, mol_pkl_sz), details_json);
+  auto res = BitVectToBinaryText(*fp);
+  return str_to_c(res, nbytes);
+}
+
+extern "C" char *get_atom_pair_fp(const char *mol_pkl, size_t mol_pkl_sz,
+                                  const char *details_json) {
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::atom_pair_fp_as_bitvect(
+      mol_from_pkl(mol_pkl, mol_pkl_sz), details_json);
+  auto res = BitVectToText(*fp);
+  return str_to_c(res);
+}
+
+extern "C" char *get_atom_pair_fp_as_bytes(const char *mol_pkl,
+                                           size_t mol_pkl_sz, size_t *nbytes,
+                                           const char *details_json) {
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::atom_pair_fp_as_bitvect(
+      mol_from_pkl(mol_pkl, mol_pkl_sz), details_json);
+  auto res = BitVectToBinaryText(*fp);
+  return str_to_c(res, nbytes);
+}
+
+#ifdef RDK_BUILD_AVALON_SUPPORT
+extern "C" char *get_avalon_fp(const char *mol_pkl, size_t mol_pkl_sz,
+                               const char *details_json) {
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::avalon_fp_as_bitvect(mol_from_pkl(mol_pkl, mol_pkl_sz),
+                                             details_json);
+  auto res = BitVectToText(*fp);
+  return str_to_c(res);
+}
+
+extern "C" char *get_avalon_fp_as_bytes(const char *mol_pkl, size_t mol_pkl_sz,
+                                        size_t *nbytes,
+                                        const char *details_json) {
+  if (!mol_pkl || !mol_pkl_sz) {
+    return nullptr;
+  }
+  auto fp = MinimalLib::avalon_fp_as_bitvect(mol_from_pkl(mol_pkl, mol_pkl_sz),
+                                             details_json);
+  auto res = BitVectToBinaryText(*fp);
+  return str_to_c(res, nbytes);
+}
+#endif
+
 extern "C" void prefer_coordgen(short val) {
 #ifdef RDK_BUILD_COORDGEN_SUPPORT
   RDDepict::preferCoordGen = val;
 #endif
 };
 
+extern "C" short has_coords(char *mol_pkl, size_t mol_pkl_sz) {
+  short res = 0;
+  if (mol_pkl && mol_pkl_sz) {
+    auto mol = mol_from_pkl(mol_pkl, mol_pkl_sz);
+    res = (mol.getNumConformers() > 0);
+  }
+  return res;
+}
+
 extern "C" short set_2d_coords(char **mol_pkl, size_t *mol_pkl_sz) {
   if (!mol_pkl || !mol_pkl_sz || !*mol_pkl || !*mol_pkl_sz) {
     return 0;
@@ -550,7 +605,11 @@ extern "C" short set_2d_coords(char **mol_pkl, size_t *mol_pkl_sz) {
 extern "C" short set_2d_coords_aligned(char **mol_pkl, size_t *mol_pkl_sz,
                                        const char *template_pkl,
                                        size_t template_sz,
-                                       const char *details_json) {
+                                       const char *details_json,
+                                       char **match_json) {
+  if (match_json) {
+    *match_json = nullptr;
+  }
   if (!mol_pkl || !mol_pkl_sz || !*mol_pkl || !*mol_pkl_sz || !template_pkl ||
       !template_sz || !template_pkl || !template_sz) {
     return 0;
@@ -560,36 +619,14 @@ extern "C" short set_2d_coords_aligned(char **mol_pkl, size_t *mol_pkl_sz,
     return 0;
   }
   auto mol = mol_from_pkl(*mol_pkl, *mol_pkl_sz);
-  bool useCoordGen = true;
-  bool allowRGroups = false;
-  bool acceptFailure = true;
-  if (details_json && strlen(details_json)) {
-    std::istringstream ss;
-    ss.str(details_json);
-    boost::property_tree::ptree pt;
-    boost::property_tree::read_json(ss, pt);
-    PT_OPT_GET(useCoordGen);
-    PT_OPT_GET(allowRGroups);
-    PT_OPT_GET(acceptFailure);
-  }
-#ifdef RDK_BUILD_COORDGEN_SUPPORT
-  bool oprefer = RDDepict::preferCoordGen;
-  RDDepict::preferCoordGen = useCoordGen;
-#endif
-
-  int confId = -1;
-  // always accept failure in the original call because
-  // we detect it afterwards
-  bool acceptOrigFailure = true;
-  auto match = RDDepict::generateDepictionMatching2DStructure(
-      mol, templ, confId, nullptr, acceptOrigFailure, false, allowRGroups);
-#ifdef RDK_BUILD_COORDGEN_SUPPORT
-  RDDepict::preferCoordGen = oprefer;
-#endif
-  if (match.empty() && !acceptFailure) {
+  auto match = MinimalLib::generate_aligned_coords(mol, templ, details_json);
+  if (match.empty()) {
     return 0;
   } else {
     mol_to_pkl(mol, mol_pkl, mol_pkl_sz);
+    if (match_json) {
+      *match_json = str_to_c(match);
+    }
     return 1;
   }
 };
