@@ -16,6 +16,7 @@
 #include <RDGeneral/versions.h>
 #include <GraphMol/RDKitBase.h>
 #include <GraphMol/MolPickler.h>
+#include <GraphMol/Chirality.h>
 #include <GraphMol/SmilesParse/SmilesParse.h>
 #include <GraphMol/SmilesParse/SmartsWrite.h>
 #include <GraphMol/FileParsers/FileParsers.h>
@@ -26,9 +27,7 @@
 #include <GraphMol/SubstructLibrary/SubstructLibrary.h>
 #include <GraphMol/Descriptors/Property.h>
 #include <GraphMol/Descriptors/MolDescriptors.h>
-#include <GraphMol/Fingerprints/MorganFingerprints.h>
 #include <GraphMol/MolInterchange/MolInterchange.h>
-#include <GraphMol/Depictor/RDDepictor.h>
 #include <GraphMol/CIPLabeler/CIPLabeler.h>
 #include <GraphMol/Abbreviations/Abbreviations.h>
 #include <GraphMol/MolTransforms/MolTransforms.h>
@@ -45,54 +44,106 @@ namespace rj = rapidjson;
 
 using namespace RDKit;
 
+namespace {
+std::string mappingToJsonArray(const ROMol &mol) {
+  std::vector<unsigned int> atomMapping;
+  std::vector<unsigned int> bondMapping;
+  mol.getPropIfPresent(Abbreviations::common_properties::origAtomMapping,
+                       atomMapping);
+  mol.getPropIfPresent(Abbreviations::common_properties::origBondMapping,
+                       bondMapping);
+  rj::Document doc;
+  doc.SetObject();
+  auto &alloc = doc.GetAllocator();
+  rj::Value rjAtoms(rj::kArrayType);
+  for (auto i : atomMapping) {
+    rjAtoms.PushBack(i, alloc);
+  }
+  doc.AddMember("atoms", rjAtoms, alloc);
+
+  rj::Value rjBonds(rj::kArrayType);
+  for (auto i : bondMapping) {
+    rjBonds.PushBack(i, alloc);
+  }
+  doc.AddMember("bonds", rjBonds, alloc);
+  rj::StringBuffer buffer;
+  rj::Writer<rj::StringBuffer> writer(buffer);
+  doc.Accept(writer);
+  std::string res = buffer.GetString();
+  return res;
+}
+}  // end of anonymous namespace
+
 std::string JSMol::get_smiles() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   return MolToSmiles(*d_mol);
 }
 std::string JSMol::get_cxsmiles() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   return MolToCXSmiles(*d_mol);
 }
 std::string JSMol::get_smarts() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   return MolToSmarts(*d_mol);
 }
 std::string JSMol::get_cxsmarts() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   return MolToCXSmarts(*d_mol);
 }
 std::string JSMol::get_svg(int w, int h) const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   return MinimalLib::mol_to_svg(*d_mol, w, h);
 }
 std::string JSMol::get_svg_with_highlights(const std::string &details) const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
 
-  int w = MinimalLib::d_defaultWidth;
-  int h = MinimalLib::d_defaultHeight;
+  int w = d_defaultWidth;
+  int h = d_defaultHeight;
   return MinimalLib::mol_to_svg(*d_mol, w, h, details);
 }
 
 std::string JSMol::get_inchi() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   ExtraInchiReturnValues rv;
   return MolToInchi(*d_mol, rv);
 }
 std::string JSMol::get_molblock() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   return MolToMolBlock(*d_mol);
 }
 std::string JSMol::get_v3Kmolblock() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   return MolToV3KMolBlock(*d_mol);
 }
 std::string JSMol::get_json() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   return MolInterchange::MolToJSONData(*d_mol);
 }
 
 std::string JSMol::get_pickle() const {
-  if (!d_mol) return std::string();
+  if (!d_mol) {
+    return "";
+  }
   std::string pickle;
   MolPickler::pickleMol(*d_mol, pickle);
   return pickle;
@@ -100,7 +151,9 @@ std::string JSMol::get_pickle() const {
 
 std::string JSMol::get_substruct_match(const JSMol &q) const {
   std::string res = "{}";
-  if (!d_mol || !q.d_mol) return res;
+  if (!d_mol || !q.d_mol) {
+    return res;
+  }
 
   MatchVectType match;
   if (SubstructMatch(*d_mol, *(q.d_mol), match)) {
@@ -118,7 +171,9 @@ std::string JSMol::get_substruct_match(const JSMol &q) const {
 
 std::string JSMol::get_substruct_matches(const JSMol &q) const {
   std::string res = "{}";
-  if (!d_mol || !q.d_mol) return res;
+  if (!d_mol || !q.d_mol) {
+    return res;
+  }
 
   auto matches = SubstructMatch(*d_mol, (*q.d_mol));
   if (!matches.empty()) {
@@ -141,44 +196,134 @@ std::string JSMol::get_substruct_matches(const JSMol &q) const {
 }
 
 std::string JSMol::get_descriptors() const {
-  if (!d_mol) return "{}";
+  if (!d_mol) {
+    return "{}";
+  }
   return MinimalLib::get_descriptors(*d_mol);
 }
 
-std::string JSMol::get_morgan_fp(unsigned int radius,
-                                 unsigned int fplen) const {
-  if (!d_mol) return "";
-  std::unique_ptr<ExplicitBitVect> fp(
-      MorganFingerprints::getFingerprintAsBitVect(*d_mol, radius, fplen));
+std::string JSMol::get_morgan_fp(const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::morgan_fp_as_bitvect(*d_mol, details.c_str());
   std::string res = BitVectToText(*fp);
   return res;
 }
 
-std::string JSMol::get_morgan_fp_as_binary_text(unsigned int radius,
-                                                unsigned int fplen) const {
-  if (!d_mol) return "";
-  std::unique_ptr<ExplicitBitVect> fp(
-      MorganFingerprints::getFingerprintAsBitVect(*d_mol, radius, fplen));
+std::string JSMol::get_morgan_fp_as_binary_text(
+    const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::morgan_fp_as_bitvect(*d_mol, details.c_str());
   std::string res = BitVectToBinaryText(*fp);
   return res;
 }
 
-std::string JSMol::get_pattern_fp(unsigned int fplen) const {
-  if (!d_mol) return "";
-  std::unique_ptr<ExplicitBitVect> fp(PatternFingerprintMol(*d_mol, fplen));
+std::string JSMol::get_pattern_fp(const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::pattern_fp_as_bitvect(*d_mol, details.c_str());
   std::string res = BitVectToText(*fp);
   return res;
 }
 
-std::string JSMol::get_pattern_fp_as_binary_text(unsigned int fplen) const {
-  if (!d_mol) return "";
-  std::unique_ptr<ExplicitBitVect> fp(PatternFingerprintMol(*d_mol, fplen));
+std::string JSMol::get_pattern_fp_as_binary_text(
+    const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::pattern_fp_as_bitvect(*d_mol, details.c_str());
   std::string res = BitVectToBinaryText(*fp);
   return res;
 }
 
+std::string JSMol::get_topological_torsion_fp(
+    const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp =
+      MinimalLib::topological_torsion_fp_as_bitvect(*d_mol, details.c_str());
+  std::string res = BitVectToText(*fp);
+  return res;
+}
+
+std::string JSMol::get_topological_torsion_fp_as_binary_text(
+    const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp =
+      MinimalLib::topological_torsion_fp_as_bitvect(*d_mol, details.c_str());
+  std::string res = BitVectToBinaryText(*fp);
+  return res;
+}
+
+std::string JSMol::get_rdkit_fp(const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::rdkit_fp_as_bitvect(*d_mol, details.c_str());
+  std::string res = BitVectToText(*fp);
+  return res;
+}
+
+std::string JSMol::get_rdkit_fp_as_binary_text(
+    const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::rdkit_fp_as_bitvect(*d_mol, details.c_str());
+  std::string res = BitVectToBinaryText(*fp);
+  return res;
+}
+
+std::string JSMol::get_atom_pair_fp(const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::atom_pair_fp_as_bitvect(*d_mol, details.c_str());
+  std::string res = BitVectToText(*fp);
+  return res;
+}
+
+std::string JSMol::get_atom_pair_fp_as_binary_text(
+    const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::atom_pair_fp_as_bitvect(*d_mol, details.c_str());
+  std::string res = BitVectToBinaryText(*fp);
+  return res;
+}
+
+#ifdef RDK_BUILD_AVALON_SUPPORT
+std::string get_avalon_fp(const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::avalon_fp_as_bitvect(*d_mol, details.c_str());
+  std::string res = BitVectToText(*fp);
+  return res;
+}
+
+std::string get_avalon_fp_as_binary_text(const std::string &details) const {
+  if (!d_mol) {
+    return "";
+  }
+  auto fp = MinimalLib::avalon_fp_as_bitvect(*d_mol, details.c_str());
+  std::string res = BitVectToBinaryText(*fp);
+  return res;
+}
+#endif
+
 std::string JSMol::get_stereo_tags() const {
-  if (!d_mol) return "{}";
+  if (!d_mol) {
+    return "{}";
+  }
   rj::Document doc;
   doc.SetObject();
 
@@ -233,7 +378,9 @@ std::string JSMol::get_stereo_tags() const {
 }
 
 std::string JSMol::get_aromatic_form() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
 
   RWMol molCopy(*d_mol);
   MolOps::setAromaticity(molCopy);
@@ -245,7 +392,9 @@ std::string JSMol::get_aromatic_form() const {
 }
 
 std::string JSMol::get_kekule_form() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
 
   RWMol molCopy(*d_mol);
   MolOps::Kekulize(molCopy);
@@ -257,7 +406,9 @@ std::string JSMol::get_kekule_form() const {
 }
 
 bool JSMol::set_new_coords(bool useCoordGen) {
-  if (!d_mol) return false;
+  if (!d_mol) {
+    return false;
+  }
 
 #ifdef RDK_BUILD_COORDGEN_SUPPORT
   bool oprefer = RDDepict::preferCoordGen;
@@ -272,7 +423,9 @@ bool JSMol::set_new_coords(bool useCoordGen) {
 }
 
 std::string JSMol::get_new_coords(bool useCoordGen) const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
 
   RWMol molCopy(*d_mol);
 
@@ -288,8 +441,35 @@ std::string JSMol::get_new_coords(bool useCoordGen) const {
   return MolToMolBlock(molCopy);
 }
 
+bool JSMol::has_prop(const std::string &key) const {
+  if (!d_mol) return false;
+  return d_mol->hasProp(key);
+}
+
+std::vector<std::string> JSMol::get_prop_list(bool includePrivate,
+                                              bool includeComputed) const {
+  if (!d_mol) return std::vector<std::string>();
+  return d_mol->getPropList(includePrivate, includeComputed);
+}
+
+bool JSMol::set_prop(const std::string &key, const std::string &val,
+                     bool computed) {
+  if (!d_mol) return false;
+  d_mol->setProp(key, val, computed);
+  return true;
+}
+
+std::string JSMol::get_prop(const std::string &key) const {
+  if (!d_mol || !d_mol->hasProp(key)) return "";
+  std::string val;
+  d_mol->getProp(key, val);
+  return val;
+}
+
 std::string JSMol::remove_hs() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
 
   RWMol molCopy(*d_mol);
   MolOps::removeAllHs(molCopy);
@@ -301,7 +481,9 @@ std::string JSMol::remove_hs() const {
 }
 
 std::string JSMol::add_hs() const {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
 
   RWMol molCopy(*d_mol);
   MolOps::addHs(molCopy);
@@ -313,7 +495,9 @@ std::string JSMol::add_hs() const {
 }
 
 std::string JSMol::condense_abbreviations(double maxCoverage, bool useLinkers) {
-  if (!d_mol) return "";
+  if (!d_mol) {
+    return "";
+  }
   if (!useLinkers) {
     Abbreviations::condenseMolAbbreviations(
         *d_mol, Abbreviations::Utils::getDefaultAbbreviations(), maxCoverage);
@@ -321,7 +505,7 @@ std::string JSMol::condense_abbreviations(double maxCoverage, bool useLinkers) {
     Abbreviations::condenseMolAbbreviations(
         *d_mol, Abbreviations::Utils::getDefaultLinkers(), maxCoverage);
   }
-  return "";
+  return mappingToJsonArray(*d_mol);
 }
 
 std::string JSMol::condense_abbreviations_from_defs(
@@ -342,49 +526,47 @@ std::string JSMol::condense_abbreviations_from_defs(
     }
   }
   Abbreviations::condenseMolAbbreviations(*d_mol, abbrevs, maxCoverage);
+  return mappingToJsonArray(*d_mol);
 }
 
 std::string JSMol::generate_aligned_coords(const JSMol &templateMol,
-                                           bool useCoordGen, bool allowRGroups,
-                                           bool acceptFailure) {
-  std::string res;
-  if (!d_mol || !templateMol.d_mol || !templateMol.d_mol->getNumConformers())
-    return res;
-
-#ifdef RDK_BUILD_COORDGEN_SUPPORT
-  bool oprefer = RDDepict::preferCoordGen;
-  RDDepict::preferCoordGen = useCoordGen;
-#endif
-  RDKit::ROMol *refPattern = nullptr;
-  int confId = -1;
-  RDKit::MatchVectType match = RDDepict::generateDepictionMatching2DStructure(
-      *d_mol, *(templateMol.d_mol), confId, refPattern, acceptFailure, false,
-      allowRGroups);
-  if (!match.empty()) {
-    rj::Document doc;
-    doc.SetObject();
-    MinimalLib::get_sss_json(*d_mol, *templateMol.d_mol, match, doc, doc);
-    rj::StringBuffer buffer;
-    rj::Writer<rj::StringBuffer> writer(buffer);
-    doc.Accept(writer);
-    res = buffer.GetString();
-  } else {
-    res = "{}";
+                                           const std::string &details) {
+  if (!d_mol || !templateMol.d_mol || !templateMol.d_mol->getNumConformers()) {
+    return "";
   }
-#ifdef RDK_BUILD_COORDGEN_SUPPORT
-  RDDepict::preferCoordGen = oprefer;
-#endif
-  return res;
+  return MinimalLib::generate_aligned_coords(*d_mol, *templateMol.d_mol,
+                                             details.c_str());
 }
 
 double JSMol::normalize_depiction(int canonicalize, double scaleFactor) {
-  if (!d_mol || !d_mol->getNumAtoms() || !d_mol->getNumConformers()) return -1.;
+  if (!d_mol || !d_mol->getNumConformers()) {
+    return -1.;
+  }
   return RDDepict::normalizeDepiction(*d_mol, -1, canonicalize, scaleFactor);
 }
 
-void JSMol::straighten_depiction() {
-  if (!d_mol || !d_mol->getNumAtoms() || !d_mol->getNumConformers()) return;
-  RDDepict::straightenDepiction(*d_mol, -1);
+void JSMol::straighten_depiction(bool minimizeRotation) {
+  if (!d_mol || !d_mol->getNumConformers()) {
+    return;
+  }
+  RDDepict::straightenDepiction(*d_mol, -1, minimizeRotation);
+}
+
+std::string JSReaction::get_svg(int w, int h) const {
+  if (!d_rxn) {
+    return "";
+  }
+  return MinimalLib::rxn_to_svg(*d_rxn, w, h);
+}
+std::string JSReaction::get_svg_with_highlights(
+    const std::string &details) const {
+  if (!d_rxn) {
+    return "";
+  }
+
+  int w = d_defaultWidth;
+  int h = d_defaultHeight;
+  return MinimalLib::rxn_to_svg(*d_rxn, w, h, details);
 }
 
 JSSubstructLibrary::JSSubstructLibrary(unsigned int num_bits)
@@ -466,12 +648,12 @@ std::string get_inchikey_for_inchi(const std::string &input) {
 }
 
 JSMol *get_mol_copy(const JSMol &other) {
-  RWMol *mol = new RWMol(*other.d_mol);
+  auto mol = new RWMol(*other.d_mol);
   return new JSMol(mol);
 }
 
 JSMol *get_mol(const std::string &input, const std::string &details_json) {
-  RWMol *mol = MinimalLib::mol_from_input(input, details_json);
+  auto mol = MinimalLib::mol_from_input(input, details_json);
   return new JSMol(mol);
 }
 
@@ -490,10 +672,15 @@ JSMol *get_mol_from_pickle(const std::string &pkl) {
 }
 
 JSMol *get_qmol(const std::string &input) {
-  RWMol *mol = MinimalLib::qmol_from_input(input);
+  auto mol = MinimalLib::qmol_from_input(input);
   return new JSMol(mol);
 }
 
+JSReaction *get_rxn(const std::string &input, const std::string &details_json) {
+  auto rxn = MinimalLib::rxn_from_input(input, details_json);
+  return new JSReaction(rxn);
+}
+
 std::string version() { return std::string(rdkitVersion); }
 
 void prefer_coordgen(bool useCoordGen) {
@@ -501,3 +688,7 @@ void prefer_coordgen(bool useCoordGen) {
   RDDepict::preferCoordGen = useCoordGen;
 #endif
 }
+
+void use_legacy_stereo_perception(bool value) {
+  Chirality::setUseLegacyStereoPerception(value);
+}
\ No newline at end of file
