@@ -11,6 +11,8 @@
 #include <string>
 #include <GraphMol/RDKitBase.h>
 #include <GraphMol/SubstructLibrary/SubstructLibrary.h>
+#include <GraphMol/ChemReactions/Reaction.h>
+#include <GraphMol/ChemReactions/ReactionParser.h>
 
 class JSMol {
  public:
@@ -33,19 +35,47 @@ class JSMol {
   std::string get_substruct_match(const JSMol &q) const;
   std::string get_substruct_matches(const JSMol &q) const;
   std::string get_descriptors() const;
-  std::string get_morgan_fp(unsigned int radius, unsigned int len) const;
-  std::string get_morgan_fp() const { return get_morgan_fp(2, 2048); }
-  std::string get_morgan_fp_as_binary_text(unsigned int radius,
-                                           unsigned int len) const;
+  std::string get_morgan_fp(const std::string &details) const;
+  std::string get_morgan_fp() const { return get_morgan_fp("{}"); }
+  std::string get_morgan_fp_as_binary_text(const std::string &details) const;
   std::string get_morgan_fp_as_binary_text() const {
-    return get_morgan_fp_as_binary_text(2, 2048);
+    return get_morgan_fp_as_binary_text("{}");
   }
-  std::string get_pattern_fp(unsigned int len) const;
-  std::string get_pattern_fp() const { return get_pattern_fp(2048); }
-  std::string get_pattern_fp_as_binary_text(unsigned int len) const;
+  std::string get_pattern_fp(const std::string &details) const;
+  std::string get_pattern_fp() const { return get_pattern_fp("{}"); }
+  std::string get_pattern_fp_as_binary_text(const std::string &details) const;
   std::string get_pattern_fp_as_binary_text() const {
-    return get_pattern_fp_as_binary_text(2048);
+    return get_pattern_fp_as_binary_text("{}");
   }
+  std::string get_topological_torsion_fp(const std::string &details) const;
+  std::string get_topological_torsion_fp() const {
+    return get_topological_torsion_fp("{}");
+  };
+  std::string get_topological_torsion_fp_as_binary_text(
+      const std::string &details) const;
+  std::string get_topological_torsion_fp_as_binary_text() const {
+    return get_topological_torsion_fp_as_binary_text("{}");
+  }
+  std::string get_rdkit_fp(const std::string &details) const;
+  std::string get_rdkit_fp() const { return get_rdkit_fp("{}"); }
+  std::string get_rdkit_fp_as_binary_text(const std::string &details) const;
+  std::string get_rdkit_fp_as_binary_text() const {
+    return get_rdkit_fp_as_binary_text("{}");
+  }
+  std::string get_atom_pair_fp(const std::string &details) const;
+  std::string get_atom_pair_fp() const { return get_atom_pair_fp("{}"); }
+  std::string get_atom_pair_fp_as_binary_text(const std::string &details) const;
+  std::string get_atom_pair_fp_as_binary_text() const {
+    return get_atom_pair_fp_as_binary_text("{}");
+  }
+#ifdef RDK_BUILD_AVALON_SUPPORT
+  std::string get_avalon_fp(const std::string &details) const;
+  std::string get_avalon_fp() const { return get_avalon_fp("{}"); }
+  std::string get_avalon_fp_as_binary_text(const std::string &details) const;
+  std::string get_avalon_fp_as_binary_text() const {
+    return get_avalon_fp_as_binary_text("{}");
+  }
+#endif
   std::string condense_abbreviations(double maxCoverage, bool useLinkers);
   std::string condense_abbreviations() {
     return condense_abbreviations(0.4, false);
@@ -54,21 +84,9 @@ class JSMol {
                                                double maxCoverage,
                                                bool areLinkers);
   std::string generate_aligned_coords(const JSMol &templateMol,
-                                      bool useCoordGen,
-                                      bool allowOptionalAttachments,
-                                      bool acceptFailure);
-  std::string generate_aligned_coords(const JSMol &templateMol,
-                                      bool useCoordGen,
-                                      bool allowOptionalAttachments) {
-    return generate_aligned_coords(templateMol, useCoordGen,
-                                   allowOptionalAttachments, true);
-  };
-  std::string generate_aligned_coords(const JSMol &templateMol,
-                                      bool useCoordGen) {
-    return generate_aligned_coords(templateMol, useCoordGen, false, true);
-  }
+                                      const std::string &details);
   std::string generate_aligned_coords(const JSMol &templateMol) {
-    return generate_aligned_coords(templateMol, false, false, true);
+    return generate_aligned_coords(templateMol, "{}");
   }
   bool is_valid() const { return d_mol.get() != nullptr; }
   bool has_coords() const {
@@ -82,6 +100,20 @@ class JSMol {
   bool set_new_coords() { return set_new_coords(false); }
   std::string get_new_coords(bool useCoordGen) const;
   std::string get_new_coords() const { return get_new_coords(false); }
+  bool has_prop(const std::string &key) const;
+  std::vector<std::string> get_prop_list(bool includePrivate,
+                                         bool includeComputed) const;
+  std::vector<std::string> get_prop_list(bool includePrivate) const {
+    return get_prop_list(includePrivate, true);
+  }
+  std::vector<std::string> get_prop_list() const {
+    return get_prop_list(true, true);
+  }
+  bool set_prop(const std::string &key, const std::string &val, bool computed);
+  bool set_prop(const std::string &key, const std::string &val) {
+    return set_prop(key, val, false);
+  }
+  std::string get_prop(const std::string &key) const;
   std::string remove_hs() const;
   std::string add_hs() const;
   double normalize_depiction(int canonicalize, double scaleFactor);
@@ -89,13 +121,31 @@ class JSMol {
     return normalize_depiction(canonicalize, -1.);
   }
   double normalize_depiction() { return normalize_depiction(1, -1.); }
-  void straighten_depiction();
+  void straighten_depiction(bool minimizeRotation);
+  void straighten_depiction() { straighten_depiction(false); }
 
   std::unique_ptr<RDKit::RWMol> d_mol;
   static constexpr int d_defaultWidth = 250;
   static constexpr int d_defaultHeight = 200;
 };
 
+class JSReaction {
+ public:
+  JSReaction() : d_rxn(nullptr) {}
+  JSReaction(RDKit::ChemicalReaction *rxn) : d_rxn(rxn) {}
+  bool is_valid() const { return d_rxn.get() != nullptr; }
+
+  std::string get_svg(int width, int height) const;
+  std::string get_svg() const {
+    return get_svg(d_defaultWidth, d_defaultHeight);
+  }
+  std::string get_svg_with_highlights(const std::string &details) const;
+
+  std::unique_ptr<RDKit::ChemicalReaction> d_rxn;
+  static constexpr int d_defaultWidth = 800;
+  static constexpr int d_defaultHeight = 200;
+};
+
 class JSSubstructLibrary {
  public:
   JSSubstructLibrary(unsigned int num_bits);
@@ -138,5 +188,7 @@ JSMol *get_mol(const std::string &input, const std::string &details_json);
 JSMol *get_mol_from_pickle(const std::string &pkl);
 JSMol *get_mol_copy(const JSMol &other);
 JSMol *get_qmol(const std::string &input);
+JSReaction *get_rxn(const std::string &input, const std::string &details_json);
 std::string version();
 void prefer_coordgen(bool prefer);
+void use_legacy_stereo_perception(bool value);
