@@ -16,10 +16,8 @@ SELECT mol_from_smiles('c1ccccc');
 SELECT mol_from_smiles('cccccc');
 SELECT is_valid_smiles('c1cccn1');
 SELECT is_valid_smarts('c1ccc[n,c]1');
-SELECT mol_from_smarts('c1ccc[n,c]1');
 SELECT qmol_from_smarts('c1ccc[n,c]1');
 SELECT is_valid_smarts('c1ccc');
-SELECT mol_from_smarts('c1ccc');
 SELECT qmol_from_smarts('c1ccc');
 SELECT mol_to_smiles(mol_from_smiles('c1ccccc1'));
 SELECT mol_to_smarts(mol_from_smiles('c1ccccc1'));
@@ -299,12 +297,12 @@ select rsubstruct_chiral('C[C@@H](O)[C@@H](C)F |o1:1,3,r|'::mol,'C[C@@H](O)[C@@H
 -- substructure counts
 select substruct_count('c1ccncc1'::mol,'c1ccncc1'::mol);
 select substruct_count('c1ccncc1'::mol,'c1ccncc1'::mol,false);
-select substruct_count('c1ccccc1C[C@@H](O)[C@@H](C)F |&1:1,3,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |o1:1,3,r|'::mol);
-select substruct_count('c1ccccc1C[C@@H](O)[C@@H](C)F |o1:1,3,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |&1:1,3,r|'::mol);
-select substruct_count_chiral('c1ccccc1C[C@@H](O)[C@@H](C)F |&1:1,3,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |o1:1,3,r|'::mol);
-select substruct_count_chiral('c1ccccc1C[C@@H](O)[C@@H](C)F |o1:1,3,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |&1:1,3,r|'::mol);
-select substruct_count_chiral('c1ccccc1C[C@@H](O)[C@@H](C)F |&1:1,3,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |o1:1,3,r|'::mol,false);
-select substruct_count_chiral('c1ccccc1C[C@@H](O)[C@@H](C)F |o1:1,3,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |&1:1,3,r|'::mol,false);
+select substruct_count('c1ccccc1C[C@@H](O)[C@@H](C)F |&1:7,9,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |o1:7,9,r|'::mol);
+select substruct_count('c1ccccc1C[C@@H](O)[C@@H](C)F |o1:7,9,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |&1:7,9,r|'::mol);
+select substruct_count_chiral('c1ccccc1C[C@@H](O)[C@@H](C)F |&1:7,9,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |o1:7,9,r|'::mol);
+select substruct_count_chiral('c1ccccc1C[C@@H](O)[C@@H](C)F |o1:7,9,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |&1:7,9,r|'::mol);
+select substruct_count_chiral('c1ccccc1C[C@@H](O)[C@@H](C)F |&1:7,9,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |o1:7,9,r|'::mol,false);
+select substruct_count_chiral('c1ccccc1C[C@@H](O)[C@@H](C)F |o1:7,9,r|'::mol,'c1ccccc1C[C@@H](O)[C@@H](C)F |&1:7,9,r|'::mol,false);
 
 -- special queries
 select 'c1ccc[nH]1'::mol@>mol_from_smiles('c1cccn1[H]') as match;
@@ -379,6 +377,57 @@ select 'c1cccn1C'::mol@>qmol_from_ctab('query
   3  4  1  0  0  0  0
   1  6  1  0  0  0  0
 M  END') as match;
+-- github #4787:
+select mol_to_smarts(qmol_from_ctab('query
+  Mrv0541 04021509592D
+
+  6  6  0  0  0  0            999 V2000
+   -0.2652    0.7248    0.0000 N   0  0  0  0  0  0  0  0  0  0  0  0
+   -0.9796    1.1373    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0
+   -0.9796    1.9623    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0
+    0.4493    1.9623    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0
+    0.4493    1.1373    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0
+   -0.2652   -0.1002    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0
+  1  2  1  0  0  0  0
+  2  3  2  0  0  0  0
+  4  5  2  0  0  0  0
+  1  5  1  0  0  0  0
+  3  4  1  0  0  0  0
+  1  6  1  0  0  0  0
+M  END'));
+select mol_to_smarts(qmol_from_ctab('query
+  Mrv0541 04021509592D
+
+  6  6  0  0  0  0            999 V2000
+   -0.2652    0.7248    0.0000 N   0  0  0  0  0  0  0  0  0  0  0  0
+   -0.9796    1.1373    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0
+   -0.9796    1.9623    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0
+    0.4493    1.9623    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0
+    0.4493    1.1373    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0
+   -0.2652   -0.1002    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0
+  1  2  4  0  0  0  0
+  2  3  4  0  0  0  0
+  4  5  4  0  0  0  0
+  1  5  4  0  0  0  0
+  3  4  4  0  0  0  0
+  1  6  1  0  0  0  0
+M  END'));
+select mol_to_smarts(qmol_from_ctab('Boronate acid/ester(aryl)
+  SciTegic12012112112D
+
+  5  4  0  0  0  0            999 V2000
+    1.7243   -2.7324    0.0000 A   0  0
+    2.7559   -2.1456    0.0000 C   0  0
+    3.7808   -2.7324    0.0000 B   0  0
+    4.8057   -2.1456    0.0000 O   0  0
+    3.7808   -3.9190    0.0000 O   0  0
+  1  2  4  0  0  1  0
+  2  3  1  0
+  3  4  1  0
+  3  5  1  0
+M  END'));
+select mol_to_smarts(qmol_from_smiles('c:c'));
+select mol_to_smarts(qmol_from_smiles('C1=CC=CC=C1'));
 
 -- mol_adjust_query_properties
 select 'C1CC1OC'::mol @> 'C1CC1O*'::mol;
@@ -410,13 +459,13 @@ select mol_to_smarts(mol_adjust_query_properties('*c1ncc(*)cc1'::qmol));
 
 
 -- CXSmiles
-SELECT mol_to_smiles(mol_from_smiles('C[C@H](F)[C@H](C)[C@@H](C)Br |a:1,o1:4,5|'));
-SELECT mol_to_cxsmiles(mol_from_smiles('C[C@H](F)[C@H](C)[C@@H](C)Br |a:1,o1:4,5|'));
-SELECT mol_to_cxsmarts(mol_from_smiles('C[C@H](F)[C@H](C)[C@@H](C)Br |a:1,o1:4,5|'));
-SELECT mol_to_cxsmarts(qmol_from_smarts('C[C@H]([F,Cl,Br])[C@H](C)[C@@H](C)Br |a:1,o1:4,5|'));
+SELECT mol_to_smiles(mol_from_smiles('C[C@H](F)[C@H](C)[C@@H](C)Br |a:1,o1:3,5|'));
+SELECT mol_to_cxsmiles(mol_from_smiles('C[C@H](F)[C@H](C)[C@@H](C)Br |a:1,o1:3,5|'));
+SELECT mol_to_cxsmarts(mol_from_smiles('C[C@H](F)[C@H](C)[C@@H](C)Br |a:1,o1:3,5|'));
+SELECT mol_to_cxsmarts(qmol_from_smarts('C[C@H]([F,Cl,Br])[C@H](C)[C@@H](C)Br |a:1,o1:3,5|'));
 
 -- CXSmiles from mol_out
-SELECT mol_out(mol_from_smiles('C[C@H](F)[C@H](C)[C@@H](C)Br |a:1,o1:4,5|'));
+SELECT mol_out(mol_from_smiles('C[C@H](F)[C@H](C)[C@@H](C)Br |a:1,o1:3,5|'));
 
 -- github #3688: bad input to qmol_from_ctab() crashes db
 select qmol_from_ctab('a'::cstring,false);
@@ -425,4 +474,20 @@ select qmol_from_smiles('a'::cstring);
 select qmol_from_smiles('C1C'::cstring);
 
 -- casting from mol to qmol
-select mol_from_smiles('C=C')::qmol;
\ No newline at end of file
+select mol_from_smiles('C=C')::qmol;
+
+-- github #5095: cannot restore molecule
+select mol_in('c1cccc'::cstring);
+select mol_in('c1cccc1'::cstring);
+select mol_in('c1co(C)cc1'::cstring);
+select mol_in('c1cccc'::cstring);
+select mol_in('CN(=O)=O'::cstring);
+select 'CN(=O)=O'::mol;
+select 'c1cccc1'::mol;
+select 'c1co(C)cc1'::mol;
+select mol_in('c1cccc1'::cstring) @> '[r5]'::qmol;
+select 'c1cccc1'::mol @> '[r5]'::qmol;
+select mol_in('Cc1ccc2c(c1)-n1-c(=O)c=cc(=O)-n-2-c2cc(C)ccc2-1');
+select 'c1cccc1'::text::mol;
+select 'c1cccc1'::varchar::mol;
+select mol_from_smiles('CCN(=O)=O') @> 'CN(=O)=O';
\ No newline at end of file
