@@ -67,6 +67,9 @@
 #if (__GNUC__ > 4 || __GNUC_MINOR__ > 7)
 #pragma GCC diagnostic ignored "-Wunused-local-typedefs"
 #endif
+#if (__GNUC__ > 8)
+#pragma GCC diagnostic ignored "-Wdeprecated-copy"
+#endif
 #elif defined(__HP_cc) || defined(__HP_aCC)
 /* Hewlett-Packard C/aC++. ---------------------------------- */
 
@@ -85,3 +88,8 @@
 /* Oracle Solaris Studio. ----------------------------------- */
 
 #endif
+
+#ifndef BOOST_ALLOW_DEPRECATED_HEADERS
+#define RDK_ALLOW_BOOST_DEPRECATED_HEADERS
+#define BOOST_ALLOW_DEPRECATED_HEADERS
+#endif
\ No newline at end of file
