@@ -1,6 +1,5 @@
-// $Id$
 //
-// Copyright (C) 2001-2013 Greg Landrum, Randal M. Henne, and Rational Discovery
+// Copyright (C) 2001-2020 Greg Landrum, Randal M. Henne, and Rational Discovery
 // LLC
 //
 //  @@ All Rights Reserved @@
@@ -17,9 +16,9 @@
 #include <boost/lexical_cast.hpp>
 #include "versions.h"
 
-#ifdef SHOW_BACKTRACES_WITH_INVARIANT_ERRORS  // note: works only with
-                                              // gcc-derived compilers
-#include <execinfo.h>
+#ifdef RDK_USE_BOOST_STACKTRACE
+#include <boost/stacktrace.hpp>
+#include <sstream>
 #endif
 
 namespace Invar {
@@ -31,20 +30,17 @@ std::ostream &operator<<(std::ostream &s, const Invariant &inv) {
 std::string Invariant::toString() const {
   std::string line = std::to_string(this->getLine());
 
-  std::string stringRep = this->prefix_d + "\n" + this->getMessage() +
-                          "\nViolation occurred on line " + line + " in file " +
-                          this->getFile() + "\nFailed Expression: " +
-                          this->getExpression() + "\n";
-
-#ifdef SHOW_BACKTRACES_WITH_INVARIANT_ERRORS
-  void *arr[10];
-  size_t sz;
-  sz = backtrace(arr, 10);
-  std::cerr << " STACK TRACE\n--------------\n" << std::endl;
-  backtrace_symbols_fd(arr, sz, 2);
-  std::cerr << "\n--------------\n" << std::endl;
+  std::string stringRep =
+      this->prefix_d + "\n" + this->what() + "\nViolation occurred on line " +
+      line + " in file " + this->getFile() +
+      "\nFailed Expression: " + this->getExpression() + "\n";
+#ifdef RDK_USE_BOOST_STACKTRACE
+  std::stringstream sstr;
+  sstr << "----------\n"
+       << "Stacktrace:\n"
+       << boost::stacktrace::stacktrace() << "----------\n";
+  stringRep += sstr.str();
 #endif
-
   return stringRep;
 }
 
@@ -52,19 +48,18 @@ std::string Invariant::toUserString() const {
   std::string line = std::to_string(this->getLine());
 
   std::string filename = this->getFile();
-  
-  std::size_t pos = filename.find("Code"); // strip out build directory info
+
+  std::size_t pos = filename.find("Code");  // strip out build directory info
   if (pos != std::string::npos) {
     filename = filename.substr(pos);
   }
-  
-  std::string stringRep = this->prefix_d + "\n\t" + this->getMessage() +
-      "\n\tViolation occurred on line " + line + " in file " +
-      filename + "\n\tFailed Expression: " +
-      this->getExpression() + "\n\t" +
-      "RDKIT: " + RDKit::rdkitVersion + "\n\t" +
-      "BOOST: " + RDKit::boostVersion + "\n";
 
+  std::string stringRep = this->prefix_d + "\n\t" + this->what() +
+                          "\n\tViolation occurred on line " + line +
+                          " in file " + filename +
+                          "\n\tFailed Expression: " + this->getExpression() +
+                          "\n\t" + "RDKIT: " + RDKit::rdkitVersion + "\n\t" +
+                          "BOOST: " + RDKit::boostVersion + "\n";
 
 #ifdef SHOW_BACKTRACES_WITH_INVARIANT_ERRORS
   void *arr[10];
@@ -78,4 +73,4 @@ std::string Invariant::toUserString() const {
   return stringRep;
 }
 
-};
+};  // namespace Invar
