@@ -1,8 +1,6 @@
 //
 // Copyright (C) 2018 Greg Landrum
 //
-#define CATCH_CONFIG_MAIN  // This tells Catch to provide a main() - only do
-                           // this in one cpp file per test
 #include "catch.hpp"
 
 #include <GraphMol/RDKitBase.h>
