@@ -64,7 +64,7 @@ from rdkit.Chem.MolDb import Loader
 logger = logger()
 import sys, os
 import io
-from rdkit.six.moves import cPickle
+import pickle
 from rdkit.Chem.MolDb.FingerprintUtils import BuildSigFactory, LayeredOptions
 from rdkit.Chem.MolDb import FingerprintUtils
 
@@ -286,7 +286,7 @@ def CreateDb(options, dataFilename='', supplier=None):
     with open(options.descriptorCalcFilename, 'r') as inTF:
       buf = inTF.read().replace('\r\n', '\n').encode('utf-8')
       inTF.close()
-    calc = cPickle.load(io.BytesIO(buf))
+    calc = pickle.load(io.BytesIO(buf))
     nms = [x for x in calc.GetDescriptorNames()]
     descrCurs = descrConn.GetCursor()
     descrs = ['guid integer not null primary key', '%s varchar not null unique' % options.molIdName]
