@@ -9,14 +9,19 @@
 #
 import os
 import warnings
+from collections import namedtuple
 from importlib.util import find_spec
+from io import BytesIO
 
-from rdkit.Chem.Draw import rdMolDraw2D
-from rdkit.Chem.Draw.MolDrawing import MolDrawing, DrawingOptions
-from rdkit.Chem.Draw.rdMolDraw2D import *
-from rdkit.Chem import rdDepictor
-from rdkit import Chem, rdBase
+import numpy
+from rdkit import Chem
 from rdkit import RDConfig
+from rdkit import rdBase
+from rdkit.Chem import rdDepictor
+from rdkit.Chem.Draw import rdMolDraw2D
+from rdkit.Chem.Draw.MolDrawing import DrawingOptions
+from rdkit.Chem.Draw.MolDrawing import MolDrawing
+from rdkit.Chem.Draw.rdMolDraw2D import *
 
 
 def _getCanvas():
@@ -150,24 +155,35 @@ def _legacyMolToImage(mol, size, kekulize, wedgeBonds, fitImage, options, canvas
 
 
 def _sip_available():
-  if find_spec('PyQt5') and find_spec('PyQt5.sip'):
+  try:
+    from rdkit.Chem.Draw.rdMolDraw2DQt import rdkitQtVersion
+  except ImportError:
+    return False
+  pyqt_pkg = f'PyQt{rdkitQtVersion[0]}'
+  if find_spec(pyqt_pkg) and find_spec(f'{pyqt_pkg}.sip'):
     return True
   elif find_spec('sip'):
     return True
   return False
 
 
-if find_spec('rdkit.Chem.Draw.rdMolDraw2DQt') and _sip_available():
+if _sip_available():
 
   def MolDraw2DFromQPainter(qpainter, width=-1, height=-1, panelWidth=-1, panelHeight=-1):
-    from PyQt5.Qt import QPainter
+    from rdkit.Chem.Draw import rdMolDraw2DQt
+    if rdMolDraw2DQt.rdkitQtVersion.startswith('6'):
+      from PyQt6.QtGui import QPainter
+    else:
+      from PyQt5.Qt import QPainter
     try:
-      # Prefer the PyQt5-bundled sip
-      from PyQt5 import sip
+      # Prefer the PyQt-bundled sip
+      if rdMolDraw2DQt.rdkitQtVersion.startswith('6'):
+        from PyQt6 import sip
+      else:
+        from PyQt5 import sip
     except ImportError:
       # No bundled sip, try the standalone package
       import sip
-    from rdkit.Chem.Draw import rdMolDraw2DQt
 
     if not isinstance(qpainter, QPainter):
       raise ValueError("argument must be a QPainter instance")
@@ -312,6 +328,7 @@ def ShowMol(mol, size=(300, 300), kekulize=True, wedgeBonds=True, title='RDKit M
   """ Generates a picture of a molecule and displays it in a Tkinter window
   """
   import tkinter
+
   from PIL import ImageTk
 
   img = MolToImage(mol, size, kekulize, wedgeBonds, **kwargs)
@@ -361,9 +378,6 @@ def MolToMPL(mol, size=(300, 300), kekulize=True, wedgeBonds=True, imageType=Non
   return canvas._figure
 
 
-import numpy
-
-
 def _bivariate_normal(X, Y, sigmax=1.0, sigmay=1.0, mux=0.0, muy=0.0, sigmaxy=0.0):
   """
 
@@ -426,21 +440,15 @@ def MolsToImage(mols, subImgSize=(200, 200), legends=None, **kwargs):
   return res
 
 
-from io import BytesIO
-
-
 def _drawerToImage(d2d):
   from PIL import Image
   sio = BytesIO(d2d.GetDrawingText())
   return Image.open(sio)
 
 
-def _okToKekulizeMol(mol, kekulize):
+def shouldKekulize(mol, kekulize):
   if kekulize:
-    for bond in mol.GetBonds():
-      if bond.GetIsAromatic() and bond.HasQuery():
-        return False
-    return True
+    return not any(bond.GetIsAromatic() and bond.HasQuery() for bond in mol.GetBonds())
   return kekulize
 
 
@@ -451,7 +459,7 @@ def _moltoimg(mol, sz, highlights, legend, returnPNG=False, drawOptions=None, **
   except RuntimeError:
     mol.UpdatePropertyCache(False)
 
-  kekulize = _okToKekulizeMol(mol, kwargs.get('kekulize', True))
+  kekulize = shouldKekulize(mol, kwargs.get('kekulize', True))
   wedge = kwargs.get('wedgeBonds', True)
 
   try:
@@ -494,7 +502,7 @@ def _moltoSVG(mol, sz, highlights, legend, kekulize, drawOptions=None, **kwargs)
   except RuntimeError:
     mol.UpdatePropertyCache(False)
 
-  kekulize = _okToKekulizeMol(mol, kekulize)
+  kekulize = shouldKekulize(mol, kekulize)
 
   try:
     with rdBase.BlockLogs():
@@ -538,6 +546,8 @@ def _MolsToGridImage(mols, molsPerRow=3, subImgSize=(200, 200), legends=None,
       highlights = None
       if highlightAtomLists and highlightAtomLists[i]:
         highlights = highlightAtomLists[i]
+      if highlightBondLists and highlightBondLists[i]:
+        kwargs["highlightBonds"] = highlightBondLists[i]
       if mol is not None:
         img = _moltoimg(mol, subImgSize, highlights, legends[i], **kwargs)
         res.paste(img, (col * subImgSize[0], row * subImgSize[1]))
@@ -717,7 +727,6 @@ def DrawMorganBits(tpls, **kwargs):
 
 # adapted from the function drawFPBits._drawFPBit() from the CheTo package
 # original author Nadine Schneider
-from collections import namedtuple
 FingerprintEnv = namedtuple(
   'FingerprintEnv',
   ('submol', 'highlightAtoms', 'atomColors', 'highlightBonds', 'bondColors', 'highlightRadii'))
@@ -748,7 +757,11 @@ def _getMorganEnv(mol, atomId, radius, baseRad, aromaticColor, ringColor, center
 
   # set the coordinates of the submol based on the coordinates of the original molecule
   amap = {}
-  submol = Chem.PathToSubmol(mol, enlargedEnv, atomMap=amap)
+  if enlargedEnv:
+    submol = Chem.PathToSubmol(mol, enlargedEnv, atomMap=amap)
+  else:
+    # generate submol from fragments with no bonds
+    submol = Chem.MolFromSmiles(Chem.MolFragmentToSmiles(mol, atomsToUse=atomsToUse))
   Chem.FastFindRings(submol)
   conf = Chem.Conformer(submol.GetNumAtoms())
   confOri = mol.GetConformer(0)
