@@ -12,6 +12,7 @@
 
  defined in: Hall and Kier JCICS _35_ 1039-1045 (1995)  Table 1
 """
+import sys
 from rdkit import Chem
 
 _rawD = [
@@ -136,9 +137,10 @@ def TypeAtoms(mol):
         res[idx] = [name]
       elif name not in res[idx]:
         res[idx].append(name)
+  
   for i, v in enumerate(res):
     if v is not None:
       res[i] = tuple(v)
     else:
-      res[i] = ()
+      res[i] = tuple()
   return res
