@@ -18,15 +18,14 @@ Sample Usage:
       --smilesName="structure" -o results.csv
 
 """
-import types
 
-from rdkit import Chem
-from rdkit import DataStructs
-from rdkit.Chem.Fingerprints import FingerprintMols, DbFpSupplier
+import pickle
+
+from rdkit import Chem, DataStructs
+from rdkit.Chem.Fingerprints import DbFpSupplier, FingerprintMols
 from rdkit.DataStructs.TopNContainer import TopNContainer
 from rdkit.Dbase import DbModule
 from rdkit.Dbase.DbConnection import DbConnect
-import pickle
 
 try:
   from rdkit.VLib.NodeLib.DbPickleSupplier import _lazyDataSeq as _dataSeq
@@ -34,24 +33,39 @@ except ImportError:
   _dataSeq = None
 
 
+def _ConnectToDatabase(details) -> DbConnect:
+  if details.dbName and details.tableName:
+    try:
+      conn = DbConnect(details.dbName, details.tableName)
+      if hasattr(details, 'dbUser'):
+        conn.user = details.dbUser
+      if hasattr(details, 'dbPassword'):
+        conn.password = details.dbPassword
+      return conn
+    except Exception:
+      import traceback
+      FingerprintMols.error(f'Error: Problems establishing connection to '
+                            f'database:{details.dbName}|{details.tableName}\n')
+      traceback.print_exc()
+  return None
+
+
 def _ConstructSQL(details, extraFields=''):
-  fields = '%s.%s' % (details.tableName, details.idName)
+  fields = f'{details.tableName}.{details.idName}'
   join = ''
   if details.smilesTableName:
     if details.smilesName:
-      fields = fields + ',%s' % (details.smilesName)
-    join = 'join %s smi on smi.%s=%s.%s' % (details.smilesTableName, details.idName,
-                                            details.tableName, details.idName)
+      fields += f',{details.smilesName}'
+    join = f'join {details.smilesTableName} smi on smi.{details.idName}={details.tableName}.{details.idName}'
   if details.actTableName:
     if details.actName:
-      fields = fields + ',%s' % (details.actName)
-    join = join + 'join %s act on act.%s=%s.%s' % (details.actTableName, details.idName,
-                                                   details.tableName, details.idName)
+      fields += f',{details.actName}'
+    join += f'join {details.actTableName} act on act.{details.idName}={details.tableName}.{details.idName}'
+    
   # data = conn.GetData(fields=fields,join=join)
   if extraFields:
-    fields += ',' + extraFields
-  cmd = 'select %s from %s %s' % (fields, details.tableName, join)
-  return cmd
+    fields += f',{extraFields}'
+  return f'select {fields} from {details.tableName} {join}'
 
 
 def ScreenInDb(details, mol):
@@ -62,48 +76,32 @@ def ScreenInDb(details, mol):
     FingerprintMols.error('Error: problems fingerprinting molecule.\n')
     traceback.print_exc()
     return []
-  if details.dbName and details.tableName:
-    try:
-      conn = DbConnect(details.dbName, details.tableName)
-      if hasattr(details, 'dbUser'):
-        conn.user = details.dbUser
-      if hasattr(details, 'dbPassword'):
-        conn.password = details.dbPassword
-    except Exception:
-      import traceback
-      FingerprintMols.error('Error: Problems establishing connection to database: %s|%s\n' %
-                            (details.dbName, details.tableName))
-      traceback.print_exc()
-
+  
   if details.metric not in (DataStructs.TanimotoSimilarity, DataStructs.DiceSimilarity,
                             DataStructs.CosineSimilarity):
-    data = GetFingerprints(details)
-    res = ScreenFingerprints(details, data, mol)
-  else:
-    res = []
-    if details.metric == DataStructs.TanimotoSimilarity:
-      func = 'rd_tanimoto'
-      pkl = probeFp.ToBitString()
-    elif details.metric == DataStructs.DiceSimilarity:
-      func = 'rd_dice'
-      pkl = probeFp.ToBitString()
-    elif details.metric == DataStructs.CosineSimilarity:
-      func = 'rd_cosine'
-      pkl = probeFp.ToBitString()
-    extraFields = "%s(%s,%s) as tani" % (func, DbModule.placeHolder, details.fpColName)
-    cmd = _ConstructSQL(details, extraFields=extraFields)
+    return ScreenFingerprints(details, data=GetFingerprints(details), mol=mol)
+  
+  conn: DbConnect = _ConnectToDatabase(details)
+  if details.metric == DataStructs.TanimotoSimilarity:
+    func = 'rd_tanimoto'
+  elif details.metric == DataStructs.DiceSimilarity:
+    func = 'rd_dice'
+  elif details.metric == DataStructs.CosineSimilarity:
+    func = 'rd_cosine'
+  pkl = probeFp.ToBitString()
+  extraFields = f"{func}({DbModule.placeHolder},{details.fpColName}) as tani"
+  cmd = _ConstructSQL(details, extraFields=extraFields)
 
-    if details.doThreshold:
-      # we need to do a subquery here:
-      cmd = "select * from (%s) tmp where tani>%f" % (cmd, details.screenThresh)
-    cmd += " order by tani desc"
-    if not details.doThreshold and details.topN > 0:
-      cmd += " limit %d" % details.topN
-    curs = conn.GetCursor()
-    curs.execute(cmd, (pkl, ))
-    res = curs.fetchall()
-
-  return res
+  if details.doThreshold:
+    # we need to do a subquery here:
+    cmd = f"select * from ({cmd}) tmp where tani>{details.screenThresh}"
+  cmd += " order by tani desc"
+  if not details.doThreshold and details.topN > 0:
+    cmd += f" limit {details.topN}"
+  
+  curs = conn.GetCursor()
+  curs.execute(cmd, (pkl, ))
+  return curs.fetchall()
 
 
 def GetFingerprints(details):
@@ -113,33 +111,24 @@ def GetFingerprints(details):
 
   """
   if details.dbName and details.tableName:
-    try:
-      conn = DbConnect(details.dbName, details.tableName)
-      if hasattr(details, 'dbUser'):
-        conn.user = details.dbUser
-      if hasattr(details, 'dbPassword'):
-        conn.password = details.dbPassword
-    except Exception:
-      import traceback
-      FingerprintMols.error('Error: Problems establishing connection to database: %s|%s\n' %
-                            (details.dbName, details.tableName))
-      traceback.print_exc()
+    conn: DbConnect = _ConnectToDatabase(details)
     cmd = _ConstructSQL(details, extraFields=details.fpColName)
     curs = conn.GetCursor()
     # curs.execute(cmd)
     # print 'CURSOR:',curs,curs.closed
+    
     if _dataSeq:
       suppl = _dataSeq(curs, cmd, depickle=not details.noPickle, klass=DataStructs.ExplicitBitVect)
       _dataSeq._conn = conn
-    else:
-      suppl = DbFpSupplier.ForwardDbFpSupplier(data, fpColName=details.fpColName)
-  elif details.inFileName:
-    conn = None
+      return suppl
+    return DbFpSupplier.ForwardDbFpSupplier(data, fpColName=details.fpColName)
+  
+  if details.inFileName:
     try:
       inF = open(details.inFileName, 'r')
     except IOError:
       import traceback
-      FingerprintMols.error('Error: Problems reading from file %s\n' % (details.inFileName))
+      FingerprintMols.error(f'Error: Problems reading from file {details.inFileName}\n')
       traceback.print_exc()
 
     suppl = []
@@ -152,10 +141,9 @@ def GetFingerprints(details):
       else:
         fp._fieldsFromDb = [ID]
         suppl.append(fp)
-  else:
-    suppl = None
+    return suppl
 
-  return suppl
+  return None
 
 
 def ScreenFingerprints(details, data, mol=None, probeFp=None):
@@ -173,7 +161,6 @@ def ScreenFingerprints(details, data, mol=None, probeFp=None):
   if not probeFp:
     return []
 
-  res = []
   if not details.doThreshold and details.topN > 0:
     topN = TopNContainer(details.topN)
   else:
@@ -183,7 +170,7 @@ def ScreenFingerprints(details, data, mol=None, probeFp=None):
   for pt in data:
     fp1 = probeFp
     if not details.noPickle:
-      if type(pt) in (types.TupleType, types.ListType):
+      if isinstance(pt, (tuple, list)):
         ID, fp = pt
       else:
         fp = pt
@@ -194,15 +181,14 @@ def ScreenFingerprints(details, data, mol=None, probeFp=None):
       score = details.metric(fp1, str(pkl))
     if topN:
       topN.Insert(score, ID)
-    elif not details.doThreshold or \
-             (details.doThreshold and score >= details.screenThresh):
+    elif not details.doThreshold or (details.doThreshold and score >= details.screenThresh):
       res.append((ID, score))
     count += 1
     if hasattr(details, 'stopAfter') and count >= details.stopAfter:
       break
+
   for score, ID in topN:
     res.append((ID, score))
-
   return res
 
 
@@ -217,9 +203,9 @@ def ScreenFromDetails(details, mol=None):
         mol = Chem.MolFromSmiles(smi)
       except Exception:
         import traceback
-        FingerprintMols.error('Error: problems generating molecule for smiles: %s\n' % (smi))
+        FingerprintMols.error(f'Error: problems generating molecule for smiles: {smi}\n')
         traceback.print_exc()
-        return
+        return None
     else:
       mol = details.probeMol
   if not mol:
@@ -229,17 +215,16 @@ def ScreenFromDetails(details, mol=None):
     try:
       outF = open(details.outFileName, 'w+')
     except IOError:
-      FingerprintMols.error("Error: could not open output file %s for writing\n" %
-                            (details.outFileName))
+      FingerprintMols.error(f"Error: could not open output file {details.outFileName} for writing\n")
       return None
   else:
     outF = None
 
   if not hasattr(details, 'useDbSimilarity') or not details.useDbSimilarity:
-    data = GetFingerprints(details)
-    res = ScreenFingerprints(details, data, mol)
+    res = ScreenFingerprints(details, data=GetFingerprints(details), mol=mol)
   else:
     res = ScreenInDb(details, mol)
+    
   if outF:
     for pt in res:
       outF.write(','.join([str(x) for x in pt]))
