@@ -7,15 +7,15 @@
 #  which is included in the file license.txt, found at the root
 #  of the RDKit source tree.
 #
-from rdkit import Chem
-from rdkit.Chem import AllChem
-from rdkit.Chem import Lipinski, Descriptors, Crippen
-from rdkit.Dbase.DbConnection import DbConnect
-from rdkit.Dbase import DbModule
 import re
 
 #set up the logger:
 import rdkit.RDLogger as logging
+from rdkit import Chem
+from rdkit.Chem import AllChem, Crippen, Descriptors, Lipinski
+from rdkit.Dbase import DbModule
+from rdkit.Dbase.DbConnection import DbConnect
+
 logger = logging.logger()
 logger.setLevel(logging.INFO)
 
@@ -32,12 +32,13 @@ def ProcessMol(mol, typeConversions, globalProps, nDone, nameProp='_Name', nameC
   except KeyError:
     nm = None
   if not nm:
-    nm = 'Mol_%d' % nDone
+    nm = f'Mol_{nDone}'
   if uniqNames and nm in namesSeen:
-    logger.error('duplicate compound id (%s) encountered. second instance skipped.' % nm)
+    logger.error(f'duplicate compound id ({nm}) encountered. second instance skipped.')
     return None
   namesSeen.add(nm)
   row = [nm]
+  pD = {}
   if not skipProps:
     if addComputedProps:
       nHD = Lipinski.NumHDonors(mol)
@@ -52,8 +53,7 @@ def ProcessMol(mol, typeConversions, globalProps, nDone, nameProp='_Name', nameC
       mol.SetProp('MolLogP', str(logp))
 
     pns = list(mol.GetPropNames())
-    pD = {}
-    for pi, pn in enumerate(pns):
+    for pn in pns:
       if pn.lower() == nameCol.lower():
         continue
       pv = mol.GetProp(pn).strip()
@@ -61,7 +61,7 @@ def ProcessMol(mol, typeConversions, globalProps, nDone, nameProp='_Name', nameC
         colTyp = globalProps.get(pn, 2)
         while colTyp > 0:
           try:
-            tpi = typeConversions[colTyp][1](pv)
+            _ = typeConversions[colTyp][1](pv)
           except Exception:
             colTyp -= 1
           else:
@@ -70,12 +70,11 @@ def ProcessMol(mol, typeConversions, globalProps, nDone, nameProp='_Name', nameC
         pD[pn] = typeConversions[colTyp][1](pv)
       else:
         pD[pn] = pv
-  else:
-    pD = {}
+
   if redraw:
     AllChem.Compute2DCoords(m)
   if not skipSmiles:
-    row.append(Chem.MolToSmiles(mol, True))
+    row.append(Chem.MolToSmiles(mol))
   row.append(DbModule.binaryHolder(mol.ToBinary()))
   row.append(pD)
   return row
@@ -83,14 +82,12 @@ def ProcessMol(mol, typeConversions, globalProps, nDone, nameProp='_Name', nameC
 
 def ConvertRows(rows, globalProps, defaultVal, skipSmiles):
   for i, row in enumerate(rows):
-    newRow = [row[0], row[1]]
-    pD = row[-1]
-    for pn in globalProps:
-      pv = pD.get(pn, defaultVal)
-      newRow.append(pv)
-    newRow.append(row[2])
-    if not skipSmiles:
-      newRow.append(row[3])
+    newRow = [row[0], row[1]] 
+    pD = row[-1] 
+    newRow.extend(pD.get(pn, defaultVal) for pn in globalProps) 
+    newRow.append(row[2]) 
+    if not skipSmiles: 
+      newRow.append(row[3]) 
     rows[i] = newRow
 
 
@@ -103,9 +100,9 @@ def LoadDb(suppl, dbName, nameProp='_Name', nameCol='compound_id', silent=False,
   else:
     nMols = -1
   if not silent:
-    logger.info("Generating molecular database in file %s" % dbName)
+    logger.info(f"Generating molecular database in file {dbName}")
     if not lazySupplier:
-      logger.info("  Processing %d molecules" % nMols)
+      logger.info(f"  Processing {nMols} molecules")
   rows = []
   globalProps = {}
   namesSeen = set()
@@ -130,18 +127,18 @@ def LoadDb(suppl, dbName, nameProp='_Name', nameCol='compound_id', silent=False,
       continue
     rows.append([nDone] + row)
     if not silent and not nDone % 100:
-      logger.info('  done %d' % nDone)
+      logger.info(f'  done {nDone}')
     if len(rows) == maxRowsCached:
       break
 
-  nameDef = '%s varchar not null' % nameCol
+  nameDef = f'{nameCol} varchar not null'
   if uniqNames:
     nameDef += ' unique'
   typs = ['guid integer not null primary key', nameDef]
   pns = []
   for pn, v in globalProps.items():
     addNm = re.sub(r'[\W]', '_', pn)
-    typs.append('%s %s' % (addNm, typeConversions[v][0]))
+    typs.append(f'{addNm} {typeConversions[v][0]}')
     pns.append(pn.lower())
 
   if not skipSmiles:
@@ -149,30 +146,30 @@ def LoadDb(suppl, dbName, nameProp='_Name', nameCol='compound_id', silent=False,
       typs.append('smiles varchar')
     else:
       typs.append('cansmiles varchar')
-  typs.append('molpkl %s' % (DbModule.binaryTypeName))
+  typs.append(f'molpkl {DbModule.binaryTypeName}')
   conn = DbConnect(dbName)
   curs = conn.GetCursor()
   if startAnew:
     try:
-      curs.execute('drop table %s' % regName)
+      curs.execute(f'drop table {regName}')
     except Exception:
       pass
-    curs.execute('create table %s (%s)' % (regName, ','.join(typs)))
+    curs.execute(f'create table {regName} ({",".join(typs)})')
   else:
-    curs.execute('select * from %s limit 1' % (regName, ))
+    curs.execute(f'select * from {regName} limit 1')
     ocolns = set([x[0] for x in curs.description])
     ncolns = set([x.split()[0] for x in typs])
     if ncolns != ocolns:
-      raise ValueError('Column names do not match: %s != %s' % (ocolns, ncolns))
-    curs.execute('select max(guid) from %s' % (regName, ))
+      raise ValueError(f'Column names do not match: {ocolns} != {ncolns}')
+    curs.execute(f'select max(guid) from {regName}')
     offset = curs.fetchone()[0]
     for row in rows:
       row[0] += offset
 
-  qs = ','.join([DbModule.placeHolder for x in typs])
+  qs = ','.join([DbModule.placeHolder for _ in typs])
 
   ConvertRows(rows, globalProps, defaultVal, skipSmiles)
-  curs.executemany('insert into %s values (%s)' % (regName, qs), rows)
+  curs.executemany(f'insert into {regName} values ({qs})', rows)
   conn.Commit()
 
   rows = []
@@ -190,7 +187,7 @@ def LoadDb(suppl, dbName, nameProp='_Name', nameCol='compound_id', silent=False,
         else:
           logger.warning('full error file support not complete')
       continue
-    tmpProps = {}
+
     row = ProcessMol(m, typeConversions, globalProps, nDone, nameProp=nameProp, nameCol=nameCol,
                      redraw=redraw, keepHs=keepHs, skipProps=skipProps,
                      addComputedProps=addComputedProps, skipSmiles=skipSmiles, uniqNames=uniqNames,
@@ -199,13 +196,13 @@ def LoadDb(suppl, dbName, nameProp='_Name', nameCol='compound_id', silent=False,
       continue
     rows.append([nDone] + row)
     if not silent and not nDone % 100:
-      logger.info('  done %d' % nDone)
+      logger.info(f'  done {nDone}')
     if len(rows) == maxRowsCached:
       ConvertRows(rows, globalProps, defaultVal, skipSmiles)
-      curs.executemany('insert into %s values (%s)' % (regName, qs), rows)
+      curs.executemany(f'insert into {regName} values ({qs})', rows)
       conn.Commit()
       rows = []
   if len(rows):
     ConvertRows(rows, globalProps, defaultVal, skipSmiles)
-    curs.executemany('insert into %s values (%s)' % (regName, qs), rows)
+    curs.executemany(f'insert into {regName} values ({qs})', rows)
     conn.Commit()
