@@ -9,10 +9,6 @@ This module contains exceptions that are raised by MolVS.
 :license: MIT, see LICENSE file for more details.
 """
 
-from __future__ import print_function
-from __future__ import unicode_literals
-from __future__ import division
-
 
 class MolVSError(Exception):
     pass
