@@ -127,10 +127,7 @@ def is_organic(fragment):
     """
     # TODO: Consider a different definition?
     # Could allow only H, C, N, O, S, P, F, Cl, Br, I
-    for a in fragment.GetAtoms():
-        if a.GetAtomicNum() == 6:
-            return True
-    return False
+    return any(atom.GetAtomicNum() == 6 for atom in fragment.GetAtoms())
 
 
 class FragmentRemover(object):
@@ -166,13 +163,13 @@ class FragmentRemover(object):
         log.debug('Running FragmentRemover')
         # Iterate FragmentPatterns and remove matching fragments
         for frag in self.fragments:
-            # If nothing is left or leave_last and only one fragment, end here
+            # If nothing is left or leave_last and only one fragment, end here.
             if mol.GetNumAtoms() == 0 or (self.leave_last and len(Chem.GetMolFrags(mol)) <= 1):
                 break
             # Apply removal for this FragmentPattern
             removed = Chem.DeleteSubstructs(mol, frag.smarts, onlyFrags=True)
-            if not mol.GetNumAtoms() == removed.GetNumAtoms():
-                log.info('Removed fragment: %s', frag.name)
+            if mol.GetNumAtoms() != removed.GetNumAtoms():
+                log.info(f'Removed fragment: {frag.name}')
             if self.leave_last and removed.GetNumAtoms() == 0:
                 # All the remaining fragments match this pattern - leave them all
                 break
@@ -215,7 +212,7 @@ class LargestFragmentChooser(object):
         largest = None
         for f in fragments:
             smiles = Chem.MolToSmiles(f, isomericSmiles=True)
-            log.debug('Fragment: %s', smiles)
+            log.debug(f'Fragment: {smiles}')
             organic = is_organic(f)
             if self.prefer_organic:
                 # Skip this fragment if not organic and we already have an organic fragment as the largest so far
@@ -239,7 +236,7 @@ class LargestFragmentChooser(object):
             if largest and atoms == largest['atoms'] and weight == largest['weight'] and smiles > largest['smiles']:
                 continue
             # Otherwise this is the largest so far
-            log.debug('New largest fragment: %s (%s)', smiles, atoms)
+            log.debug(f'New largest fragment: {smiles} ({atoms})')
             largest = {'smiles': smiles, 'fragment': f,
                 'atoms': atoms, 'weight': weight, 'organic': organic}
         return largest['fragment']
