@@ -28,7 +28,6 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
-
 '''
 Importing pandasTools enables several features that allow for using RDKit molecules as columns of a
 Pandas dataframe.
@@ -153,7 +152,8 @@ _originalSettings = {}
 highlightSubstructures = True
 molRepresentation = "png"  # supports also SVG
 molSize = (200, 200)
-molJustify = "center" # supports also left, right
+molJustify = "center"  # supports also left, right
+
 
 def _molge(x, y):
   """Allows for substructure check using the >= operator (X has substructure Y -> X >= Y) by
@@ -204,16 +204,16 @@ def PrintAsImageString(x):
       svg.attributes['data-content'] = 'rdkit/molecule'
       return svg.toxml()
     else:
-      data = Draw._moltoimg(x, molSize, highlightAtoms, "", returnPNG=True, kekulize=True, drawOptions=drawOptions)
+      data = Draw._moltoimg(x, molSize, highlightAtoms, "", returnPNG=True, kekulize=True,
+                            drawOptions=drawOptions)
       return (
         f'<div style="width: {molSize[0]}px; height: {molSize[1]}px" data-content="rdkit/molecule">'
-         '<img src="data:image/png;base64,%s" alt="Mol"/>'
-         '</div>' % _get_image(data)
-      )
+        '<img src="data:image/png;base64,%s" alt="Mol"/>'
+        '</div>' % _get_image(data))
 
 
 try:
-  from . import PandasPatcher
+  from rdkit.Chem import PandasPatcher
   PandasPatcher.PrintAsImageString = PrintAsImageString
   PandasPatcher.molJustify = molJustify
   PandasPatcher.InteractiveRenderer = InteractiveRenderer
@@ -239,6 +239,7 @@ try:
 except ImportError:
   pass
 else:
+
   def LoadSDF(filename, idName='ID', molColName='ROMol', includeFingerprints=False,
               isomericSmiles=True, smilesName=None, embedProps=False, removeHs=True,
               strictParsing=True):
@@ -290,7 +291,6 @@ else:
     ChangeMoleculeRendering(df)
     return df
 
-
   def RGroupDecompositionToFrame(groups, mols, include_core=False, redraw_sidechains=False):
     """ returns a dataframe with the results of R-Group Decomposition
 
@@ -301,6 +301,9 @@ else:
     >>> scaffold = Chem.MolFromSmiles('c1ccccn1')
     >>> mols = [Chem.MolFromSmiles(smi) for smi in 'c1c(F)cccn1 c1c(Cl)c(C)ccn1 c1c(O)cccn1 c1c(F)c(C)ccn1 c1cc(Cl)c(F)cn1'.split()]
     >>> groups,_ = rdRGroupDecomposition.RGroupDecompose([scaffold],mols,asSmiles=False,asRows=False)
+    >>> df = PandasTools.RGroupDecompositionToFrame(groups,mols,include_core=False)
+    >>> list(df.columns)
+    ['Mol', 'R1', 'R2']
     >>> df = PandasTools.RGroupDecompositionToFrame(groups,mols,include_core=True)
     >>> list(df.columns)
     ['Mol', 'Core', 'R1', 'R2']
@@ -318,6 +321,7 @@ else:
     memory usage: *...*
 
     """
+    groups = groups.copy()
     cols = ['Mol'] + list(groups.keys())
     if redraw_sidechains:
       from rdkit.Chem import rdDepictor
@@ -333,6 +337,7 @@ else:
       del groups['Core']
     groups['Mol'] = mols
     frame = pd.DataFrame(groups, columns=cols)
+    ChangeMoleculeRendering(frame)
     return frame
 
 
@@ -629,7 +634,6 @@ def _runDoctests(verbose=None):  # pragma: nocover
 
 InstallPandasTools()
 
-
 if __name__ == '__main__':  # pragma: nocover
   import unittest
   try:
@@ -638,6 +642,7 @@ if __name__ == '__main__':  # pragma: nocover
     xlsxwriter = None
   try:
     import pandas as pd
+
     def _getPandasVersion():
       """ Get the pandas version as a tuple """
       import re
