@@ -115,7 +115,7 @@ class FontManager:
             '-underline %(underline)s' % tkfont.config())
 
   def getTkFontName(self, font):
-    """Return a the name associated with the piddle-style FONT"""
+    """Return a name associated with the piddle-style FONT"""
     tkfont = self.piddleToTkFont(font)
     return str(tkfont)
 
@@ -133,7 +133,7 @@ class FontManager:
 
     if font.face:
       # check if the user specified a generic face type
-      # like serif or monospaced. check is case-insenstive.
+      # like serif or monospaced. check is case-insensitive.
       f = font.face.lower()
       if f in self.__alt_faces:
         family = self.__alt_faces[f]
